@@ -10,9 +10,8 @@
 # For more details see the full text of the license in the file        *
 # LICENSE or in <http://www.gnu.org/licenses/>.                        *
 #                                                                      *
-# Copyright (C) 2013-2017, Daniel Fairhead                             *
+# Copyright (C) 2013-2019, Daniel Fairhead                             *
 #***********************************************************************
-
 """
 SimpleEval - from https://github.com/danthedeckie/simpleeval
 -------------------------------------
@@ -46,7 +45,7 @@ THE SOFTWARE.
 
 Initial idea copied from J.F. Sebastian on Stack Overflow
 ( http://stackoverflow.com/a/9558001/1973500 ) with
-modifications and many improvments.
+modifications and many improvements.
 
 -------------------------------------
 Contributors:
@@ -57,10 +56,19 @@ Contributors:
 - perkinslr (Logan Perkins) (.__globals__ or .func_ breakouts)
 - impala2 (Kirill Stepanov) (massive _eval refactor)
 - gk (ugik) (Other iterables than str can DOS too, and can be made)
-- daveisfera (Dave Johansen) 'not' Boolean op, Pycharm and pep8 fixes.
+- daveisfera (Dave Johansen) 'not' Boolean op, Pycharm, pep8, various other fixes
+- xaled (Khalid Grandi) method chaining correctly, double-eval bugfix.
+- EdwardBetts (Edward Betts) spelling correction.
+- charlax (Charles-Axel Dein charlax) Makefile and cleanups
+- mommothazaz123 (Andrew Zhu) f"string" support, Python 3.8 support
+- lubieowoce (Uryga) various potential vulnerabilities
+- JCavallo (Jean Cavallo) names dict shouldn't be modified
+- Birne94 (Daniel Birnstiel) for fixing leaking generators.
+- patricksurry (Patrick Surry) or should return last value, even if falsy.
+- shughes-uk (Samantha Hughes) python w/o 'site' should not fail to import.
 
 -------------------------------------
-Usage:
+Basic Usage:
 
 >>> s = SimpleEval()
 >>> s.eval("20 + 30")
@@ -71,11 +79,11 @@ You can add your own functions easily too:
 if file.txt contents is "11"
 
 >>> def get_file():
-        with open("file.txt",'r') as f:
-            return f.read()
+...     with open("file.txt", 'r') as f:
+...         return f.read()
 
-    s.functions["get_file"] = get_file
-    s.eval("int(get_file()) + 31")
+>>> s.functions["get_file"] = get_file
+>>> s.eval("int(get_file()) + 31")
 42
 
 For more information, see the full package documentation on pypi, or the github
@@ -98,19 +106,41 @@ well:
 """
 
 import ast
-import sys
 import operator as op
+import sys
+import warnings
 from random import random
 
+PYTHON3 = sys.version_info[0] == 3
+
 ########################################
 # Module wide 'globals'
 
 MAX_STRING_LENGTH = 100000
+MAX_COMPREHENSION_LENGTH = 10000
 MAX_POWER = 4000000  # highest exponent
 DISALLOW_PREFIXES = ['_', 'func_']
-DISALLOW_METHODS = ['format']
+DISALLOW_METHODS = ['format', 'format_map', 'mro']
+
+# Disallow functions:
+# This, strictly speaking, is not necessary.  These /should/ never be accessable anyway,
+# if DISALLOW_PREFIXES and DISALLOW_METHODS are all right.  This is here to try and help
+# people not be stupid.  Allowing these functions opens up all sorts of holes - if any of
+# their functionality is required, then please wrap them up in a safe container.  And think
+# very hard about it first.  And don't say I didn't warn you.
+# builtins is a dict in python >3.6 but a module before
+DISALLOW_FUNCTIONS = {
+        type, isinstance, eval, getattr, setattr, repr, compile, open
+        }
+if hasattr(__builtins__, 'help') or \
+        (hasattr(__builtins__, '__contains__') and 'help' in __builtins__):
+    # PyInstaller environment doesn't include this module.
+    DISALLOW_FUNCTIONS.add(help)
+
+
+if PYTHON3:
+    exec('DISALLOW_FUNCTIONS.add(exec)') # exec is not a function in Python2...
 
-PYTHON3 = sys.version_info[0] == 3
 
 ########################################
 # Exceptions:
@@ -118,15 +148,17 @@ PYTHON3 = sys.version_info[0] == 3
 
 class InvalidExpression(Exception):
     """ Generic Exception """
+
     pass
 
 
 class FunctionNotDefined(InvalidExpression):
     """ sorry! That function isn't defined! """
+
     def __init__(self, func_name, expression):
         self.message = "Function '{0}' not defined," \
                        " for expression '{1}'.".format(func_name, expression)
-        self.func_name = func_name
+        setattr(self, 'func_name', func_name)  # bypass 2to3 confusion.
         self.expression = expression
 
         # pylint: disable=bad-super-call
@@ -135,6 +167,7 @@ class FunctionNotDefined(InvalidExpression):
 
 class NameNotDefined(InvalidExpression):
     """ a name isn't defined. """
+
     def __init__(self, name, expression):
         self.name = name
         self.message = "'{0}' is not defined for expression '{1}'".format(
@@ -147,6 +180,7 @@ class NameNotDefined(InvalidExpression):
 
 class AttributeDoesNotExist(InvalidExpression):
     """attribute does not exist"""
+
     def __init__(self, attr, expression):
         self.message = \
             "Attribute '{0}' does not exist in expression '{1}'".format(
@@ -157,19 +191,24 @@ class AttributeDoesNotExist(InvalidExpression):
 
 class FeatureNotAvailable(InvalidExpression):
     """ What you're trying to do is not allowed. """
+
     pass
 
 
 class NumberTooHigh(InvalidExpression):
     """ Sorry! That number is too high. I don't want to spend the
         next 10 years evaluating this expression! """
+
     pass
 
 
 class IterableTooLong(InvalidExpression):
     """ That iterable is **way** too long, baby. """
+
     pass
 
+class AssignmentAttempted(UserWarning):
+    pass
 
 ########################################
 # Default simple functions to include:
@@ -177,11 +216,13 @@ class IterableTooLong(InvalidExpression):
 
 def random_int(top):
     """ return a random int below <top> """
+
     return int(random() * top)
 
 
 def safe_power(a, b):  # pylint: disable=invalid-name
     """ a limited exponent/to-the-power-of function, for safety reasons """
+
     if abs(a) > MAX_POWER or abs(b) > MAX_POWER:
         raise NumberTooHigh("Sorry! I don't want to evaluate {0} ** {1}"
                             .format(a, b))
@@ -191,9 +232,9 @@ def safe_power(a, b):  # pylint: disable=invalid-name
 def safe_mult(a, b):  # pylint: disable=invalid-name
     """ limit the number of times an iterable can be repeated... """
 
-    if hasattr(a, '__len__') and b*len(a) > MAX_STRING_LENGTH:
+    if hasattr(a, '__len__') and b * len(a) > MAX_STRING_LENGTH:
         raise IterableTooLong('Sorry, I will not evalute something that long.')
-    if hasattr(b, '__len__') and a*len(b) > MAX_STRING_LENGTH:
+    if hasattr(b, '__len__') and a * len(b) > MAX_STRING_LENGTH:
         raise IterableTooLong('Sorry, I will not evalute something that long.')
 
     return a * b
@@ -201,6 +242,7 @@ def safe_mult(a, b):  # pylint: disable=invalid-name
 
 def safe_add(a, b):  # pylint: disable=invalid-name
     """ iterable length limit again """
+
     if hasattr(a, '__len__') and hasattr(b, '__len__'):
         if len(a) + len(b) > MAX_STRING_LENGTH:
             raise IterableTooLong("Sorry, adding those two together would"
@@ -229,7 +271,10 @@ DEFAULT_FUNCTIONS = {"rand": random, "randint": random_int,
                      "int": int, "float": float,
                      "str": str if PYTHON3 else unicode}
 
-DEFAULT_NAMES = {"True": True, "False": False}
+DEFAULT_NAMES = {"True": True, "False": False, "None": None}
+
+ATTR_INDEX_FALLBACK = True
+
 
 ########################################
 # And the actual evaluator:
@@ -249,17 +294,21 @@ class SimpleEval(object):  # pylint: disable=too-few-public-methods
             functions (add, random, get_val, whatever) and names. """
 
         if not operators:
-            operators = DEFAULT_OPERATORS
+            operators = DEFAULT_OPERATORS.copy()
         if not functions:
-            functions = DEFAULT_FUNCTIONS
+            functions = DEFAULT_FUNCTIONS.copy()
         if not names:
-            names = DEFAULT_NAMES
+            names = DEFAULT_NAMES.copy()
 
         self.operators = operators
         self.functions = functions
         self.names = names
 
         self.nodes = {
+            ast.Expr: self._eval_expr,
+            ast.Assign: self._eval_assign,
+            ast.AugAssign: self._eval_aug_assign,
+            ast.Import: self._eval_import,
             ast.Num: self._eval_num,
             ast.Str: self._eval_str,
             ast.Name: self._eval_name,
@@ -278,9 +327,27 @@ class SimpleEval(object):  # pylint: disable=too-few-public-methods
 
         # py3k stuff:
         if hasattr(ast, 'NameConstant'):
-            self.nodes[ast.NameConstant] = self._eval_nameconstant
-        elif isinstance(self.names, dict) and "None" not in self.names:
-            self.names["None"] = None
+            self.nodes[ast.NameConstant] = self._eval_constant
+
+        # py3.6, f-strings
+        if hasattr(ast, 'JoinedStr'):
+            self.nodes[ast.JoinedStr] = self._eval_joinedstr  # f-string
+            self.nodes[ast.FormattedValue] = self._eval_formattedvalue  # formatted value in f-string
+
+        # py3.8 uses ast.Constant instead of ast.Num, ast.Str, ast.NameConstant
+        if hasattr(ast, 'Constant'):
+            self.nodes[ast.Constant] = self._eval_constant
+
+        # Defaults:
+
+        self.ATTR_INDEX_FALLBACK = ATTR_INDEX_FALLBACK
+
+        # Check for forbidden functions:
+
+        for f in self.functions.values():
+            if f in DISALLOW_FUNCTIONS:
+                raise FeatureNotAvailable('This function {} is a really bad idea.'.format(f))
+
 
     def eval(self, expr):
         """ evaluate an expresssion, using the operators, functions and
@@ -291,7 +358,7 @@ class SimpleEval(object):  # pylint: disable=too-few-public-methods
         self.expr = expr
 
         # and evaluate:
-        return self._eval(ast.parse(expr.strip()).body[0].value)
+        return self._eval(ast.parse(expr.strip()).body[0])
 
     def _eval(self, node):
         """ The internal evaluator used on each node in the parsed tree. """
@@ -304,6 +371,21 @@ class SimpleEval(object):  # pylint: disable=too-few-public-methods
 
         return handler(node)
 
+    def _eval_expr(self, node):
+        return self._eval(node.value)
+
+    def _eval_assign(self, node):
+        warnings.warn("Assignment ({}) attempted, but this is ignored".format(self.expr), AssignmentAttempted)
+        return self._eval(node.value)
+
+    def _eval_aug_assign(self, node):
+        warnings.warn("Assignment ({}) attempted, but this is ignored".format(self.expr), AssignmentAttempted)
+        return self._eval(node.value)
+
+    def _eval_import(self, node):
+        raise FeatureNotAvailable("Sorry, 'import' is not allowed.")
+        return self._eval(node.value)
+
     @staticmethod
     def _eval_num(node):
         return node.n
@@ -317,7 +399,10 @@ class SimpleEval(object):  # pylint: disable=too-few-public-methods
         return node.s
 
     @staticmethod
-    def _eval_nameconstant(node):
+    def _eval_constant(node):
+        if hasattr(node.value, '__len__') and len(node.value) > MAX_STRING_LENGTH:
+            raise IterableTooLong("Literal in statement is too long!"
+                                  " ({0}, when {1} is max)".format(len(node.value), MAX_STRING_LENGTH))
         return node.value
 
     def _eval_unaryop(self, node):
@@ -333,24 +418,25 @@ class SimpleEval(object):  # pylint: disable=too-few-public-methods
             for value in node.values:
                 vout = self._eval(value)
                 if not vout:
-                    return False
+                    return vout
             return vout
         elif isinstance(node.op, ast.Or):
             for value in node.values:
                 vout = self._eval(value)
                 if vout:
                     return vout
-            return False
+            return vout
 
     def _eval_compare(self, node):
-        left = self._eval(node.left)
+        right = self._eval(node.left)
+        to_return = True
         for operation, comp in zip(node.ops, node.comparators):
+            if not to_return:
+                break
+            left = right
             right = self._eval(comp)
-            if self.operators[type(operation)](left, right):
-                left = right  # Hi Dr. Seuss...
-            else:
-                return False
-        return True
+            to_return = self.operators[type(operation)](left, right)
+        return to_return
 
     def _eval_ifexp(self, node):
         return self._eval(node.body) if self._eval(node.test) \
@@ -364,6 +450,11 @@ class SimpleEval(object):  # pylint: disable=too-few-public-methods
                 func = self.functions[node.func.id]
             except KeyError:
                 raise FunctionNotDefined(node.func.id, self.expr)
+            except AttributeError as e:
+                raise FeatureNotAvailable('Lambda Functions not implemented')
+
+            if func in DISALLOW_FUNCTIONS:
+                raise FeatureNotAvailable('This function is forbidden')
 
         return func(
             *(self._eval(a) for a in node.args),
@@ -380,7 +471,7 @@ class SimpleEval(object):  # pylint: disable=too-few-public-methods
             # that there is a true exression assigning to none
             # (the compiler rejects it, so you can't even
             # pass that to ast.parse)
-            if isinstance(self.names, dict):
+            if hasattr(self.names, '__getitem__'):
                 return self.names[node.id]
             elif callable(self.names):
                 return self.names(node)
@@ -396,7 +487,6 @@ class SimpleEval(object):  # pylint: disable=too-few-public-methods
             raise NameNotDefined(node.id, self.expr)
 
     def _eval_subscript(self, node):
-
         container = self._eval(node.value)
         key = self._eval(node.slice)
         try:
@@ -413,20 +503,24 @@ class SimpleEval(object):  # pylint: disable=too-few-public-methods
                     "({0})".format(node.attr))
         if node.attr in DISALLOW_METHODS:
             raise FeatureNotAvailable(
-                    "Sorry, this method is not available. "
-                    "({0})".format(node.attr))
-
-        try:
-            return self._eval(node.value)[node.attr]
-        except (KeyError, TypeError):
-            pass
+                "Sorry, this method is not available. "
+                "({0})".format(node.attr))
+        # eval node
+        node_evaluated = self._eval(node.value)
 
         # Maybe the base object is an actual object, not just a dict
         try:
-            return getattr(self._eval(node.value), node.attr)
+            return getattr(node_evaluated, node.attr)
         except (AttributeError, TypeError):
             pass
 
+        # TODO: is this a good idea?  Try and look for [x] if .x doesn't work?
+        if self.ATTR_INDEX_FALLBACK:
+            try:
+                return node_evaluated[node.attr]
+            except (KeyError, TypeError):
+                pass
+
         # If it is neither, raise an exception
         raise AttributeDoesNotExist(node.attr, self.expr)
 
@@ -443,6 +537,22 @@ class SimpleEval(object):  # pylint: disable=too-few-public-methods
             step = self._eval(node.step)
         return slice(lower, upper, step)
 
+    def _eval_joinedstr(self, node):
+        length = 0
+        evaluated_values = []
+        for n in node.values:
+            val = str(self._eval(n))
+            if len(val) + length > MAX_STRING_LENGTH:
+                raise IterableTooLong("Sorry, I will not evaluate something this long.")
+            evaluated_values.append(val)
+        return ''.join(evaluated_values)
+
+    def _eval_formattedvalue(self, node):
+        if node.format_spec:
+            fmt = "{:" + self._eval(node.format_spec) + "}"
+            return fmt.format(self._eval(node.value))
+        return self._eval(node.value)
+
 
 class EvalWithCompoundTypes(SimpleEval):
     """
@@ -463,9 +573,15 @@ class EvalWithCompoundTypes(SimpleEval):
             ast.Dict: self._eval_dict,
             ast.Tuple: self._eval_tuple,
             ast.List: self._eval_list,
-            ast.Set: self._eval_set
+            ast.Set: self._eval_set,
+            ast.ListComp: self._eval_comprehension,
+            ast.GeneratorExp: self._eval_comprehension,
         })
 
+    def eval(self, expr):
+        self._max_count = 0
+        return super(EvalWithCompoundTypes, self).eval(expr)
+
     def _eval_dict(self, node):
         return {self._eval(k): self._eval(v)
                 for (k, v) in zip(node.keys, node.values)}
@@ -479,6 +595,55 @@ class EvalWithCompoundTypes(SimpleEval):
     def _eval_set(self, node):
         return set(self._eval(x) for x in node.elts)
 
+    def _eval_comprehension(self, node):
+        to_return = []
+
+        extra_names = {}
+
+        previous_name_evaller = self.nodes[ast.Name]
+
+        def eval_names_extra(node):
+            """
+                Here we hide our extra scope for within this comprehension
+            """
+            if node.id in extra_names:
+                return extra_names[node.id]
+            return previous_name_evaller(node)
+
+        self.nodes.update({ast.Name: eval_names_extra})
+
+        def recurse_targets(target, value):
+            """
+                Recursively (enter, (into, (nested, name), unpacking)) = \
+                             and, (assign, (values, to), each
+            """
+            if isinstance(target, ast.Name):
+                extra_names[target.id] = value
+            else:
+                for t, v in zip(target.elts, value):
+                    recurse_targets(t, v)
+
+        def do_generator(gi=0):
+            g = node.generators[gi]
+            for i in self._eval(g.iter):
+                self._max_count += 1
+
+                if self._max_count > MAX_COMPREHENSION_LENGTH:
+                    raise IterableTooLong('Comprehension generates too many elements')
+                recurse_targets(g.target, i)
+                if all(self._eval(iff) for iff in g.ifs):
+                    if len(node.generators) > gi + 1:
+                        do_generator(gi+1)
+                    else:
+                        to_return.append(self._eval(node.elt))
+
+        try:
+            do_generator()
+        finally:
+            self.nodes.update({ast.Name: previous_name_evaller})
+
+        return to_return
+
 
 def simple_eval(expr, operators=None, functions=None, names=None):
     """ Simply evaluate an expresssion """
