@@ -21,7 +21,7 @@
 !     Z =  Boltzmann statistical sum, real scalar
 !----------------------------------------------------------------------
       Implicit None
-      Integer, parameter          :: wp=SELECTED_REAL_KIND(p=15,r=307)
+      Integer, parameter          :: wp=kind(0.d0)
       Integer, intent(in)         :: N
       Real(kind=8),intent(in)    :: E(N), T
       Complex(kind=8),intent(in) :: M(N,N)
