@@ -17,7 +17,7 @@ C
 
       Implicit None
 #include "stdalloc.fh"
-      Integer, parameter        :: wp=SELECTED_REAL_KIND(p=15,r=307)
+      Integer, parameter        :: wp=kind(0.d0)
       Integer, intent(in)       :: N
       Integer, intent(out)      :: INFO
       Real(kind=8), intent(in) :: MATRIX(N,N)
