@@ -45,7 +45,7 @@ c     l -- labels the cartesian component of the momentum (convention: x=1, y=2,
 c    iT -- labes the temperature points;
       Implicit None
 #include "stdalloc.fh"
-      Integer, parameter           :: wp=SELECTED_REAL_KIND(p=15,r=307)
+      Integer, parameter        :: wp=kind(0.d0)
       Integer, intent(in)          :: EXCH, N, nT
       Real(kind=8), intent(in)    :: X, Y, Z, H
       Real(kind=8), intent(in)    :: W(EXCH), T(nT)
@@ -56,7 +56,7 @@ c    iT -- labes the temperature points;
       Logical, intent(in)          :: sopt
 c local variables:
       Integer          :: i, l, iT
-      Real(kind=8)    :: kB, mB, zJ
+      Real(kind=8)    :: zJ
       Real(kind=8), allocatable :: WM(:), ST(:), RWORK(:)
 !                                   WM(EXCH), ST(3)
       Complex(kind=8), allocatable :: HZEE(:), WORK(:), W_c(:)
@@ -64,8 +64,6 @@ c local variables:
       Complex(kind=8), allocatable :: SZ(:,:,:), MZ(:,:,:)
 !                                      SZ(3,EXCH,EXCH), MZ(3,EXCH,EXCH)
       Logical          :: DBG
-      kB=0.6950356000_wp   ! Boltzmann constant,  in cm^-1*K-1
-      mB=0.4668643740_wp   ! Bohr magneton,       in cm-1*T-1
 
 c a few checks, before proceeding:
       Do iT=1,nT
