@@ -10,9 +10,9 @@
 ************************************************************************
 #ifdef _HDF5_
       SUBROUTINE read_hdf5_init(file_h5,nstate,nss)
+      Use mh5, Only: mh5_open_file_r, mh5_fetch_attr, mh5_close_file
       Implicit None
 #include "stdalloc.fh"
-#include "mh5.fh"
       Character(Len=180),intent(in) ::    file_h5
       Integer, intent(out)      ::    nstate,nss
       ! local variables:
@@ -103,10 +103,11 @@
      &                         multiplicity, eso, esfs,
      &                         U, MM, MS, ML, DM, ANGMOM, EDMOM,
      &                         amfi, HSO )
+      Use mh5, Only: mh5_open_file_r, mh5_fetch_attr, mh5_exists_dset,
+     &               mh5_fetch_dset, mh5_close_file
       Implicit None
-      Integer, Parameter            :: wp=selected_real_kind(p=15,r=307)
+      Integer, parameter        :: wp=kind(0.d0)
 #include "stdalloc.fh"
-#include "mh5.fh"
       Integer, intent(in)           :: nstate,nss
       Integer, intent(out)          :: multiplicity(nstate)
 
@@ -140,21 +141,21 @@
       Complex(kind=8), allocatable    :: tmp(:,:)
 
 !      Logical :: Exist
-      Logical :: found_edmom, found_angmom, found_hso, found_amfi,
-     &           found_sos_coeff, found_eso, found_esfs, found_mult
+      Logical :: found_edmom !, found_angmom, found_hso, found_amfi,
+!     &           found_sos_coeff, found_eso, found_esfs, found_mult
       Logical :: DBG
 
       DBG  =.false.
       AU2CM=219474.6313702_wp
       g_e=2.00231930437180_wp
       found_edmom=.false.
-      found_angmom=.false.
-      found_hso=.false.
-      found_amfi=.false.
-      found_sos_coeff=.false.
-      found_eso=.false.
-      found_esfs=.false.
-      found_mult=.false.
+!      found_angmom=.false.
+!      found_hso=.false.
+!      found_amfi=.false.
+!      found_sos_coeff=.false.
+!      found_eso=.false.
+!      found_esfs=.false.
+!      found_mult=.false.
 
       WRITE (6,'(A,A)') 'Read data from rassi.h5 file ',trim(file_h5)
 
@@ -168,7 +169,7 @@
 !----------------------------------------------------------------------|
       ! read spin multiplicity of each state:
 c      IF (mh5_exists_dset(fileid,'STATE_SPINMULT')) THEN
-         found_mult=.true.
+!         found_mult=.true.
          Call mh5_fetch_attr(fileid,'STATE_SPINMULT',
      &                       multiplicity(1:nstate))
          IF (DBG) WRITE (6,'(A)') 'read_hdf5_all:: multiplicity'
@@ -190,8 +191,8 @@ c      END IF
       Call mma_allocate(etmp,nstate,'etmp)')
       Call dcopy_(nstate,[0.0_wp],0,etmp,1)
       IF (mh5_exists_dset(fileid,'SFS_ENERGIES')) THEN
-         found_esfs=.true.
-         Call mh5_fetch_dset_array_real(fileid,'SFS_ENERGIES',etmp)
+!         found_esfs=.true.
+         Call mh5_fetch_dset(fileid,'SFS_ENERGIES',etmp)
          RNRM=0.0_wp
          RNRM=dnrm2_(nstate,etmp,1)
          IF ( RNRM.lt.1.0D-50 ) THEN
@@ -222,8 +223,8 @@ c      END IF
       Call mma_allocate(etmp,nss,'tmp)')
       Call dcopy_(nss,[0.0_wp],0,etmp,1)
       IF (mh5_exists_dset(fileid,'SOS_ENERGIES')) THEN
-         found_eso=.true.
-         Call mh5_fetch_dset_array_real(fileid,'SOS_ENERGIES',etmp)
+!         found_eso=.true.
+         Call mh5_fetch_dset(fileid,'SOS_ENERGIES',etmp)
          RNRM=0.0_wp
          RNRM=dnrm2_(nss,etmp,1)
          IF ( RNRM.lt.1.0D-50 ) THEN
@@ -258,11 +259,9 @@ c      END IF
 
       IF ( mh5_exists_dset(fileid,'SOS_COEFFICIENTS_REAL').and.
      &     mh5_exists_dset(fileid,'SOS_COEFFICIENTS_IMAG') ) THEN
-         found_sos_coeff=.true.
-         Call mh5_fetch_dset_array_real(fileid,'SOS_COEFFICIENTS_REAL',
-     &                                          RR )
-         Call mh5_fetch_dset_array_real(fileid,'SOS_COEFFICIENTS_IMAG',
-     &                                          RI )
+!         found_sos_coeff=.true.
+         Call mh5_fetch_dset(fileid,'SOS_COEFFICIENTS_REAL', RR )
+         Call mh5_fetch_dset(fileid,'SOS_COEFFICIENTS_IMAG', RI )
          ! assemble the complex matrix U:
          DO i=1,nss
             DO j=1,nss
@@ -297,8 +296,8 @@ c      END IF
       Call mma_allocate(AL,nstate,nstate,3,'AL')
       Call dcopy_(nstate*nstate*3,[0.0_wp],0,AL,1)
       IF (mh5_exists_dset(fileid,'SFS_ANGMOM')) THEN
-         found_angmom=.true.
-         Call mh5_fetch_dset_array_real(fileid,'SFS_ANGMOM',AL)
+!         found_angmom=.true.
+         Call mh5_fetch_dset(fileid,'SFS_ANGMOM',AL)
          DO i=1,nstate
             DO j=1,nstate
                DO l=1,3
@@ -335,7 +334,7 @@ c      END IF
       Call dcopy_(nstate*nstate*3,[0.0_wp],0,AL,1)
       IF (mh5_exists_dset(fileid,'SFS_EDIPMOM')) THEN
          found_edmom=.true.
-         Call mh5_fetch_dset_array_real(fileid,'SFS_EDIPMOM',AL)
+         Call mh5_fetch_dset(fileid,'SFS_EDIPMOM',AL)
          DO i=1,nstate
             DO j=1,nstate
                DO l=1,3
@@ -371,8 +370,8 @@ c      END IF
       Call mma_allocate(AL,nstate,nstate,3,'AL')
       Call dcopy_(nstate*nstate*3,[0.0_wp],0,AL,1)
       IF (mh5_exists_dset(fileid,'SFS_AMFIINT')) THEN
-         found_amfi=.true.
-         Call mh5_fetch_dset_array_real(fileid,'SFS_AMFIINT',AL)
+!         found_amfi=.true.
+         Call mh5_fetch_dset(fileid,'SFS_AMFIINT',AL)
          DO i=1,nstate
             DO j=1,nstate
                DO l=1,3
@@ -415,9 +414,9 @@ c      END IF
 
       IF ( mh5_exists_dset(fileid,'HSO_MATRIX_REAL').and.
      &     mh5_exists_dset(fileid,'HSO_MATRIX_IMAG') ) THEN
-         found_hso=.true.
-         Call mh5_fetch_dset_array_real(fileid,'HSO_MATRIX_REAL',RR )
-         Call mh5_fetch_dset_array_real(fileid,'HSO_MATRIX_IMAG',RI )
+!         found_hso=.true.
+         Call mh5_fetch_dset(fileid,'HSO_MATRIX_REAL',RR )
+         Call mh5_fetch_dset(fileid,'HSO_MATRIX_IMAG',RI )
          ! assemble the complex matrix U:
          DO i=1,nss
             DO j=1,nss
@@ -579,10 +578,11 @@ c----- expand the spin free basis to the spin-orbit basis:
 
       SUBROUTINE read_hdf5_poly( file_h5, nss, nstate,
      &                           eso, MM, MS,iReturn )
+      Use mh5, Only: mh5_open_file_r, mh5_fetch_attr, mh5_exists_dset,
+     &               mh5_fetch_dset, mh5_close_file
       Implicit None
-      Integer, Parameter            :: wp=selected_real_kind(p=15,r=307)
+      Integer, parameter        :: wp=kind(0.d0)
 #include "stdalloc.fh"
-#include "mh5.fh"
       Integer, intent(in)           :: nstate,nss
       Integer                       :: multiplicity(nstate)
       Integer                       :: iReturn
@@ -617,21 +617,21 @@ c----- expand the spin free basis to the spin-orbit basis:
       Complex(kind=8), allocatable    :: tmp(:,:)
 
 !      Logical :: Exist
-      Logical :: found_edmom, found_angmom, found_hso, found_amfi,
-     &           found_sos_coeff, found_eso, found_esfs, found_mult
+!      Logical :: found_edmom, found_angmom, found_hso, found_amfi,
+!     &           found_sos_coeff, found_eso, found_esfs, found_mult
       Logical :: DBG
 
       DBG  =.false.
       AU2CM=219474.6313702_wp
       g_e=2.00231930437180_wp
-      found_edmom=.false.
-      found_angmom=.false.
-      found_hso=.false.
-      found_amfi=.false.
-      found_sos_coeff=.false.
-      found_eso=.false.
-      found_esfs=.false.
-      found_mult=.false.
+!      found_edmom=.false.
+!      found_angmom=.false.
+!      found_hso=.false.
+!      found_amfi=.false.
+!      found_sos_coeff=.false.
+!      found_eso=.false.
+!      found_esfs=.false.
+!      found_mult=.false.
       iReturn=0
 
       WRITE (6,'(A,A)') 'Read data from rassi.h5 file ',trim(file_h5)
@@ -646,7 +646,7 @@ c----- expand the spin free basis to the spin-orbit basis:
 !----------------------------------------------------------------------|
       ! read spin multiplicity of each state:
 c      IF (mh5_exists_dset(fileid,'STATE_SPINMULT')) THEN
-         found_mult=.true.
+!         found_mult=.true.
          Call mh5_fetch_attr(fileid,'STATE_SPINMULT',
      &                       multiplicity(1:nstate))
          IF (DBG) WRITE (6,'(A)') 'read_hdf5_all:: multiplicity'
@@ -669,7 +669,7 @@ c      END IF
 !      Call dcopy_(nstate,[0.0_wp],0,etmp,1)
 !      IF (mh5_exists_dset(fileid,'SFS_ENERGIES')) THEN
 !         found_esfs=.true.
-!         Call mh5_fetch_dset_array_real(fileid,'SFS_ENERGIES',etmp)
+!         Call mh5_fetch_dset(fileid,'SFS_ENERGIES',etmp)
 !         RNRM=0.0_wp
 !         RNRM=dnrm2_(nstate,etmp,1)
 !         IF ( RNRM.lt.1.0D-50 ) THEN
@@ -700,8 +700,8 @@ c      END IF
       Call mma_allocate(etmp,nss,'tmp)')
       Call dcopy_(nss,[0.0_wp],0,etmp,1)
       IF (mh5_exists_dset(fileid,'SOS_ENERGIES')) THEN
-         found_eso=.true.
-         Call mh5_fetch_dset_array_real(fileid,'SOS_ENERGIES',etmp)
+!         found_eso=.true.
+         Call mh5_fetch_dset(fileid,'SOS_ENERGIES',etmp)
          RNRM=0.0_wp
          RNRM=dnrm2_(nss,etmp,1)
          IF ( RNRM.lt.1.0D-50 ) THEN
@@ -738,11 +738,9 @@ c      END IF
 
       IF ( mh5_exists_dset(fileid,'SOS_COEFFICIENTS_REAL').and.
      &     mh5_exists_dset(fileid,'SOS_COEFFICIENTS_IMAG') ) THEN
-         found_sos_coeff=.true.
-         Call mh5_fetch_dset_array_real(fileid,'SOS_COEFFICIENTS_REAL',
-     &                                          RR )
-         Call mh5_fetch_dset_array_real(fileid,'SOS_COEFFICIENTS_IMAG',
-     &                                          RI )
+!         found_sos_coeff=.true.
+         Call mh5_fetch_dset(fileid,'SOS_COEFFICIENTS_REAL', RR )
+         Call mh5_fetch_dset(fileid,'SOS_COEFFICIENTS_IMAG', RI )
          ! assemble the complex matrix U:
          DO i=1,nss
             DO j=1,nss
@@ -777,8 +775,8 @@ c      END IF
       Call mma_allocate(AL,nstate,nstate,3,'AL')
       Call dcopy_(nstate*nstate*3,[0.0_wp],0,AL,1)
       IF (mh5_exists_dset(fileid,'SFS_ANGMOM')) THEN
-         found_angmom=.true.
-         Call mh5_fetch_dset_array_real(fileid,'SFS_ANGMOM',AL)
+!         found_angmom=.true.
+         Call mh5_fetch_dset(fileid,'SFS_ANGMOM',AL)
          DO i=1,nstate
             DO j=1,nstate
                DO l=1,3
@@ -817,7 +815,7 @@ c      END IF
 !      Call dcopy_(nstate*nstate*3,[0.0_wp],0,AL,1)
 !      IF (mh5_exists_dset(fileid,'SFS_EDIPMOM')) THEN
 !         found_edmom=.true.
-!         Call mh5_fetch_dset_array_real(fileid,'SFS_EDIPMOM',AL)
+!         Call mh5_fetch_dset(fileid,'SFS_EDIPMOM',AL)
 !         DO i=1,nstate
 !            DO j=1,nstate
 !               DO l=1,3
@@ -854,7 +852,7 @@ c      END IF
 !      Call dcopy_(nstate*nstate*3,[0.0_wp],0,AL,1)
 !      IF (mh5_exists_dset(fileid,'SFS_AMFIINT')) THEN
 !         found_amfi=.true.
-!         Call mh5_fetch_dset_array_real(fileid,'SFS_AMFIINT',AL)
+!         Call mh5_fetch_dset(fileid,'SFS_AMFIINT',AL)
 !         DO i=1,nstate
 !            DO j=1,nstate
 !               DO l=1,3
@@ -898,8 +896,8 @@ c      END IF
 !      IF ( mh5_exists_dset(fileid,'HSO_MATRIX_REAL').and.
 !     &     mh5_exists_dset(fileid,'HSO_MATRIX_IMAG') ) THEN
 !         found_hso=.true.
-!         Call mh5_fetch_dset_array_real(fileid,'HSO_MATRIX_REAL',RR )
-!         Call mh5_fetch_dset_array_real(fileid,'HSO_MATRIX_IMAG',RI )
+!         Call mh5_fetch_dset(fileid,'HSO_MATRIX_REAL',RR )
+!         Call mh5_fetch_dset(fileid,'HSO_MATRIX_IMAG',RI )
 !         ! assemble the complex matrix U:
 !         DO i=1,nss
 !            DO j=1,nss
