@@ -21,7 +21,7 @@
 
       Implicit None
 
-      Integer, parameter         :: wp=SELECTED_REAL_KIND(p=15,r=307)
+      Integer, parameter        :: wp=kind(0.d0)
       Integer, intent(in)        :: ln
       Real(kind=8), intent(out) :: a(6)
       ! local variables:
