@@ -13,7 +13,7 @@
      &                  T, XTexp )
 
       Implicit None
-      Integer, parameter        :: wp=SELECTED_REAL_KIND(p=15,r=307)
+      Integer, parameter        :: wp=kind(0.d0)
 c input:
       Integer, intent(in)       :: nT, nTempMagn
       Logical, intent(in)       :: TINPUT
