@@ -12,7 +12,7 @@
      &                DBG, RWORK, HZEE, WORK, W_c )
 c
       Implicit None
-      Integer, parameter       :: wp=SELECTED_REAL_KIND(p=15,r=307)
+      Integer, parameter        :: wp=kind(0.d0)
 c input variables:
       Integer,         intent(in) :: N
       Real(kind=8),   intent(in) :: H,dX,dY,dZ,zJ
