@@ -42,7 +42,7 @@ C> full permutational symmetry (see ::mksmat and ::mkbmat). The
 C> same storage applies to the \f$ F \f$ matrices.
 C>
 C> @param[in]  IFF   switch to activate computation of \f$ F \f$ matrices
-C> @param[in]  CI    wave function CI coefficients, with symmetry \c LSYM
+C> @param[in]  CI    wave function CI coefficients, with symmetry \c STSYM
 C> @param[out] G1    1-body active density matrix
 C> @param[out] G2    2-body active density matrix
 C> @param[out] G3    process-local part of 3-body active density matrix
@@ -56,15 +56,17 @@ C> @param[out] idxG3 table to translate from process-local array index
 C>                   to active indices
 
       SUBROUTINE MKFG3(IFF,CI,G1,F1,G2,F2,G3,F3,idxG3)
+      use output_caspt2, only:iPrGlb,verbose,debug
+#if defined (_MOLCAS_MPP_) && !defined (_GA_)
+      USE Para_Info, ONLY: nProcs, Is_Real_Par, King
+#endif
       IMPLICIT NONE
 #include "rasdim.fh"
 #include "caspt2.fh"
-#include "output.fh"
 #include "SysDef.fh"
 #include "WrkSpc.fh"
 #include "pt2_guga.fh"
 
-#include "para_info.fh"
       LOGICAL RSV_TSK
 
       INTEGER, INTENT(IN) :: IFF
@@ -96,7 +98,7 @@ C>                   to active indices
       INTEGER L1,LTO,LFROM
       INTEGER MEMMAX, MEMMAX_SAFE
       INTEGER NLEV2
-      INTEGER LDUM,NDUM
+      INTEGER LDUM
       INTEGER NCI,ICSF
 
       REAL*8, EXTERNAL :: DDOT_,DNRM2_
@@ -126,7 +128,7 @@ C Put in zeroes. Recognize special cases:
 
       IF(NACTEL.EQ.0) GOTO 999
 
-      NCI=NCSF(LSYM)
+      NCI=NCSF(STSYM)
 * This should not happen, but...
       IF(NCI.EQ.0) GOTO 999
 
@@ -164,7 +166,6 @@ C Special pair index idx2ij allows true RAS cases to be handled:
 
 * Dummy values necessary for fooling syntax checkers:
       ldum=1
-      ndum=1
       call getmem('memmx','max','real',ldum,memmax)
 
 * Use *almost* all remaining memory:
@@ -208,7 +209,7 @@ C-SVC20100301: calculate maximum number of tasks possible
 * A *very* long loop over the symmetry of Sgm1 = E_ut Psi as segmentation.
 * This also allows precomputing the Hamiltonian (H0) diagonal elements.
       DO issg1=1,nsym
-       isp1=mul(issg1,lsym)
+       isp1=mul(issg1,stsym)
        nsgm1=ncsf(issg1)
        CALL H0DIAG_CASPT2(ISSG1,WORK(LBUFD),IWORK(LNOW),IWORK(LIOW))
 
@@ -329,7 +330,7 @@ C-sigma vectors in the buffer.
           ip1_buf(ibuf1)=ip1i
           lto=lbuf1+mxci*(ibuf1-1)
           call dcopy_(nsgm1,[0.0D0],0,work(lto),1)
-          CALL SIGMA1_CP2(IULEV,ITLEV,1.0D00,LSYM,CI,WORK(LTO),
+          CALL SIGMA1_CP2(IULEV,ITLEV,1.0D00,STSYM,CI,WORK(LTO),
      &     IWORK(LNOCSF),IWORK(LIOCSF),IWORK(LNOW),IWORK(LIOW),
      &     IWORK(LNOCP),IWORK(LIOCP),IWORK(LICOUP),
      &     WORK(LVTAB),IWORK(LMVL),IWORK(LMVR))
@@ -344,7 +345,7 @@ C-SVC20100301: necessary batch of sigma vectors is now in the buffer
       ! The ip1 buffer could be the same on different processes
       ! so only compute the G1 contribution when ip3 is 1, as
       ! this will only be one task per buffer.
-      if (issg1.eq.lsym.AND.ip3.eq.1) then
+      if (issg1.eq.stsym.AND.ip3.eq.1) then
         do ib=1,ibuf1
           idx=ip1_buf(ib)
           itlev=idx2ij(1,idx)
@@ -382,13 +383,13 @@ C-SVC20100309: use simpler procedure by keeping inner ip2-loop intact
       iylev=idx2ij(1,ip3)
       izlev=idx2ij(2,ip3)
       isyz=mul(ism(iylev),ism(izlev))
-      issg2=mul(isyz,lsym)
+      issg2=mul(isyz,stsym)
       nsgm2=ncsf(issg2)
       iy=L2ACT(iylev)
       iz=L2ACT(izlev)
       lto=lbuf2
       call dcopy_(nsgm2,[0.0D0],0,work(lto),1)
-      CALL SIGMA1_CP2(IYLEV,IZLEV,1.0D00,LSYM,CI,WORK(LTO),
+      CALL SIGMA1_CP2(IYLEV,IZLEV,1.0D00,STSYM,CI,WORK(LTO),
      &     IWORK(LNOCSF),IWORK(LIOCSF),IWORK(LNOW),IWORK(LIOW),
      &     IWORK(LNOCP),IWORK(LIOCP),IWORK(LICOUP),
      &     WORK(LVTAB),IWORK(LMVL),IWORK(LMVR))
