@@ -54,7 +54,7 @@ C For correct ordering, change sign.
             LIJ=LIJ+1
            END DO
           END DO
-          CALL NIDiag(WORK(LTMP),CNAT(ICMO+1),NA,NB,0)
+          CALL NIDiag(WORK(LTMP),CNAT(ICMO+1),NA,NB)
           CALL JACORD(WORK(LTMP),CNAT(ICMO+1),NA,NB)
           CALL VEIG(NA,WORK(LTMP),OCC(IOCC+1))
           CALL GETMEM('TMP','FREE','REAL',LTMP,NTMP)
