@@ -10,6 +10,7 @@
 ************************************************************************
       SUBROUTINE RHSALL2(IVEC)
       USE CHOVEC_IO
+      use output_caspt2, only:iPrGlb,verbose
       IMPLICIT REAL*8 (A-H,O-Z)
 * ----------------------------------------------------------------
 * Code for processing all the cholesky vectors
@@ -17,9 +18,8 @@
 * Also form the active two-electron integrals 'TUVX'.
 * ================================================================
 #include "rasdim.fh"
-#include "warnings.fh"
+#include "warnings.h"
 #include "caspt2.fh"
-#include "output.fh"
 #include "eqsolv.fh"
 #include "chocaspt2.fh"
 #include "WrkSpc.fh"
@@ -464,10 +464,10 @@ C      the case, symmetry, and rhs vector respectively.
      &                             BUFF,idxBuff,nBUFF,
      &                             nSh,JSYM,
      &                             IVEC,NV)
+      use output_caspt2, only:iPrGlb,debug
       IMPLICIT REAL*8 (A-H,O-Z)
 #include "rasdim.fh"
 #include "caspt2.fh"
-#include "output.fh"
 #include "WrkSpc.fh"
       DIMENSION Cho_Bra(nBra), Cho_Ket(nKet)
       DIMENSION BUFF(nBuff),idxBuff(nBuff),PIQK(mxPIQK)
@@ -648,10 +648,10 @@ C-SVC: sanity check
       SUBROUTINE MEMORY_ESTIMATE(JSYM,LBGRP,NBGRP,
      &                           NCHOBUF,NPIQK,NADDBUF)
       USE CHOVEC_IO
+      use output_caspt2, only:iPrGlb,verbose
       IMPLICIT REAL*8 (A-H,O-Z)
 #include "rasdim.fh"
 #include "caspt2.fh"
-#include "output.fh"
 #include "WrkSpc.fh"
       DIMENSION LBGRP(2,NBGRP)
       Integer Active, Inactive, Virtual
