@@ -20,13 +20,15 @@
 
 *||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||*
       SUBROUTINE RHSOD(IVEC)
+      use output_caspt2, only:iPrGlb,verbose
+#ifdef _MOLCAS_MPP_
+      USE Para_Info, ONLY: Is_Real_Par
+#endif
       IMPLICIT REAL*8 (A-H,O-Z)
 #include "rasdim.fh"
 #include "caspt2.fh"
-#include "output.fh"
 #include "WrkSpc.fh"
 #include "eqsolv.fh"
-#include "para_info.fh"
 
 
       IF (IPRGLB.GE.VERBOSE) THEN
@@ -79,10 +81,10 @@
       SUBROUTINE RHSOD_A(IVEC)
       USE SUPERINDEX
       USE CHOVEC_IO
+      use output_caspt2, only:iPrGlb,debug
       IMPLICIT REAL*8 (A-H,O-Z)
 #include "rasdim.fh"
 #include "caspt2.fh"
-#include "output.fh"
 #include "WrkSpc.fh"
 #include "eqsolv.fh"
       DIMENSION IOBRA(8,8), IOKET(8,8)
@@ -90,8 +92,7 @@
 #include "global.fh"
 #include "mafdecls.fh"
 #else
-      REAL*8 DBL_MB(1:IWORKLEN)
-      EQUIVALENCE (DBL_MB,WORK)
+#define DBL_MB Work
 #endif
 
       IF (iPrGlb.GE.DEBUG) THEN
@@ -103,10 +104,6 @@
 C   RHS(tvx,j)=(tj,vx)+FIMO(t,j)*kron(v,x)/NACTEL
 ************************************************************************
 
-      SQRT2=SQRT(2.0D0)
-      SQRT3=SQRT(3.0D0)
-      SQRTH=1/SQRT2
-
 ************************************************************************
 CSVC: read in all the cholesky vectors (need all symmetries)
 ************************************************************************
@@ -134,7 +131,6 @@ CSVC: read in all the cholesky vectors (need all symmetries)
 
         CALL RHS_ALLO (NAS,NIS,lg_W)
         CALL RHS_ACCESS (NAS,NIS,lg_W,IASTA,IAEND,IISTA,IIEND,MW)
-        NA=NAS*(IIEND-IISTA+1)
 
 ************************************************************************
 * inner loop over RHS elements in symmetry ISYM
@@ -194,10 +190,10 @@ CSVC: read in all the cholesky vectors (need all symmetries)
       SUBROUTINE RHSOD_C(IVEC)
       USE SUPERINDEX
       USE CHOVEC_IO
+      use output_caspt2, only:iPrGlb,debug
       IMPLICIT REAL*8 (A-H,O-Z)
 #include "rasdim.fh"
 #include "caspt2.fh"
-#include "output.fh"
 #include "WrkSpc.fh"
 #include "eqsolv.fh"
       DIMENSION IOBRA(8,8), IOKET(8,8)
@@ -205,8 +201,7 @@ CSVC: read in all the cholesky vectors (need all symmetries)
 #include "global.fh"
 #include "mafdecls.fh"
 #else
-      REAL*8 DBL_MB(1:IWORKLEN)
-      EQUIVALENCE (DBL_MB,WORK)
+#define DBL_MB Work
 #endif
 
       IF (iPrGlb.GE.DEBUG) THEN
@@ -218,10 +213,6 @@ CSVC: read in all the cholesky vectors (need all symmetries)
 C   RHS(tvx,a)=(at,vx)+(FIMO(a,t)-Sum_u(au,ut))*delta(v,x)/NACTEL
 ************************************************************************
 
-      SQRT2=SQRT(2.0D0)
-      SQRT3=SQRT(3.0D0)
-      SQRTH=1/SQRT2
-
 ************************************************************************
 CSVC: read in all the cholesky vectors (need all symmetries)
 ************************************************************************
@@ -249,7 +240,6 @@ CSVC: read in all the cholesky vectors (need all symmetries)
 
         CALL RHS_ALLO (NAS,NIS,lg_W)
         CALL RHS_ACCESS (NAS,NIS,lg_W,IASTA,IAEND,IISTA,IIEND,MW)
-        NA=NAS*(IIEND-IISTA+1)
 
 ************************************************************************
 * inner loop over RHS elements in symmetry ISYM
@@ -322,10 +312,10 @@ CSVC: read in all the cholesky vectors (need all symmetries)
       SUBROUTINE RHSOD_B(IVEC)
       USE SUPERINDEX
       USE CHOVEC_IO
+      use output_caspt2, only:iPrGlb,debug
       IMPLICIT REAL*8 (A-H,O-Z)
 #include "rasdim.fh"
 #include "caspt2.fh"
-#include "output.fh"
 #include "WrkSpc.fh"
 #include "eqsolv.fh"
       DIMENSION IOSYM(8,8)
@@ -334,8 +324,7 @@ CSVC: read in all the cholesky vectors (need all symmetries)
 #include "global.fh"
 #include "mafdecls.fh"
 #else
-      REAL*8 DBL_MB(1:IWORKLEN)
-      EQUIVALENCE (DBL_MB,WORK)
+#define DBL_MB Work
 #endif
 
       IF (iPrGlb.GE.DEBUG) THEN
@@ -349,7 +338,6 @@ C   BP(tv,jl)=((tj,vl)+(tl,vj))*(1-Kron(t,v)/2)/(2*SQRT(1+Kron(j,l))
 C   BM(tv,jl)=((tj,vl)-(tl,vj))*(1-Kron(t,v)/2)/(2*SQRT(1+Kron(j,l))
 ************************************************************************
 
-      SQRT2=SQRT(2.0D0)
       SQRTH=SQRT(0.5D0)
 
 ************************************************************************
@@ -510,10 +498,10 @@ CSVC: read in all the cholesky vectors (need all symmetries)
       SUBROUTINE RHSOD_F(IVEC)
       USE SUPERINDEX
       USE CHOVEC_IO
+      use output_caspt2, only:iPrGlb,debug
       IMPLICIT REAL*8 (A-H,O-Z)
 #include "rasdim.fh"
 #include "caspt2.fh"
-#include "output.fh"
 #include "WrkSpc.fh"
 #include "eqsolv.fh"
       DIMENSION IOSYM(8,8)
@@ -522,8 +510,7 @@ CSVC: read in all the cholesky vectors (need all symmetries)
 #include "global.fh"
 #include "mafdecls.fh"
 #else
-      REAL*8 DBL_MB(1:IWORKLEN)
-      EQUIVALENCE (DBL_MB,WORK)
+#define DBL_MB Work
 #endif
 
       IF (iPrGlb.GE.DEBUG) THEN
@@ -536,7 +523,6 @@ C FP(tv,ac)=((at,cv)+(av,ct))*(1-Kron(t,v)/2)/(2*SQRT(1+Kron(a,c))
 C FM(tv,ac)= -((at,cv)-(av,ct))/(2*SQRT(1+Kron(a,c))
 ************************************************************************
 
-      SQRT2=SQRT(2.0D0)
       SQRTH=SQRT(0.5D0)
 
 ************************************************************************
@@ -697,10 +683,10 @@ CSVC: read in all the cholesky vectors (need all symmetries)
       SUBROUTINE RHSOD_H(IVEC)
       USE SUPERINDEX
       USE CHOVEC_IO
+      use output_caspt2, only:iPrGlb,debug
       IMPLICIT REAL*8 (A-H,O-Z)
 #include "rasdim.fh"
 #include "caspt2.fh"
-#include "output.fh"
 #include "WrkSpc.fh"
 #include "eqsolv.fh"
       DIMENSION IOSYM(8,8)
@@ -709,8 +695,7 @@ CSVC: read in all the cholesky vectors (need all symmetries)
 #include "global.fh"
 #include "mafdecls.fh"
 #else
-      REAL*8 DBL_MB(1:IWORKLEN)
-      EQUIVALENCE (DBL_MB,WORK)
+#define DBL_MB Work
 #endif
 
       IF (iPrGlb.GE.DEBUG) THEN
@@ -723,9 +708,8 @@ C   WP(jl,ac)=((ajcl)+(alcj))/SQRT((1+Kron(jl))*(1+Kron(ac))
 C   WM(jl,ac)=((ajcl)-(alcj))*SQRT(3.0D0)
 ************************************************************************
 
-      SQRT2=SQRT(2.0D0)
       SQRT3=SQRT(3.0D0)
-      SQRTH=1/SQRT2
+      SQRTH=SQRT(0.5D0)
 
 ************************************************************************
 CSVC: read in all the cholesky vectors (need all symmetries)
@@ -884,10 +868,10 @@ CSVC: read in all the cholesky vectors (need all symmetries)
       SUBROUTINE RHSOD_D(IVEC)
       USE SUPERINDEX
       USE CHOVEC_IO
+      use output_caspt2, only:iPrGlb,debug
       IMPLICIT REAL*8 (A-H,O-Z)
 #include "rasdim.fh"
 #include "caspt2.fh"
-#include "output.fh"
 #include "WrkSpc.fh"
 #include "eqsolv.fh"
       DIMENSION IOBRA1(8,8), IOKET1(8,8), IOBRA2(8,8), IOKET2(8,8)
@@ -895,8 +879,7 @@ CSVC: read in all the cholesky vectors (need all symmetries)
 #include "global.fh"
 #include "mafdecls.fh"
 #else
-      REAL*8 DBL_MB(1:IWORKLEN)
-      EQUIVALENCE (DBL_MB,WORK)
+#define DBL_MB Work
 #endif
       DIMENSION NFIMOES(8)
 
@@ -910,9 +893,6 @@ C D1(tv,aj)=(aj,tv) + FIMO(a,j)*Kron(t,v)/NACTEL
 C D2(tv,aj)=(tj,av)
 ************************************************************************
 
-      SQRT2=SQRT(2.0D0)
-      SQRTH=SQRT(0.5D0)
-
 ************************************************************************
 CSVC: read in all the cholesky vectors (need all symmetries)
 ************************************************************************
@@ -1052,10 +1032,10 @@ CSVC: read in all the cholesky vectors (need all symmetries)
       SUBROUTINE RHSOD_E(IVEC)
       USE SUPERINDEX
       USE CHOVEC_IO
+      use output_caspt2, only:iPrGlb,debug
       IMPLICIT REAL*8 (A-H,O-Z)
 #include "rasdim.fh"
 #include "caspt2.fh"
-#include "output.fh"
 #include "WrkSpc.fh"
 #include "eqsolv.fh"
       DIMENSION IOBRA(8,8), IOKET(8,8)
@@ -1064,8 +1044,7 @@ CSVC: read in all the cholesky vectors (need all symmetries)
 #include "global.fh"
 #include "mafdecls.fh"
 #else
-      REAL*8 DBL_MB(1:IWORKLEN)
-      EQUIVALENCE (DBL_MB,WORK)
+#define DBL_MB Work
 #endif
 
       IF (iPrGlb.GE.DEBUG) THEN
@@ -1086,7 +1065,6 @@ C EM(v,ajl)=((aj,vl)-(al,vj))*SQRT(3/2)
 * be determined by integer division. This could be optimized by combining
 * it with loop peeling (on the todo list?).
 
-      SQRT2=SQRT(2.0D0)
       SQRTH=SQRT(0.5D0)
       SQRTA=SQRT(1.5D0)
 
@@ -1271,10 +1249,10 @@ CSVC: read in all the cholesky vectors (need all symmetries)
       SUBROUTINE RHSOD_G(IVEC)
       USE SUPERINDEX
       USE CHOVEC_IO
+      use output_caspt2, only:iPrGlb,debug
       IMPLICIT REAL*8 (A-H,O-Z)
 #include "rasdim.fh"
 #include "caspt2.fh"
-#include "output.fh"
 #include "WrkSpc.fh"
 #include "eqsolv.fh"
       DIMENSION IOBRA(8,8), IOKET(8,8)
@@ -1283,8 +1261,7 @@ CSVC: read in all the cholesky vectors (need all symmetries)
 #include "global.fh"
 #include "mafdecls.fh"
 #else
-      REAL*8 DBL_MB(1:IWORKLEN)
-      EQUIVALENCE (DBL_MB,WORK)
+#define DBL_MB Work
 #endif
 
       IF (iPrGlb.GE.DEBUG) THEN
@@ -1305,7 +1282,6 @@ C GM(v,jac)=((av,cj)-(cv,aj))*SQRT(3/2)
 * be determined by integer division. This could be optimized by combining
 * it with loop peeling (on the todo list?).
 
-      SQRT2=SQRT(2.0D0)
       SQRTH=SQRT(0.5D0)
       SQRTA=SQRT(1.5D0)
 
