@@ -22,13 +22,15 @@
 
 *||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||*
       SUBROUTINE RHSOD_NOSYM(IVEC)
+      use output_caspt2, only:iPrGlb,verbose
+#ifdef _MOLCAS_MPP_
+      USE Para_Info, ONLY: Is_Real_Par
+#endif
       IMPLICIT REAL*8 (A-H,O-Z)
 #include "rasdim.fh"
 #include "caspt2.fh"
-#include "output.fh"
 #include "WrkSpc.fh"
 #include "eqsolv.fh"
-#include "para_info.fh"
 
 
       IF (IPRGLB.GE.VERBOSE) THEN
@@ -83,10 +85,10 @@
       SUBROUTINE RHSOD_A_NOSYM(IVEC)
       USE SUPERINDEX
       USE CHOVEC_IO
+      use output_caspt2, only:iPrGlb,debug
       IMPLICIT REAL*8 (A-H,O-Z)
 #include "rasdim.fh"
 #include "caspt2.fh"
-#include "output.fh"
 #include "WrkSpc.fh"
 #include "eqsolv.fh"
       DIMENSION IOBRA(8,8), IOKET(8,8)
@@ -94,8 +96,7 @@
 #include "global.fh"
 #include "mafdecls.fh"
 #else
-      REAL*8 DBL_MB(1:IWORKLEN)
-      EQUIVALENCE (DBL_MB,WORK)
+#define DBL_MB Work
 #endif
 
       IF (iPrGlb.GE.DEBUG) THEN
@@ -107,10 +108,6 @@
 C   RHS(tvx,j)=(tj,vx)+FIMO(t,j)*kron(v,x)/NACTEL
 ************************************************************************
 
-      SQRT2=SQRT(2.0D0)
-      SQRT3=SQRT(3.0D0)
-      SQRTH=1/SQRT2
-
 ************************************************************************
 CSVC: read in all the cholesky vectors (need all symmetries)
 ************************************************************************
@@ -138,7 +135,6 @@ CSVC: read in all the cholesky vectors (need all symmetries)
 
         CALL RHS_ALLO (NAS,NIS,lg_W)
         CALL RHS_ACCESS (NAS,NIS,lg_W,IASTA,IAEND,IISTA,IIEND,MW)
-        NA=NAS*(IIEND-IISTA+1)
 
 ************************************************************************
 * inner loop over RHS elements in symmetry ISYM
@@ -198,10 +194,10 @@ CSVC: read in all the cholesky vectors (need all symmetries)
       SUBROUTINE RHSOD_C_NOSYM(IVEC)
       USE SUPERINDEX
       USE CHOVEC_IO
+      use output_caspt2, only:iPrGlb,debug
       IMPLICIT REAL*8 (A-H,O-Z)
 #include "rasdim.fh"
 #include "caspt2.fh"
-#include "output.fh"
 #include "WrkSpc.fh"
 #include "eqsolv.fh"
       DIMENSION IOBRA(8,8), IOKET(8,8)
@@ -209,8 +205,7 @@ CSVC: read in all the cholesky vectors (need all symmetries)
 #include "global.fh"
 #include "mafdecls.fh"
 #else
-      REAL*8 DBL_MB(1:IWORKLEN)
-      EQUIVALENCE (DBL_MB,WORK)
+#define DBL_MB Work
 #endif
 
       IF (iPrGlb.GE.DEBUG) THEN
@@ -222,10 +217,6 @@ CSVC: read in all the cholesky vectors (need all symmetries)
 C   RHS(tvx,a)=(at,vx)+(FIMO(a,t)-Sum_u(au,ut))*delta(v,x)/NACTEL
 ************************************************************************
 
-      SQRT2=SQRT(2.0D0)
-      SQRT3=SQRT(3.0D0)
-      SQRTH=1/SQRT2
-
 ************************************************************************
 CSVC: read in all the cholesky vectors (need all symmetries)
 ************************************************************************
@@ -253,7 +244,6 @@ CSVC: read in all the cholesky vectors (need all symmetries)
 
         CALL RHS_ALLO (NAS,NIS,lg_W)
         CALL RHS_ACCESS (NAS,NIS,lg_W,IASTA,IAEND,IISTA,IIEND,MW)
-        NA=NAS*(IIEND-IISTA+1)
 
 ************************************************************************
 * inner loop over RHS elements in symmetry ISYM
@@ -326,10 +316,10 @@ CSVC: read in all the cholesky vectors (need all symmetries)
       SUBROUTINE RHSOD_B_NOSYM(IVEC)
       USE SUPERINDEX
       USE CHOVEC_IO
+      use output_caspt2, only:iPrGlb,debug
       IMPLICIT REAL*8 (A-H,O-Z)
 #include "rasdim.fh"
 #include "caspt2.fh"
-#include "output.fh"
 #include "WrkSpc.fh"
 #include "eqsolv.fh"
       DIMENSION IOSYM(8,8)
@@ -338,8 +328,7 @@ CSVC: read in all the cholesky vectors (need all symmetries)
 #include "global.fh"
 #include "mafdecls.fh"
 #else
-      REAL*8 DBL_MB(1:IWORKLEN)
-      EQUIVALENCE (DBL_MB,WORK)
+#define DBL_MB Work
 #endif
 
       IF (iPrGlb.GE.DEBUG) THEN
@@ -353,7 +342,6 @@ C   BP(tv,jl)=((tj,vl)+(tl,vj))*(1-Kron(t,v)/2)/(2*SQRT(1+Kron(j,l))
 C   BM(tv,jl)=((tj,vl)-(tl,vj))*(1-Kron(t,v)/2)/(2*SQRT(1+Kron(j,l))
 ************************************************************************
 
-      SQRT2=SQRT(2.0D0)
       SQRTH=SQRT(0.5D0)
 
 ************************************************************************
@@ -514,10 +502,10 @@ CSVC: read in all the cholesky vectors (need all symmetries)
       SUBROUTINE RHSOD_F_NOSYM(IVEC)
       USE SUPERINDEX
       USE CHOVEC_IO
+      use output_caspt2, only:iPrGlb,debug
       IMPLICIT REAL*8 (A-H,O-Z)
 #include "rasdim.fh"
 #include "caspt2.fh"
-#include "output.fh"
 #include "WrkSpc.fh"
 #include "eqsolv.fh"
       DIMENSION IOSYM(8,8)
@@ -526,8 +514,7 @@ CSVC: read in all the cholesky vectors (need all symmetries)
 #include "global.fh"
 #include "mafdecls.fh"
 #else
-      REAL*8 DBL_MB(1:IWORKLEN)
-      EQUIVALENCE (DBL_MB,WORK)
+#define DBL_MB Work
 #endif
 
       IF (iPrGlb.GE.DEBUG) THEN
@@ -540,7 +527,6 @@ C FP(tv,ac)=((at,cv)+(av,ct))*(1-Kron(t,v)/2)/(2*SQRT(1+Kron(a,c))
 C FM(tv,ac)= -((at,cv)-(av,ct))/(2*SQRT(1+Kron(a,c))
 ************************************************************************
 
-      SQRT2=SQRT(2.0D0)
       SQRTH=SQRT(0.5D0)
 
 ************************************************************************
@@ -701,10 +687,10 @@ CSVC: read in all the cholesky vectors (need all symmetries)
       SUBROUTINE RHSOD_H_NOSYM(IVEC)
       USE SUPERINDEX
       USE CHOVEC_IO
+      use output_caspt2, only:iPrGlb,debug
       IMPLICIT REAL*8 (A-H,O-Z)
 #include "rasdim.fh"
 #include "caspt2.fh"
-#include "output.fh"
 #include "WrkSpc.fh"
 #include "eqsolv.fh"
       DIMENSION IOSYM(8,8)
@@ -713,8 +699,7 @@ CSVC: read in all the cholesky vectors (need all symmetries)
 #include "global.fh"
 #include "mafdecls.fh"
 #else
-      REAL*8 DBL_MB(1:IWORKLEN)
-      EQUIVALENCE (DBL_MB,WORK)
+#define DBL_MB Work
 #endif
       INTEGER, PARAMETER :: NOSYM = 1
       REAL*8, ALLOCATABLE :: AIBJ(:,:)
@@ -729,9 +714,8 @@ C   WP(jl,ac)=((ajcl)+(alcj))/SQRT((1+Kron(jl))*(1+Kron(ac))
 C   WM(jl,ac)=((ajcl)-(alcj))*SQRT(3.0D0)
 ************************************************************************
 
-      SQRT2=SQRT(2.0D0)
       SQRT3=SQRT(3.0D0)
-      SQRTH=1/SQRT2
+      SQRTH=SQRT(0.5D0)
 
       NV=NVTOT_CHOSYM(NOSYM)
       ALLOCATE(AIBJ(NSSHT,NSSHT))
@@ -842,10 +826,10 @@ CSVC: read in all the cholesky vectors (need all symmetries)
       SUBROUTINE RHSOD_D_NOSYM(IVEC)
       USE SUPERINDEX
       USE CHOVEC_IO
+      use output_caspt2, only:iPrGlb,debug
       IMPLICIT REAL*8 (A-H,O-Z)
 #include "rasdim.fh"
 #include "caspt2.fh"
-#include "output.fh"
 #include "WrkSpc.fh"
 #include "eqsolv.fh"
       DIMENSION IOBRA1(8,8), IOKET1(8,8), IOBRA2(8,8), IOKET2(8,8)
@@ -853,8 +837,7 @@ CSVC: read in all the cholesky vectors (need all symmetries)
 #include "global.fh"
 #include "mafdecls.fh"
 #else
-      REAL*8 DBL_MB(1:IWORKLEN)
-      EQUIVALENCE (DBL_MB,WORK)
+#define DBL_MB Work
 #endif
       DIMENSION NFIMOES(8)
 
@@ -868,9 +851,6 @@ C D1(tv,aj)=(aj,tv) + FIMO(a,j)*Kron(t,v)/NACTEL
 C D2(tv,aj)=(tj,av)
 ************************************************************************
 
-      SQRT2=SQRT(2.0D0)
-      SQRTH=SQRT(0.5D0)
-
 ************************************************************************
 CSVC: read in all the cholesky vectors (need all symmetries)
 ************************************************************************
@@ -1010,10 +990,10 @@ CSVC: read in all the cholesky vectors (need all symmetries)
       SUBROUTINE RHSOD_E_NOSYM(IVEC)
       USE SUPERINDEX
       USE CHOVEC_IO
+      use output_caspt2, only:iPrGlb,debug
       IMPLICIT REAL*8 (A-H,O-Z)
 #include "rasdim.fh"
 #include "caspt2.fh"
-#include "output.fh"
 #include "WrkSpc.fh"
 #include "eqsolv.fh"
       DIMENSION IOBRA(8,8), IOKET(8,8)
@@ -1022,8 +1002,7 @@ CSVC: read in all the cholesky vectors (need all symmetries)
 #include "global.fh"
 #include "mafdecls.fh"
 #else
-      REAL*8 DBL_MB(1:IWORKLEN)
-      EQUIVALENCE (DBL_MB,WORK)
+#define DBL_MB Work
 #endif
 
       IF (iPrGlb.GE.DEBUG) THEN
@@ -1044,7 +1023,6 @@ C EM(v,ajl)=((aj,vl)-(al,vj))*SQRT(3/2)
 * be determined by integer division. This could be optimized by combining
 * it with loop peeling (on the todo list?).
 
-      SQRT2=SQRT(2.0D0)
       SQRTH=SQRT(0.5D0)
       SQRTA=SQRT(1.5D0)
 
@@ -1229,10 +1207,10 @@ CSVC: read in all the cholesky vectors (need all symmetries)
       SUBROUTINE RHSOD_G_NOSYM(IVEC)
       USE SUPERINDEX
       USE CHOVEC_IO
+      use output_caspt2, only:iPrGlb,debug
       IMPLICIT REAL*8 (A-H,O-Z)
 #include "rasdim.fh"
 #include "caspt2.fh"
-#include "output.fh"
 #include "WrkSpc.fh"
 #include "eqsolv.fh"
       DIMENSION IOBRA(8,8), IOKET(8,8)
@@ -1241,8 +1219,7 @@ CSVC: read in all the cholesky vectors (need all symmetries)
 #include "global.fh"
 #include "mafdecls.fh"
 #else
-      REAL*8 DBL_MB(1:IWORKLEN)
-      EQUIVALENCE (DBL_MB,WORK)
+#define DBL_MB Work
 #endif
 
       IF (iPrGlb.GE.DEBUG) THEN
@@ -1263,7 +1240,6 @@ C GM(v,jac)=((av,cj)-(cv,aj))*SQRT(3/2)
 * be determined by integer division. This could be optimized by combining
 * it with loop peeling (on the todo list?).
 
-      SQRT2=SQRT(2.0D0)
       SQRTH=SQRT(0.5D0)
       SQRTA=SQRT(1.5D0)
 
