@@ -17,14 +17,16 @@
 * SWEDEN                                     *
 *--------------------------------------------*
       SUBROUTINE SBDIAG()
+      use output_caspt2, only:iPrGlb,usual,verbose
+#ifdef _MOLCAS_MPP_
+      USE Para_Info, ONLY: Is_Real_Par
+#endif
       IMPLICIT REAL*8 (A-H,O-Z)
 #include "rasdim.fh"
 #include "caspt2.fh"
-#include "output.fh"
 #include "eqsolv.fh"
 #include "WrkSpc.fh"
 #include "SysDef.fh"
-#include "para_info.fh"
 
 
       IF(IPRGLB.GE.VERBOSE) THEN
@@ -100,11 +102,11 @@ C usually print info on the total number of parameters
       END
 
       SUBROUTINE SBDIAG_SER(ISYM,ICASE,CONDNR,CPU)
+      use output_caspt2, only:iPrGlb,insane
       IMPLICIT REAL*8 (A-H,O-Z)
 
 #include "rasdim.fh"
 #include "caspt2.fh"
-#include "output.fh"
 #include "eqsolv.fh"
 #include "WrkSpc.fh"
 
@@ -398,7 +400,6 @@ C - Alt 0: Use diagonal approxim., if allowed:
           WORK(LEIG-1+I)=WORK(LB-1+IDIAG)/SD
         END DO
       ELSE
-        NBB=(NIN*(NIN+1))/2
         IJ=0
         DO J=1,NIN
           DO I=1,J
@@ -500,10 +501,13 @@ C batch mode.  However, unlike in the replicate routine, this amount is
 C divided over processors.
 #ifdef _MOLCAS_MPP_
       SUBROUTINE SBDIAG_MPP(ISYM,ICASE,CONDNR,CPU)
+      use output_caspt2, only:iPrGlb,insane
+#ifdef _MOLCAS_MPP_
+      USE Para_Info, ONLY: King
+#endif
       IMPLICIT REAL*8 (A-H,O-Z)
 #include "rasdim.fh"
 #include "caspt2.fh"
-#include "output.fh"
 #include "eqsolv.fh"
 #include "WrkSpc.fh"
 #include "SysDef.fh"
@@ -511,12 +515,11 @@ C divided over processors.
 C-SVC20100902: global arrays header files
 #include "global.fh"
 #include "mafdecls.fh"
-#ifndef SCALAPACK
+#ifndef _SCALAPACK_
       DIMENSION WGRONK(2)
 #endif
       LOGICAL bSTAT
       CHARACTER(LEN=2) cSYM,cCASE
-      LOGICAL KING
 
 C On entry, the DRA metafiles contain the matrices S and B for cases A
 C (iCASE=1) en C (iCASE=4).  These symmetric matrices are stored on disk
@@ -630,7 +633,7 @@ C performance recommend PDSYEVX or PDSYEVR as fastest methods if
 C eigenvectors are needed (FIXME: should time this).  For the linear
 C dependence removal, split eigenvectors in horizontal stripes so that
 C each processor has a row window of all column vectors
-#ifdef SCALAPACK
+#ifdef _SCALAPACK_
       CALL PSBMAT_GETMEM('VMAT',lg_V,NAS)
       CALL GA_PDSYEVX_ (lg_S, lg_V, WORK(LEIG), 0)
       bSTAT = GA_Destroy (lg_S)
@@ -888,7 +891,7 @@ C FIXME: this original code seemed wrong, using uninitialized SD?
         WRITE(6,*) 'GLOB_SBDIAG: option not implemented'
         call AbEnd()
       ELSE
-#ifdef SCALAPACK
+#ifdef _SCALAPACK_
         CALL GA_CREATE_STRIPED ('H',NIN,NIN,'VMAT',lg_V)
         CALL GA_PDSYEVX_ (lg_B, lg_V, WORK(LEIG), 0)
         bStat = GA_Destroy (lg_B)
@@ -1013,7 +1016,6 @@ C replicate array.  FIXME: Should be removed later.
       IMPLICIT REAL*8 (A-H,O-Z)
 #include "rasdim.fh"
 #include "caspt2.fh"
-#include "output.fh"
 #include "eqsolv.fh"
 #include "WrkSpc.fh"
 #include "SysDef.fh"
@@ -1029,7 +1031,6 @@ C replicate array.  FIXME: Should be removed later.
       IMPLICIT REAL*8 (A-H,O-Z)
 #include "rasdim.fh"
 #include "caspt2.fh"
-#include "output.fh"
 #include "eqsolv.fh"
 #include "WrkSpc.fh"
 #include "SysDef.fh"
