@@ -17,16 +17,15 @@
 * SWEDEN                                     *
 *--------------------------------------------*
       SUBROUTINE SIZES()
+      use output_caspt2, only:iPrGlb,usual
       USE SUPERINDEX
       IMPLICIT REAL*8 (A-H,O-Z)
 
 #include "rasdim.fh"
-#include "warnings.fh"
+#include "warnings.h"
 #include "caspt2.fh"
-#include "output.fh"
 #include "eqsolv.fh"
 #include "pt2_guga.fh"
-#include "WrkSpc.fh"
 
 
 C Available workspace right now:
@@ -79,7 +78,7 @@ C SBMAT need:
 *       N=NTUV(ISYM)
 *       NG3C=NG3C+(N*(N+1))/2
 *     END DO
-      NG3C=iPARDIV(NG3TOT,NG2)
+*     NG3C=iPARDIV(NG3TOT,NG2)
 
 C Sizes and addresses to lists:
       DO ISL1=1,NSYM
