@@ -21,8 +21,6 @@
       IMPLICIT NONE
 #include "rasdim.fh"
 #include "caspt2.fh"
-#include "output.fh"
-#include "WrkSpc.fh"
       INTEGER IFC,ISYM
       REAL*8 FACT,X(*),Y(*)
       INTEGER NAS,NT,NI,IT,ITQ,IUQ,ITUU
