@@ -11,10 +11,10 @@
 * Copyright (C) 1998, Per Ake Malmqvist                                *
 ************************************************************************
       SUBROUTINE STINI
+      use output_caspt2, only:iPrGlb,usual,debug
       IMPLICIT NONE
 #include "rasdim.fh"
 #include "caspt2.fh"
-#include "output.fh"
 #include "pt2_guga.fh"
 #include "WrkSpc.fh"
 #include "SysDef.fh"
