@@ -8,17 +8,17 @@
 * For more details see the full text of the license in the file        *
 * LICENSE or in <http://www.gnu.org/licenses/>.                        *
 *                                                                      *
-* Copyright (C) 1996-2006, T. Thorsteinsson and D. L. Cooper           *
+* Copyright (C) 1996-2006, Thorstein Thorsteinsson                     *
+*               1996-2006, David L. Cooper                             *
 ************************************************************************
       subroutine construc2_cvb(tconstr)
       implicit real*8 (a-h,o-z)
-#include "ext_cvb.fh"
 #include "main_cvb.fh"
 #include "optze_cvb.fh"
 #include "files_cvb.fh"
 #include "print_cvb.fh"
 
-#include "malloc_cvb.fh"
+#include "WrkSpc.fh"
       dimension tconstr(nvb,nvb)
       dimension dum(1)
 
@@ -28,11 +28,11 @@
 
       call span0_cvb(nvb,nvb)
       do 100 ivb=1,nvb
-      call fzero(w(irepm),nvb)
-      w(ivb+irepm-1)=-1d0
-      call symtrizcvb_cvb(w(irepm))
-      w(ivb+irepm-1)=w(ivb+irepm-1)+1d0
-      call span1_cvb(w(irepm),1,dum,nvb,0)
+      call fzero(work(irepm),nvb)
+      work(ivb+irepm-1)=-1d0
+      call symtrizcvb_cvb(work(irepm))
+      work(ivb+irepm-1)=work(ivb+irepm-1)+1d0
+      call span1_cvb(work(irepm),1,dum,nvb,0)
 100   continue
       call span2_cvb(tconstr,nconstr,dum,nvb,0)
 
