@@ -8,23 +8,23 @@
 * For more details see the full text of the license in the file        *
 * LICENSE or in <http://www.gnu.org/licenses/>.                        *
 *                                                                      *
-* Copyright (C) 1996-2006, T. Thorsteinsson and D. L. Cooper           *
+* Copyright (C) 1996-2006, Thorstein Thorsteinsson                     *
+*               1996-2006, David L. Cooper                             *
 ************************************************************************
       subroutine indxab_cvb(indxa,indxb,nstra,nstrb,nsa,nsb)
       implicit real*8 (a-h,o-z)
-#include "ext_cvb.fh"
 #include "main_cvb.fh"
 #include "optze_cvb.fh"
 #include "files_cvb.fh"
 #include "print_cvb.fh"
 
-#include "malloc_cvb.fh"
+#include "WrkSpc.fh"
       dimension indxa(nsa),indxb(nsb),nstra(mxirrep),nstrb(mxirrep)
 
       i1 = mstacki_cvb(norb+1)
 
       call indxab2_cvb(indxa,indxb,nstra,nstrb,
-     >  iw(i1),nsa,nsb)
+     >  iwork(i1),nsa,nsb)
       call mfreei_cvb(i1)
       return
       end
