@@ -8,11 +8,12 @@
 * For more details see the full text of the license in the file        *
 * LICENSE or in <http://www.gnu.org/licenses/>.                        *
 *                                                                      *
-* Copyright (C) 1996-2006, T. Thorsteinsson and D. L. Cooper           *
+* Copyright (C) 1996-2006, Thorstein Thorsteinsson                     *
+*               1996-2006, David L. Cooper                             *
 ************************************************************************
       subroutine seth_cvb(iarr,n)
       implicit real*8(a-h,o-z)
-#include "malloc_cvb.fh"
+#include "WrkSpc.fh"
 #include "seth_cvb.fh"
       dimension iarr(n)
 
@@ -21,7 +22,7 @@
       end
       subroutine geth_cvb(iarr,n)
       implicit real*8(a-h,o-z)
-#include "malloc_cvb.fh"
+#include "WrkSpc.fh"
 #include "seth_cvb.fh"
       dimension iarr(n)
       if(icnt.lt.ncnt)then
