@@ -10,16 +10,6 @@
 *                                                                      *
 * Copyright (C) 2006, Pavel Neogrady                                   *
 ************************************************************************
-c
-c       this package contains:
-c       sumoerab
-c         multstack
-c         grc0stack
-c         extstack
-c           extstackhlp1
-c
-c     -----------------------------
-c
       subroutine sumoverab (wrk,wrksize,
      & lunt2o1, lunt2o2, lunt2o3,nabstack,possabstack,
      & niter)
@@ -67,15 +57,16 @@ c     end syma
 c
 c     N.B. nab musi byt dakde deklarovane (daky common)
 c
-c     N.B. II. in paralell.fh there are:
+c     N.B. II. in parallel.fh there are:
 c     nprocab - number of nodeschoosed for 'sumoverab' part
 c     idab    - array of id's of these nodes
 c
+       use Para_Info, only: MyRank
         implicit none
 #include "ccsd1.fh"
 #include "ccsd2.fh"
 #include "wrk.fh"
-#include "paralell.fh"
+#include "parallel.fh"
       INTEGER lunt2o1,lunt2o2,lunt2o3
       integer nabstack,possabstack
       integer niter
@@ -84,7 +75,7 @@ c     help variables
 c
       INTEGER key,aeqb,yes
       INTEGER a,b,syma,symb,ssh3,ssn,ssh1
-      INTEGER nlenght,posst,rc
+      INTEGER nlength,posst,rc
       INTEGER lunab,nsa,nsb,limb
       integer nab,nadd
       integer idtot(1:maxproc)
@@ -96,7 +87,7 @@ c
       possab=possabstack
 c
 c
-c     I.paralell
+c     I.parallel
 c
 c     I.par.1  - escape, if this node is not reserved for sumoverab
       yes=0
@@ -181,10 +172,10 @@ c      II   sum over ab
         end if
 c
 c      II.1   read mapdn,mapin
-        CALL getmap (lunab, possn0, nlenght, mapdn, mapin, rc)
+        CALL getmap (lunab, possn0, nlength, mapdn, mapin, rc)
 c
 c      II.3     skip sum over a,b if N is empty
-        IF (nlenght.eq.0) GO TO 21
+        IF (nlength.eq.0) GO TO 21
 c
 c      II.4   skip sum over a,b if # of ab is zero
         IF ((nvb(syma)*nvb(symb)).eq.0) GO TO 21
@@ -251,7 +242,7 @@ c
 c       all cycle over b need to be skipped
           do b=1,limb
 c           blank read and nothing more
-            call reajalovy (lunab, nlenght, wrk(possn0))
+            call reajalovy (lunab, nlength, wrk(possn0))
             nadd=nadd-1
           end do
 c       no setup needed
@@ -266,7 +257,7 @@ c       setup first
 c       part of the cycle over b need to be skipped
           do b=1,nadd
 c           blank read and nothing more
-            call reajalovy (lunab, nlenght, wrk(possn0))
+            call reajalovy (lunab, nlength, wrk(possn0))
           end do
           nadd=0
 c
@@ -319,11 +310,11 @@ c*.3    set stacking conditions for real stacking
 c
 c*.     reading to N or to stack
 6       if (nabnow.eq.1) then
-          CALL rea (lunab, nlenght, wrk(possn0))
+          CALL rea (lunab, nlength, wrk(possn0))
         else
           do iab=1,nabnow
-          CALL rea (lunab, nlenght, wrk(possabstack+(iab-1)*nlenght))
-          if ((possabstack+iab*nlenght).ge.possm10) then
+          CALL rea (lunab, nlength, wrk(possabstack+(iab-1)*nlength))
+          if ((possabstack+iab*nlength).ge.possm10) then
           end if
           end do
 c         qq=wrk(possabstack)
@@ -333,7 +324,7 @@ c
           do 8 b=bstart,bstop
 c
 c      III.3       read N
-cStare    CALL rea (lunab, nlenght, wrk(possn0))
+cStare    CALL rea (lunab, nlength, wrk(possn0))
 c
 c      III.4       def aeqb
           IF ((syma.eq.symb).and.(a.eq.b)) THEN
@@ -455,7 +446,7 @@ c       def mapd and mapi for V4 _a,(ef,Bp)
        call grc0stack (nabnow,1,3,3,3,0,ssn,possv40,posst,mapdv4,mapiv4)
 c           -> V4 _a,_b(ef)aaaa  = <ab||ef>
        call unpackab3 (wrk,wrksize,
-     &      mapdn,mapin,mapdv4,mapiv4,ssn,nabnow,possabstack,nlenght,1)
+     &      mapdn,mapin,mapdv4,mapiv4,ssn,nabnow,possabstack,nlength,1)
 c
 c      T25.1.1      H2 (ij,Bp) = V1(ij,ef) . V4 (ef,Bp)
         call multstack (wrk,wrksize,
@@ -480,7 +471,7 @@ c       def mapd and mapi for V4 _a,(ef,Bp)
        call grc0stack (nabnow,1,4,4,4,0,ssn,possv40,posst,mapdv4,mapiv4)
 c           -> V4 _a,_b(ef)bbbb  = <ab||ef>
        call unpackab3 (wrk,wrksize,
-     &      mapdn,mapin,mapdv4,mapiv4,ssn,nabnow,possabstack,nlenght,2)
+     &      mapdn,mapin,mapdv4,mapiv4,ssn,nabnow,possabstack,nlength,2)
 c
 c      T25.2.1      H2 (ij,Bp) = V2(ij,ef) . V4 (ef,Bp)
         call multstack (wrk,wrksize,
@@ -505,7 +496,7 @@ c       def mapd and mapi for V4 _a,(ef,Bp)
        call grc0stack (nabnow,0,3,4,4,0,ssn,possv40,posst,mapdv4,mapiv4)
 c           -> V4 _a,_b(e,f)abab = <ab||ef>
        call unpackab3 (wrk,wrksize,
-     &      mapdn,mapin,mapdv4,mapiv4,ssn,nabnow,possabstack,nlenght,3)
+     &      mapdn,mapin,mapdv4,mapiv4,ssn,nabnow,possabstack,nlength,3)
 c
 c      T25.3.1      H2 (i,j,Bp) = V3(i,j,e,f) . V4 (e,f,Bp)
         call multstack (wrk,wrksize,
@@ -530,7 +521,7 @@ c       def mapd and mapi for V4 _a,(ef,Bp)
        call grc0stack (nabnow,0,3,4,3,0,ssn,possv40,posst,mapdv4,mapiv4)
 c           -> V4 _b,_a(e,f)abab = <ba||fe>
        call unpackab3 (wrk,wrksize,
-     &      mapdn,mapin,mapdv4,mapiv4,ssn,nabnow,possabstack,nlenght,4)
+     &      mapdn,mapin,mapdv4,mapiv4,ssn,nabnow,possabstack,nlength,4)
 c
 c      T25.3.4      H2 (i,j,Bp) = V3(i,j,e,f) . V4 (e,f,Bp)
         call multstack (wrk,wrksize,
@@ -564,11 +555,11 @@ c
 c       put appropriate data from AB_stack to N mediate, if needed
         if (nabnow.gt.1) then
 c       transfer data
-          do nhelp=0,nlenght-1
+          do nhelp=0,nlength-1
           wrk(possn0+nhelp)=wrk(possab+nhelp)
           end do
 c       upgrade address
-          possab=possab+nlenght
+          possab=possab+nlength
         end if
 c
 c
@@ -720,304 +711,3 @@ c
 c Avoid unused argument warnings
       IF (.FALSE.) CALL Unused_integer(niter)
       END
-c
-c     -----------------------------
-c
-       subroutine multstack (wrk,wrksize,
-     &                       mapda,mapdb,mapdc,mapia,mapib,mapic,
-     &                       ssa,ssb,possc0,bsize)
-c
-c        This is a special routine for multiplying of the:
-c        C(ij,Bp) = A(ij,cd) . B(cd,Bp)
-c        where Bp is a limited (partial) sumation over
-c        b index (#b - bsize), namely those, hich are stacked
-c
-c        This routine is used only in stacking in sumoverab
-c        process and is a modification of grc42y routine.
-c        Type of index Bp is registered as for standard b, but
-c        all lengths of blocks are calculated with
-c        bsize, instead of dimm(typb,symb) and the symmetry
-c       of b is ignored, B and C are treated as 2index
-c
-c        P.N. 17.02.06
-c
-c
-#include "ccsd1.fh"
-#include "wrk.fh"
-c
-       integer mapda(0:512,1:6)
-       integer mapdb(0:512,1:6)
-       integer mapdc(0:512,1:6)
-c
-       integer mapia(1:8,1:8,1:8)
-       integer mapib(1:8,1:8,1:8)
-       integer mapic(1:8,1:8,1:8)
-c
-       integer mvec(1:4096,1:7)
-       integer possc0,bsize
-       integer ssa,ssb
-c
-c     help variables
-c
-       integer nhelp1,nhelp2,nhelp3,nhelp4
-       integer nhelp21,nhelp22,nhelp41,nhelp42
-       integer ntest1,ntest2
-       integer sa1,sa2,sa3,sa4,sb1,sb2,sa34,sa134
-CLD    integer sa1,sa2,sa3,sa4,sb1,sb2,sb3,sa12,sa34,sa134,sb12
-CLD    integer nsyma2
-       integer ia,ib,ix,iy
-CLD    integer ia,ib,ic,ix,iy
-       integer possct
-c
-c1*
-c
-c     sctructure A(pq,rs)*B(rs,t)=C(pq,t)
-c     sctructure A(pq,rs)*B(rs)=YC(pq)
-c
-c1.1  define limitations -  p>q,r,s must be tested - ntest1
-c     p,q,r>s must be tested - ntest2
-c
-       if ((mapda(0,6).eq.1).or.(mapda(0,6).eq.4)) then
-       ntest1=1
-       else
-       ntest1=0
-       end if
-c
-       if ((mapda(0,6).eq.3).or.(mapda(0,6).eq.4)) then
-       ntest2=1
-       else
-       ntest2=0
-       end if
-c
-c1.0  prepare mapdc,mapic
-c
-       call grc0stack (bsize,ntest1,mapda(0,1),mapda(0,2),mapdb(0,3),
-     &                 0,mmul(ssa,ssb),possc0,possct,mapdc,mapic)
-
-c
-c
-c1.2  def symm states and test the limitations
-c
-       ix=1
-       do 100 sb1=1,nsym
-       sa3=sb1
-c
-       sb2=mmul(ssb,sb1)
-       sa4=sb2
-       sa34=mmul(sa3,sa4)
-       if ((ntest2.eq.1).and.(sb1.lt.sb2)) then
-c     Meggie out
-       goto 100
-       end if
-c
-       do 50 sa1=1,nsym
-       sa134=mmul(sa1,sa34)
-c
-       sa2=mmul(ssa,sa134)
-       if ((ntest1.eq.1).and.(sa1.lt.sa2)) then
-c     Meggie out
-       goto 50
-       end if
-c
-c1.3  def mvec,mapdc and mapdi
-c
-       ia=mapia(sa1,sa2,sa3)
-       ib=mapib(sb1,1,1)
-       iy=mapic(sa1,1,1)
-c
-c     yes/no
-       if ((mapda(ia,2).gt.0).and.(mapdb(ib,2).gt.0)) then
-       nhelp1=1
-       else
-       goto 50
-       end if
-c
-c     rowA
-       nhelp21=dimm(mapda(0,1),sa1)
-       nhelp22=dimm(mapda(0,2),sa2)
-       if ((ntest1.eq.1).and.(sa1.eq.sa2)) then
-       nhelp2=nhelp21*(nhelp21-1)/2
-       else
-       nhelp2=nhelp21*nhelp22
-       end if
-c
-c     sum
-       nhelp41=dimm(mapda(0,3),sa3)
-       nhelp42=dimm(mapda(0,4),sa4)
-       if ((ntest2.eq.1).and.(sa3.eq.sa4)) then
-       nhelp4=nhelp41*(nhelp41-1)/2
-       else
-       nhelp4=nhelp41*nhelp42
-       end if
-c
-c     colBp
-       nhelp3=bsize
-c
-       mvec(ix,1)=nhelp1
-       mvec(ix,2)=mapda(ia,1)
-       mvec(ix,3)=mapdb(ib,1)
-       mvec(ix,4)=mapdc(iy,1)
-       mvec(ix,5)=nhelp2
-       mvec(ix,6)=nhelp4
-       mvec(ix,7)=nhelp3
-c
-       ix=ix+1
-c
- 50     continue
- 100    continue
-       ix=ix-1
-c
-c
-c*        multiplying
-c
-        call multc0 (wrk,wrksize,
-     &               mvec,ix,mapdc,1)
-c
-       return
-       end
-c
-c     -----------------------------
-c
-       subroutine grc0stack (bsize,typ,typp,typq,typr,typs,stot,
-     & poss0,posst,mapd,mapi)
-c
-c             This routine defines mapd and mapi for specific
-c        3 index intermediat A(pq,Bp), needed when stacking
-c        (About Bp, see notes in multstack)
-c        This routine is a modification of grc0 routine
-c
-c        P.N. 17.02.06
-c     !N.B. (this routine cannot run with +OP2)
-c
-       integer bsize,typ,typp,typq,typr,typs,stot,poss0,posst
-c
-#include "ccsd1.fh"
-       integer mapd(0:512,1:6)
-       integer mapi(1:8,1:8,1:8)
-c
-c     help variables
-c
-       integer sp,sq
-CLD    integer sp,sq,sr,ss,spq,spqr
-CLD    integer nsymq,nsymr
-       integer poss,i,nhelp1,nhelp2,nhelp3
-CLD    integer poss,i,nhelp1,nhelp2,nhelp3,nhelp4
-
-c     To get rid of compiler warning
-      poss=0
-      i=0
-c
-c     vanishing mapi files
-c
-       do nhelp1=1,nsym
-       do nhelp2=1,nsym
-       do nhelp3=1,nsym
-       mapi(nhelp3,nhelp2,nhelp1)=0
-       end do
-       end do
-       end do
-c
-c     matrix A(p,q) or specifilally A(i,j,Bp)
-c
-       i=1
-       poss=poss0
-c
-       do 100 sp=1,nsym
-c
-       sq=mmul(stot,sp)
-       if ((typ.eq.1).and.(sp.lt.sq)) then
-c     Meggie out
-       goto 100
-       end if
-c
-       nhelp1=dimm(typp,sp)
-       nhelp2=dimm(typq,sq)
-c
-c     def mapi
-       mapi(sp,1,1)=i
-c
-c     def possition
-       mapd(i,1)=poss
-c
-c     def lenght
-       if ((typ.eq.1).and.(sp.eq.sq)) then
-       mapd(i,2)=bsize*nhelp1*(nhelp1-1)/2
-       else
-       mapd(i,2)=bsize*nhelp1*nhelp2
-       end if
-c
-c     def sym p,q
-       mapd(i,3)=sp
-       mapd(i,4)=sq
-       mapd(i,5)=0
-       mapd(i,6)=0
-c
-       poss=poss+mapd(i,2)
-       i=i+1
-c
- 100    continue
-c
-c
-       posst=poss
-c
-c     definition of other coll
-c
-       mapd(0,1)=typp
-       mapd(0,2)=typq
-       mapd(0,3)=typr
-       mapd(0,4)=typs
-       mapd(0,5)=i-1
-       mapd(0,6)=typ
-c
-       return
-       end
-c
-c     -----------------------------
-c
-        subroutine extstack (wrk,wrksize,
-     &                 mapda,mapdb,b,dimb)
-c
-c       This routine do:
-c       A(ij) <- B(ij,_b) for given b
-c
-c       A special routine used only in sumoverab for stacking
-c       case.
-c
-c       Yet it is assumed,that blocks in A and B are in the same
-c       order. To je pomerne odflaknuty predpoklad, a moze to
-c       byt bugous
-c
-#include "wrk.fh"
-c
-       integer mapda(0:512,1:6)
-       integer mapdb(0:512,1:6)
-       integer b,dimb
-c
-c     help variables
-c
-       integer ii,dimij,possa,possb
-c
-c
-        do ii=1,mapda(0,5)
-          dimij=mapda(ii,2)
-          possa=mapda(ii,1)
-          possb=mapdb(ii,1)
-          call extstackhlp1 (wrk(possa),wrk(possb),dimij,dimb,b)
-        end do
-c
-        return
-        end
-c
-c       -----------
-c
-        subroutine extstackhlp1 (a,b,dimij,dimb,bb)
-        integer dimij,dimb,bb,ij
-        real*8 a(1:dimij),b(1:dimij,1:dimb)
-        do ij=1,dimij
-        a(ij)=b(ij,bb)
-        end do
-        return
-        end
-c
-c     -----------------------------
-c
