@@ -8,17 +8,6 @@
 * For more details see the full text of the license in the file        *
 * LICENSE or in <http://www.gnu.org/licenses/>.                        *
 ************************************************************************
-c
-c     this file contains following routines:
-c     expand
-c     expand0
-c     expand1
-c     expand2
-c     expand3
-c     expand40
-c     expand41
-c     expand42
-c
        subroutine cct3_expand (wrk,wrksize,
      & nind,exptyp,mapda,mapia,ssa,possb0,mapdb,
      & mapib,rc)
@@ -891,335 +880,3 @@ c
 c Avoid unused argument warnings
       if (.false.) call Unused_integer_array(mapia)
        end
-c
-c     ------------------------------
-c
-       subroutine cct3_expand0 (a,b,dimpq,dimp)
-c
-c     expand a(pq) -> b(p,q)
-c     assumption: p>q, a(p,q)=-a(q,p)
-c     RISC version
-c
-       integer dimpq,dimp
-       real*8 a(1:dimpq)
-       real*8 b(1:dimp,1:dimp)
-c
-c     help variables
-c
-       integer p,q,pq
-       real*8 scalar
-c
-       if (dimp.gt.1) then
-c
-       pq=0
-       do 100 p=2,dimp
-       do 101 q=1,p-1
-       pq=pq+1
-       scalar=a(pq)
-       b(p,q)=scalar
-       b(q,p)=-scalar
- 101    continue
- 100    continue
-c
-       end if
-c
-       do p=1,dimp
-       b(p,p)=0.0d0
-       end do
-c
-       return
-       end
-c
-c     --------------------------
-c
-       subroutine cct3_expand1 (a,b,dimpq,dimr,dimp)
-c
-c     expand a(pq,r) -> b(p,q,r)
-c     assumption: p>q, a(p,q,r)=-a(q,p,r)
-c     RISC version
-c
-       integer dimpq,dimr,dimp
-       real*8 a(1:dimpq,1:dimr)
-       real*8 b(1:dimp,1:dimp,1:dimr)
-c
-c     help variables
-c
-       integer p,q,r,pq
-       real*8 scalar
-c
-       if (dimp.gt.1) then
-c
-       do r=1,dimr
-       pq=0
-       do 100 p=2,dimp
-       do 101 q=1,p-1
-       pq=pq+1
-       scalar=a(pq,r)
-       b(p,q,r)=scalar
-       b(q,p,r)=-scalar
- 101    continue
- 100    continue
-       end do
-c
-       end if
-c
-       do r=1,dimr
-       do p=1,dimp
-       b(p,p,r)=0.0d0
-       end do
-       end do
-c
-       return
-       end
-c
-c     --------------------------
-c
-       subroutine cct3_expand2 (a,b,dimp,dimqr,dims,dimq)
-c
-c     expand a(p,qr,s) -> b(p,q,r,s)
-c     assumption: p>q, a(p,q,r,s)=-a(p,r,q,s)
-c     RISC version
-c
-       integer dimp,dimqr,dims,dimq
-       real*8 a(1:dimp,1:dimqr,1:dims)
-       real*8 b(1:dimp,1:dimq,1:dimq,1:dims)
-c
-c     help variables
-c
-       integer p,q,r,s,qr
-       real*8 scalar
-c      To fix some warnings
-       s=0
-c
-       if (dimq.gt.1) then
-c
-       do s=1,dims
-       qr=0
-       do 100 q=2,dimq
-       do 101 r=1,q-1
-       qr=qr+1
-       do p=1,dimp
-       scalar=a(p,qr,s)
-       b(p,q,r,s)=scalar
-       b(p,r,q,s)=-scalar
-       end do
- 101    continue
- 100    continue
-       end do
-c
-       end if
-c
-       do r=1,dimq
-       do q=1,dimq
-       do p=1,dimp
-       b(p,q,q,s)=0.0d0
-       end do
-       end do
-       end do
-c
-       return
-       end
-c
-c     --------------------------
-c
-       subroutine cct3_expand3 (a,b,dimp,dimqr,dimq)
-c
-c     expand a(p,qr) -> b(p,q,r)
-c     assumption: q>r, a(p,q,r)=-a(p,r,q)
-c     RISC version
-c
-       integer dimp,dimq,dimqr
-       real*8 a(1:dimp,1:dimqr)
-       real*8 b(1:dimp,1:dimq,1:dimq)
-c
-c     help variables
-c
-       integer p,q,r,qr
-       real*8 scalar
-c
-       if (dimq.gt.1) then
-c
-       qr=0
-       do 100 q=2,dimq
-       do 101 r=1,q-1
-       qr=qr+1
-c
-       do p=1,dimp
-       scalar=a(p,qr)
-       b(p,q,r)=scalar
-       b(p,r,q)=-scalar
-       end do
- 101    continue
- 100    continue
-c
-       end if
-c
-       do q=1,dimq
-       do p=1,dimp
-       b(p,q,q)=0.0d0
-       end do
-       end do
-c
-       return
-       end
-c
-c     --------------------------
-c
-       subroutine cct3_expand40 (a,b,dimpq,dimrs,dimp,dimr)
-c
-c     expand a(pq,rs) -> b(p,q,r,s)
-c     assumption: p>q,r>s, + antisymetry
-c     RISC version
-c
-       integer dimpq,dimrs,dimp,dimr
-       real*8 a(1:dimpq,1:dimrs)
-       real*8 b(1:dimp,1:dimp,1:dimr,1:dimr)
-c
-c     help variables
-c
-       integer p,q,r,s,pq,rs
-       real*8 scalar
-c
-       if ((dimp.gt.1).and.(dimr.gt.1)) then
-c
-       rs=0
-       do 100 r=2,dimr
-       do 101 s=1,r-1
-       rs=rs+1
-c
-       pq=0
-       do 102 p=2,dimp
-       do 103 q=1,p-1
-       pq=pq+1
-c
-       scalar=a(pq,rs)
-       b(p,q,r,s)=scalar
-       b(p,q,s,r)=-scalar
-       b(q,p,r,s)=-scalar
-       b(q,p,s,r)=scalar
-c
- 103    continue
- 102    continue
- 101    continue
- 100    continue
-c
-       end if
-c
-       do r=1,dimr
-       do p=1,dimp
-       do q=1,dimp
-       b(p,q,r,r)=0.0d0
-       end do
-       end do
-       end do
-c
-       do s=1,dimr
-       do r=1,dimr
-       do p=1,dimp
-       b(p,p,r,s)=0.0d0
-       end do
-       end do
-       end do
-c
-       return
-       end
-c
-c     --------------------------
-c
-       subroutine cct3_expand41 (a,b,dimpq,dimr,dims,dimp)
-c
-c     expand a(pq,r,s) -> - b(p,q,s,r)
-c     assumption: p>q + antisymetry
-c     RISC version
-c
-       integer dimpq,dimr,dims,dimp
-       real*8 a(1:dimpq,1:dimr,1:dims)
-       real*8 b(1:dimp,1:dimp,1:dims,1:dimr)
-c
-c     help variables
-c
-       integer p,q,r,s,pq
-       real*8 scalar
-c
-       if (dimp.gt.1) then
-c
-       do 100 s=1,dims
-       do 101 r=1,dimr
-c
-       pq=0
-       do 102 p=2,dimp
-       do 103 q=1,p-1
-       pq=pq+1
-c
-       scalar=a(pq,r,s)
-       b(p,q,s,r)=-scalar
-       b(q,p,s,r)=scalar
-c
- 103    continue
- 102    continue
- 101    continue
- 100    continue
-c
-       end if
-c
-       do r=1,dimr
-       do s=1,dims
-       do p=1,dimp
-       b(p,p,s,r)=0.0d0
-       end do
-       end do
-       end do
-c
-       return
-       end
-#ifdef _NOTUSED_
-c
-c     --------------------------
-c
-       subroutine cct3_expand42 (a,b,dimp,dimq,dimrs,dimr)
-c
-c     expand a(p,q,rs) -> - b(q,p,r,s)
-c     assumption: r>s + antisymetry
-c     RISC version
-c
-       integer dimp,dimq,dimrs,dimr
-       real*8 a(1:dimp,1:dimq,1:dimrs)
-       real*8 b(1:dimq,1:dimp,1:dimr,1:dimr)
-c
-c     help variables
-c
-       integer p,q,r,s,rs
-       real*8 scalar
-c
-       if (dimr.gt.1) then
-c
-       rs=0
-       do 100 r=2,dimr
-       do 101 s=1,r-1
-c
-       do 102 q=1,dimq
-       do 103 p=1,dimp
-c
-       scalar=a(p,q,rs)
-       b(q,p,r,s)=-scalar
-       b(q,p,s,r)=scalar
-c
- 103    continue
- 102    continue
- 101    continue
- 100    continue
-c
-       end if
-c
-       do r=1,dimr
-       do p=1,dimp
-       do q=1,dimq
-       b(q,p,r,r)=0.0d0
-       end do
-       end do
-       end do
-c
-       return
-       end
-c
-#endif
