@@ -8,21 +8,6 @@
 * For more details see the full text of the license in the file        *
 * LICENSE or in <http://www.gnu.org/licenses/>.                        *
 ************************************************************************
-c
-c     this file contains following routines:
-c
-c     t3div
-c     t3dhlp1
-c     t3dhlp2
-c     t3dhlp3
-c     t3dhlp4
-c     t3dhlp5
-c     t3dhlp6
-c     t3dhlp7
-c     t3dhlp8
-c
-cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
-c
        subroutine t3div (wrk,wrksize,
      & mapdw,mapdv,ssw,mapdd1,mapid1,mapdd2,mapid2,
      & typdiv,i,j,k,symi,symj,symk,ec,rc)
@@ -504,227 +489,3 @@ c
 c Avoid unused argument warnings
       if (.false.) call Unused_integer(ssw)
        end
-c
-c     -----------------------------
-c
-       subroutine t3dhlp1 (w,v,dimp,dimq,dimr,denijk,ec,
-     & diagp,diagq,diagr,
-     & dimdiagp,dimdiagq,dimdiagr,addp,addq,addr)
-c
-c     this routine realize following procedure
-c     for symp.ne.symq.ne.symr
-c
-c     ec = sum(p,q,r) [ W(p,q,r) . V(p,q,r) / Dijkpqr ]
-c
-c     w      - W  matrix (I)
-c     v      - V  matrix (I)
-c     dimp   - dimension of p index (I)
-c     dimq   - dimension of q index (I)
-c     dimr   - dimension of r index (I)
-c     denijk - sum of i,j,k diagonal (other) F parts (I)
-c     ec     - energy contribution
-c     diagp  - vector of diagonal parts of symmetry p (I)
-c     diagq  - vector of diagonal parts of symmetry q (I)
-c     diagr  - vector of diagonal parts of symmetry r (I)
-c     dimdiagp - dimension of diagonal parts in symetry p (I)
-c     dimdiagq - dimension of diagonal parts in symetry q (I)
-c     dimdiagr - dimension of diagonal parts in symetry r (I)
-c     addp   - additional constant to p (Nocc) (I)
-c     addq   - additional constant to q (Nocc) (I)
-c     addr   - additional constant to r (Nocc) (I)
-c
-       integer dimp,dimq,dimr
-       integer dimdiagp,dimdiagq,dimdiagr,addp,addq,addr
-       real*8 ec,denijk
-       real*8 w(1:dimp,1:dimq,1:dimr)
-       real*8 v(1:dimp,1:dimq,1:dimr)
-       real*8 diagp(1:dimdiagp)
-       real*8 diagq(1:dimdiagq)
-       real*8 diagr(1:dimdiagr+dimr)
-c
-c     help variables
-c
-       integer p,q,r
-       real*8 denijkr,denijkqr,denijkpqr
-c
-       ec=0.0d0
-c
-       do 100 r=1,dimr
-       denijkr=denijk-diagr(addr+r)
-       do 101 q=1,dimq
-       denijkqr=denijkr-diagq(q+addq)
-       do 102 p=1,dimp
-       denijkpqr=denijkqr-diagp(p+addp)
-       ec=ec+w(p,q,r)*v(p,q,r)/denijkpqr
- 102    continue
- 101    continue
- 100    continue
-c
-       return
-       end
-c
-c     ----------------
-c
-       subroutine t3dhlp2 (w,v,dimp,dimpq,dimr,denijk,ec,
-     & diagp,diagr,
-     & dimdiagp,dimdiagr,addp,addr)
-c
-c     this routine realize following procedure
-c     for symp=symq.ne.symr
-c
-c     ec = sum(pq,r) [ W(pq,r) . V(pq,r) / Dijkpqr ]
-c
-c     w      - W  matrix (I)
-c     v      - V  matrix (I)
-c     dimp   - dimension of p (q) index (I)
-c     dimpq  - dimension of pq index (I)
-c     dimr   - dimension of r index (I)
-c     denijk - sum of i,j,k diagonal (other) F parts (I)
-c     ec     - energy contribution
-c     diagp  - vector of diagonal parts of symmetry p (q) (I)
-c     diagr  - vector of diagonal parts of symmetry r (I)
-c     dimdiagp - dimension of diagonal parts in symetry p (I)
-c     dimdiagr - dimension of diagonal parts in symetry r (I)
-c     addp   - additional constant to p (Nocc) (I)
-c     addr   - additional constant to r (Nocc) (I)
-c
-       integer dimp,dimpq,dimr
-       integer dimdiagp,dimdiagr,addp,addr
-       real*8 ec,denijk
-       real*8 w(1:dimpq,1:dimr)
-       real*8 v(1:dimpq,1:dimr)
-       real*8 diagp(1:dimdiagp)
-       real*8 diagr(1:dimdiagr)
-c
-c     help variables
-c
-       integer p,q,r,pq
-       real*8 denijkr,denijkpr,denijkpqr
-c
-       ec=0.0d0
-c
-       do 100 r=1,dimr
-       denijkr=denijk-diagr(addr+r)
-       pq=0
-       do 101 p=2,dimp
-       denijkpr=denijkr-diagp(p+addp)
-       do 102 q=1,p-1
-       pq=pq+1
-       denijkpqr=denijkpr-diagp(q+addp)
-       ec=ec+w(pq,r)*v(pq,r)/denijkpqr
- 102    continue
- 101    continue
- 100    continue
-c
-       return
-       end
-c
-c     ----------------
-c
-       subroutine t3dhlp3 (w,v,dimp,dimq,dimqr,denijk,ec,
-     & diagp,diagq,
-     & dimdiagp,dimdiagq,addp,addq)
-c
-c     this routine realize following procedure
-c     for symp.ne.symq=symr
-c
-c     ec = sum(p,qr) [ W(p,qr) . V(p,qr) / Dijkpqr ]
-c
-c     w      - W  matrix (I)
-c     v      - V  matrix (I)
-c     dimp   - dimension of p index (I)
-c     dimq   - dimension of q (r) index (I)
-c     dimqr  - dimension of r index (I)
-c     denijk - sum of i,j,k diagonal (other) F parts (I)
-c     ec     - energy contribution
-c     diagp  - vector of diagonal parts of symmetry p (I)
-c     diagq  - vector of diagonal parts of symmetry q (I)
-c     dimdiagp - dimension of diagonal parts in symetry p (I)
-c     dimdiagq - dimension of diagonal parts in symetry q (I)
-c     addp   - additional constant to p (Nocc) (I)
-c     addq   - additional constant to q (Nocc) (I)
-c
-       integer dimp,dimq,dimqr
-       integer dimdiagp,dimdiagq,addp,addq
-       real*8 ec,denijk
-       real*8 w(1:dimp,1:dimqr)
-       real*8 v(1:dimp,1:dimqr)
-       real*8 diagp(1:dimdiagp)
-       real*8 diagq(1:dimdiagq)
-c
-c     help variables
-c
-       integer p,q,r,qr
-       real*8 denijkq,denijkqr,denijkpqr
-c
-       ec=0.0d0
-c
-       qr=0
-       do 100 q=2,dimq
-       denijkq=denijk-diagq(addq+q)
-       do 101 r=1,q-1
-       denijkqr=denijkq-diagq(r+addq)
-       qr=qr+1
-       do 102 p=1,dimp
-       denijkpqr=denijkqr-diagp(p+addp)
-       ec=ec+w(p,qr)*v(p,qr)/denijkpqr
- 102    continue
- 101    continue
- 100    continue
-c
-       return
-       end
-c
-c     ----------------
-c
-       subroutine t3dhlp4 (w,v,dimp,dimpqr,denijk,ec,
-     & diagp,
-     & dimdiagp,addp)
-c
-c     this routine realize following procedure
-c     for symp=symq=symr
-c
-c     ec = sum(pqr) [ W(pqr) . V(pqr) / Dijkpqr ]
-c
-c     w      - W  matrix (I)
-c     v      - V  matrix (I)
-c     dimp   - dimension of p index (I)
-c     dimpqr - dimension of q index (I)
-c     denijk - sum of i,j,k diagonal (other) F parts (I)
-c     ec     - energy contribution
-c     diagp  - vector of diagonal parts of symmetry p (I)
-c     dimdiagp - dimension of diagonal parts in symetry p (I)
-c     addp   - additional constant to p (Nocc) (I)
-c
-       integer dimp,dimpqr
-       integer dimdiagp,addp
-       real*8 ec,denijk
-       real*8 w(1:dimpqr)
-       real*8 v(1:dimpqr)
-       real*8 diagp(1:dimdiagp)
-c
-c     help variables
-c
-       integer p,q,r,pqr
-       real*8 denijkp,denijkpq,denijkpqr
-c
-       ec=0.0d0
-c
-       pqr=0
-       do 100 p=3,dimp
-       denijkp=denijk-diagp(p+addp)
-       do 101 q=2,p-1
-       denijkpq=denijkp-diagp(q+addp)
-       do 102 r=1,q-1
-       denijkpqr=denijkpq-diagp(r+addp)
-       pqr=pqr+1
-       ec=ec+w(pqr)*v(pqr)/denijkpqr
- 102    continue
- 101    continue
- 100    continue
-c
-       return
-       end
-c
-c     ----------------
-c
