@@ -8,7 +8,6 @@
 * For more details see the full text of the license in the file        *
 * LICENSE or in <http://www.gnu.org/licenses/>.                        *
 ************************************************************************
-c
         subroutine o3v3jk (wrk,wrksize,NvGrp,maxdim,LunAux)
 c
 c
@@ -95,10 +94,10 @@ c       t2(A',B',IJ)  T2xxyy xx - Group of A'
 c                            yy - Group of B'
 c
 c
+        use Para_Info, only: MyRank
         implicit none
 #include "chcc1.fh"
-#include "chcc_parcc.fh"
-#include "para_info.fh"
+#include "parcc.fh"
 #include "o3v3.fh"
 #include "chcc_files.fh"
 #include "wrk.fh"
@@ -603,365 +602,3 @@ c        call Chck_A (wrk(PossA))
 c@@
         return
         end
-c
-c        ---------------------
-c
-        subroutine Chck_Hvo (Hvo)
-c
-c        check Hvo
-c
-        implicit none
-#include "chcc1.fh"
-        real*8 Hvo(1:nv,1:no)
-c
-c        help var
-        integer i,a,j,b,bad,tot
-        real*8 s
-c
-        bad=0
-        tot=0
-c
-        do i=1,no
-        do a=1,nv
-c
-          s=0.0d0
-c
-          do j=1,no
-          do b=1,nv
-          s=s+(2.0d0*Q21(b,j,a,i)-Q21(b,i,a,j))*T1c(b,j)
-          end do
-          end do
-c
-          Hvoc(a,i)=s
-c
-          if (abs(Hvo(a,i)-s).gt.1.0d-10) then
-          bad=bad+1
-          end if
-          tot=tot+1
-c
-        end do
-        end do
-c
-        write (6,*) ' Hvo Chck :',bad
-c
-        return
-        end
-c
-c        ---------------------
-c
-        subroutine Chck_Hoo (Hoo)
-c
-c        check Hoo
-c
-        implicit none
-#include "chcc1.fh"
-        real*8 Hoo(1:no,1:no)
-c
-c        help var
-        integer i,u,j,a,b,bad
-        real*8 s
-c
-        bad=0
-c
-        do i=1,no
-        do u=1,no
-c
-          s=0.0d0
-          do j=1,no
-          do a=1,nv
-          do b=1,nv
-          s=s+(2.0d0*Q21(a,i,b,j)-Q21(a,j,b,i))*
-     c        (T2c(a,b,u,j)+T1c(a,u)*T1c(b,j))
-          end do
-          end do
-          end do
-c
-          Hooc(i,u)=s
-c
-          if (abs(Hoo(i,u)-s).gt.1.0d-10) then
-          bad=bad+1
-c          write (6,*) Hoo(i,u),s
-          end if
-c
-        end do
-        end do
-c
-        write (6,*) ' Hoo Chck :',bad
-c
-        return
-        end
-c
-c        ---------------------
-c
-        subroutine Chck_Hvv (Hvv)
-c
-c        check Hoo
-c
-        implicit none
-#include "chcc1.fh"
-        real*8 Hvv(1:nv,1:nv)
-c
-c        help var
-        integer i,j,a,b,be,bad
-        real*8 s
-c
-        bad=0
-c
-        do be=1,nv
-        do a=1,nv
-c
-          s=0.0d0
-          do i=1,no
-          do j=1,no
-          do b=1,nv
-          s=s+(2.0d0*Q21(a,i,b,j)-Q21(a,j,b,i))*
-     c        (T2c(be,b,i,j)+T1c(be,i)*T1c(b,j))
-          end do
-          end do
-          end do
-          s=-s
-c
-          Hvvc(be,a)=s
-c
-          if (abs(Hvv(a,be)-s).gt.1.0d-10) then
-          bad=bad+1
-c          write (6,*) Hoo(i,u),s,
-          end if
-c
-        end do
-        end do
-c
-        write (6,*) ' Hvv Chck :',bad
-c
-        return
-        end
-c
-c        ---------------------
-c
-        subroutine Chck_A (AA)
-c
-c        check AA(ij,u,v)
-c
-        implicit none
-#include "chcc1.fh"
-        real*8 AA(1:no*(no+1)/2,1:no,1:no)
-c
-c        help var
-        integer i,j,ij,u,v,a,b,bad
-        real*8 s
-c
-        bad=0
-c
-        ij=0
-        do i=1,no
-        do j=1,i
-        ij=ij+1
-c
-        do u=1,no
-        do v=1,no
-c
-          s=Q0(u,i,v,j)
-c
-          do a=1,nv
-           s=s+Q1(a,j,u,i)*T1c(a,v)
-          end do
-c
-          do a=1,nv
-           s=s+Q1(a,i,v,j)*T1c(a,u)
-          end do
-c
-          do a=1,nv
-          do b=1,nv
-           s=s+Q21(a,i,b,j)*(T2c(a,b,u,v)+T1c(a,u)*T1c(b,v))
-          end do
-          end do
-c
-          Ac(i,j,u,v)=s
-c
-c          write (6,99) i,j,u,v,AA(ij,u,v),s,AA(ij,u,v)-s
-c99          format (4(i2,1x),3(f15.10,1x))
-          if (abs(AA(ij,u,v)-s).gt.1.0d-10) then
-          bad=bad+1
-          end if
-c
-        end do
-        end do
-        end do
-        end do
-c
-c
-        do u=1,no
-        do v=1,no
-        do i=2,no
-        do j=1,i-1
-          Ac(j,i,v,u)=Ac(i,j,u,v)
-        end do
-        end do
-        end do
-        end do
-c
-        write (6,*) ' A   Chck :',bad
-c
-        return
-        end
-c
-c        ---------------------
-c
-        subroutine Chck_Tjedna (T1)
-c
-c        check T1
-c
-        implicit none
-#include "chcc1.fh"
-        real*8 T1(1:nv,1:no)
-c
-c        help var
-        integer u,a,bad
-        real*8 s
-c
-        bad=0
-c
-        do u=1,no
-        do a=1,nv
-          s=T1c(a,u)
-          if (abs(T1(a,u)-s).gt.1.0d-10) then
-          bad=bad+1
-          T1(a,u)=s
-          end if
-        end do
-        end do
-c
-        write (6,*) ' Tjedna   Chck :',bad
-c
-c
-        return
-        end
-c
-c        ---------------------
-c
-        subroutine Chck_Th (T2)
-c
-c        check
-c       T2 = T2(a,b,j_b,u_a)
-c
-        implicit none
-#include "chcc1.fh"
-        real*8 T2(1:nv*(nv+1)/2,1:no,1:no)
-c
-c        help var
-        integer u,a,b,j,bad,ab
-        real*8 s
-c
-        bad=0
-c
-        do u=1,no
-        do j=1,no
-        ab=0
-        do a=1,nv
-        do b=1,a
-        ab=ab+1
-c
-          s=T2c(a,b,j,u)+T1c(a,j)*T1c(b,u)
-c
-          if (abs(T2(ab,j,u)-s).gt.1.0d-10) then
-          T2(ab,j,u)=s
-          bad=bad+1
-          end if
-c
-        end do
-        end do
-        end do
-        end do
-c
-        write (6,*) ' T2  Chck :',bad
-c
-        return
-        end
-c
-c        ---------------------
-c
-        subroutine Chck_V (VV)
-c
-c        check  V
-c
-        implicit none
-#include "chcc1.fh"
-        real*8 VV(1:nv,1:no,1:no,1:no)
-c
-c        help var
-        integer be,v,u,j,b,bad
-        real*8 s
-c
-        bad=0
-c
-        do j=1,no
-        do u=1,no
-        do v=1,no
-        do be=1,nv
-c
-          s=0.0d0
-          do b=1,nv
-          s=s+Q22(be,b,u,j)*T1c(b,v)
-          end do
-c
-          if (abs(VV(be,v,u,j)-s).gt.1.0d-10) then
-          VV(be,v,u,j)=s
-          bad=bad+1
-          end if
-c
-        end do
-        end do
-        end do
-        end do
-c
-        write (6,*) ' V  Chck :',bad
-c
-        return
-        end
-c
-c        ---------------------
-c
-        subroutine Chck_T17g (V,dima,adda,dimbe,addbe)
-c
-c        check V(a',u) -
-c        sum(be',b,i)  (b,i|be',a') . [ 2 Ta(b,be',i,u) - Ta(b,be',u,i)]
-c
-        implicit none
-#include "chcc1.fh"
-        integer dima,adda,dimbe,addbe
-        real*8 V(1:dima,1:no)
-c
-c        help var
-        integer a,u,be,b,i,bad,tot
-        real*8 s
-c
-        tot=0
-        bad=0
-c
-        do u=1,no
-        do a=adda+1,adda+dima
-c
-          s=0.0d0
-          do b=1,nv
-          do be=1+addbe,addbe+dimbe
-          do i=1,no
-c
-           s=s+Q3(be,a,b,i)*(2.0d0*(T2c(be,b,u,i)+T1c(be,u)*T1c(b,i))
-     c                         -(T2c(be,b,i,u)+T1c(be,i)*T1c(b,u)))
-          end do
-          end do
-          end do
-c
-          if (abs(V(a-adda,u)-s).gt.1.0d-10) then
-          bad=bad+1
-          end if
-          tot=tot+1
-c
-        end do
-        end do
-c
-        write (6,*) ' T17 Chck :',bad,tot
-c
-        return
-        end
-c
