@@ -16,20 +16,20 @@ C     Thomas Bondo Pedersen, March 2006.
 C
 C     Purpose: prescreening of diagonal.
 C
+      use ChoArr, only: iSP2F
       Implicit Real*8 (a-h,o-z)
 #include "cholesky.fh"
-#include "choptr.fh"
-#include "WrkSpc.fh"
+#include "stdalloc.fh"
+
+      Real*8, Allocatable:: TMax(:,:)
 
       iTri(i,j)=max(i,j)*(max(i,j)-3)/2+i+j
-      Tmax(i,j)=Work(ip_Tmax-1+nShell*(j-1)+i)
 
       If (Cho_PreScreen) Then ! prescreening with approx. diagonal
 
-         l_Tmax = nShell**2
-         Call GetMem('Cho_Tmax','Allo','Real',ip_Tmax,l_Tmax)
+         Call mma_allocate(Tmax,nShell,nShell,Label='nShell')
 
-         Call Shell_MxSchwz(nShell,Work(ip_Tmax))
+         Call Shell_MxSchwz(nShell,Tmax)
          Tmax_All = Tmax(1,1)
          Do i = 2,nShell
             Do j = 1,i
@@ -46,29 +46,27 @@ C
                End If
             End Do
          End Do
-         l_iSP2F = nnShl
-         Call GetMem('SP2F','Allo','Inte',ip_iSP2F,l_iSP2F)
+         Call mma_allocate(iSP2F,nnShl,Label='iSP2F')
 
          ij = 0
          Do i = 1,nShell
             Do j = 1,i
                If (Tmax_All*Tmax(i,j) .gt. Tau) Then
                   ij = ij + 1
-                  iWork(ip_iSP2F-1+ij) = iTri(i,j)
+                  iSP2F(ij) = iTri(i,j)
                End If
             End Do
          End Do
 
-         Call GetMem('Cho_Tmax','Free','Real',ip_Tmax,l_Tmax)
+         Call mma_deallocate(TMax)
 
       Else ! no prescreening, include all shell pairs.
 
          nnShl = nnShl_Tot
-         l_iSP2F = nnShl
-         Call GetMem('SP2F','Allo','Inte',ip_iSP2F,l_iSP2F)
+         Call mma_allocate(iSP2F,nnShl,Label='iSP2F')
 
          Do ij = 1,nnShl
-            iWork(ip_iSP2F-1+ij) = ij
+            iSP2F(ij) = ij
          End Do
 
       End If
