@@ -37,9 +37,9 @@ C     ------------------------
          IOPT = 2
          CALL CHO_IODIAG(DIAG,IOPT)
       ELSE
-         CALL CHO_DZERO(DIAG,NNBSTRT(1))
-         CALL CHO_IZERO(INDRSH,NNBSTRT(1))
-         CALL CHO_IZERO(INDRED,NNBSTRT(1))
+         CALL FZERO(DIAG,NNBSTRT(1))
+         CALL IZERO(INDRSH,NNBSTRT(1))
+         CALL IZERO(INDRED,NNBSTRT(1))
          CALL CHO_RDDBUF(DIAG,BUF,IBUF,INDRSH,INDRED,
      &                   LENBUF,MMBSTRT,NDUMP)
          CALL CHO_GADGOP(DIAG,NNBSTRT(1),'+')
