@@ -26,7 +26,7 @@ C
          IADR = 0
          CALL IDAFILE(LUMAP,IOPT,INTMAP,NDIM,IADR)
       ELSE
-         CALL CHO_IZERO(INTMAP,SIZE(INTMAP))
+         CALL IZERO(INTMAP,SIZE(INTMAP))
       END IF
 
       END
