@@ -16,12 +16,11 @@ C              from unit LUNIT. LUOUT is the unit of the output file
 C              which is stored internally in the Cholesky program as
 C              LUPRI (in cholesky.fh).
 C
+      use ChoSubScr, only: Cho_SScreen, SSTau, SubScrStat, SSNorm
 #include "implicit.fh"
       LOGICAL DFONLY
 #include "cholesky.fh"
-#include "chosubscr.fh"
 #include "choprint.fh"
-#include "chosimri.fh"
 
       CHARACTER*7 SECNAM
       PARAMETER (SECNAM = 'CHO_INP')
@@ -831,8 +830,8 @@ C     ----------------
          END IF
       END IF
 
-C     Put decomposition threshold in info.fh.
-C     ---------------------------------------
+C     Put decomposition threshold in RICD_Info.
+C     -----------------------------------------
 
       CALL PUT_THR_CHO(THRCOM)
 
@@ -860,6 +859,10 @@ C     ------------
       GO TO 9999
 
  9999 CALL CHO_QUIT('Error in '//SECNAM,IRC)
+      RETURN
+#ifdef _WARNING_WORKAROUND_
+      IF (.FALSE.) Call Unused_character(Line)
+#endif
       END
 ************************************************************************
 *                                                                      *
