@@ -12,9 +12,10 @@
 C
 C     Purpose: MOLCAS interface to Cholesky decomposition driver.
 C
+      use ChoArr, only: MySP
 #include "implicit.fh"
 #include "cholesky.fh"
-#include "WrkSpc.fh"
+#include "stdalloc.fh"
 
       CHARACTER*11 SECNAM
       PARAMETER (SECNAM = 'CHO_MCA_DRV')
@@ -80,7 +81,10 @@ C     ----------------------------
          CALL CHO_QUIT('End of Test (in '//SECNAM//')',100)
       END IF
 
-      CALL GASYNC
+      CALL GASYNC()
       Call Free_iSD()
 
+      If (Allocated(MySP)) Call mma_deallocate(MySP)
+      Call Cho_X_dealloc(irc)
+
       END
