@@ -17,21 +17,18 @@ C     Notes:
 C        LOCPRT: flag for printing the shell quadruple to output;
 C                output format differs depending on IFCSEW.
 C
+      use ChoArr, only: nBstSh, iSP2F
       IMPLICIT REAL*8 (A-H,O-Z)
       EXTERNAL Integral_WrOut_Cho
       REAL*8   XINT(LINT)
       LOGICAL  LOCPRT
 #include "itmax.fh"
 #include "cholesky.fh"
-#include "choptr.fh"
-#include "WrkSpc.fh"
 
       CHARACTER*13 SECNAM
       PARAMETER (SECNAM = 'CHO_MCA_INT_1')
 
       ITRI(I,J) = MAX(I,J)*(MAX(I,J)-3)/2 + I + J
-      ISP2F(I)=IWORK(ip_iSP2F-1+I)
-      NBSTSH(I)=IWORK(ip_NBSTSH-1+I)
 
 C     Initializations.
 C     ----------------
@@ -39,11 +36,6 @@ C     ----------------
       CALL CHO_INVPCK(ISP2F(IJ),I,J,.TRUE.)
       CALL CHO_INVPCK(ISP2F(KL),K,L,.TRUE.)
 
-      NIJ = MAX(I,J)*(MAX(I,J)+1)/2+MIN(I,J)
-      NKL = MAX(K,L)*(MAX(K,L)+1)/2+MIN(K,L)
-      XIJ = DBLE(MAX(NIJ,NKL))
-      XKL = DBLE(MIN(NIJ,NKL))
-
       SHCD = IJ
       SHAB = KL
       SHC = I
