@@ -42,10 +42,10 @@ C     ------------------------------------------------------
 
       nDim = nSym*nnShl
       IndRed(:,2)=0
-      Call Cho_iZero(iiBstRSh(:,:,2),nDim)
-      Call Cho_iZero(nnBstRSh(:,:,2),nDim)
-      Call Cho_iZero(iiBstR(:,2),nSym)
-      Call Cho_iZero(nnBstR(:,2),nSym)
+      Call iZero(iiBstRSh(:,:,2),nDim)
+      Call iZero(nnBstRSh(:,:,2),nDim)
+      Call iZero(iiBstR(:,2),nSym)
+      Call iZero(nnBstR(:,2),nSym)
       nnBstRT(2) = 0
 
 C     Set local nnBstRSh counter at location 2.
