@@ -19,7 +19,7 @@ C
 
       MULD2H(I,J)=IEOR(I-1,J-1)+1
 
-      CALL CHO_IZERO(NNBST,NSYM)
+      CALL IZERO(NNBST,NSYM)
       DO ISYMA = 1,NSYM
          DO ISYMB = 1,ISYMA-1
             NABPK(ISYMA,ISYMB) = NBAS(ISYMA)*NBAS(ISYMB)
