@@ -26,13 +26,13 @@ C
       Logical Delete
       Real*8  EMP2
       Integer irc
-#include "WrkSpc.fh"
+
 #include "chomp2_cfg.fh"
 #include "chomp2.fh"
 #include "cholesky.fh"
+#include "stdalloc.fh"
 
-      Character*21 SecNam
-      Parameter (SecNam='ChoLSOSMP2_Energy_Fll')
+      Character(LEN=21), Parameter:: SecNam='ChoLSOSMP2_Energy_Fll'
 
       Integer nEnrVec(8)
 
@@ -41,7 +41,7 @@ C
       Integer iSym
       Integer Nai
       Integer need
-      Integer ip, l
+      Integer l
 
       ! check if there is enough memory to read through vector files
       ! only once
@@ -60,7 +60,7 @@ C
          End If
       End Do
       need=l_X+2*l_V
-      Call GetMem('LSMTst','Max ','Real',ip,l)
+      Call mma_maxDBLE(l)
       l=l-100
       If (l.lt.1 .or. need.ge.l) Then ! not enough memory for one read
          Call ChoLSOSMP2_Energy_Fll2(N,w,t,EOcc,EVir,Delete,EMP2,irc)
@@ -97,24 +97,21 @@ C
       Logical Delete
       Real*8  EMP2
       Integer irc
-#include "WrkSpc.fh"
 #include "chomp2_cfg.fh"
 #include "chomp2.fh"
 #include "cholesky.fh"
+#include "stdalloc.fh"
 
-      Character*22 SecNam
-      Parameter (SecNam='ChoLSOSMP2_Energy_Fll1')
+      Character(LEN=22), Parameter:: SecNam='ChoLSOSMP2_Energy_Fll1'
 
-      Real*8   dDot_
-      external ddot_
+      Real*8, external:: dDot_
 
       Integer nEnrVec(8)
 
       Integer iClos
       Integer iTyp
       Integer iSym
-      Integer ip_X, l_X
-      Integer ip_V, l_V, ip_SV
+      Integer l_X
       Integer Nai
       Integer nBlock
       Integer iOpt, iAddr, l_Tot
@@ -129,9 +126,12 @@ C
 
       Real*8  tq, Eq
 
+      Real*8, Allocatable:: X(:), V(:,:)
+
       Integer j, k
       Real*8  epsi, epsa
       Integer MulD2h
+
       epsi(j,k)=EOcc(iOcc(k)+j)
       epsa(j,k)=EVir(iVir(k)+j)
       MulD2h(j,k)=iEOr(j-1,k-1)+1
@@ -179,20 +179,18 @@ C
             ! set vector block size and allocate X matrix
             l_X=min(Laplace_BlockSize,nEnrVec(iSym))
             l_X=l_X**2
-            Call GetMem('LSMX','Allo','Real',ip_X,l_X)
+            Call mma_allocate(X,l_X,Label='X')
             ! compute number of vector blocks
             nBlock=(nEnrVec(iSym)-1)/Laplace_BlockSize+1
             ! open vector file
             Call ChoMP2_OpenF(1,iTyp,iSym)
             ! allocate memory for vectors
             l_Tot=Nai*nEnrVec(iSym)
-            l_V=2*l_Tot
-            Call GetMem('LSMV','Allo','Real',ip_V,l_V)
-            ip_SV=ip_V+l_Tot
+            Call mma_allocate(V,l_Tot,2,Label='V')
             ! Read all vectors
             iOpt=2
             iAddr=1
-            Call dDAFile(lUnit_F(iSym,iTyp),iOpt,Work(ip_V),l_Tot,iAddr)
+            Call dDAFile(lUnit_F(iSym,iTyp),iOpt,V(:,1),l_Tot,iAddr)
             ! loop over Laplace grid
             Do q=1,N
                ! init energy for this q
@@ -200,19 +198,19 @@ C
                ! scale grid point by 1/2
                tq=0.5d0*t(q)
                ! scale vectors
-               Call dCopy_(l_Tot,Work(ip_V),1,Work(ip_SV),1)
+               Call dCopy_(l_Tot,V(:,1),1,V(:,2),1)
                Do iVec=1,nEnrVec(iSym)
-                  ip0=ip_SV-1+Nai*(iVec-1)
+                  ip0=Nai*(iVec-1)
                   Do iSymi=1,nSym
                      iSyma=MulD2h(iSym,iSymi)
                      ip1=ip0+iT1am(iSyma,iSymi)
                      Do i=1,nOcc(iSymi)
                         Call dScal_(nVir(iSyma),exp(epsi(i,iSymi)*tq),
-     &                             Work(ip1+nVir(iSyma)*(i-1)+1),1)
+     &                             V(ip1+nVir(iSyma)*(i-1)+1,2),1)
                      End Do
                      Do a=1,nVir(iSyma)
                         Call dScal_(nOcc(iSymi),exp(-epsa(a,iSyma)*tq),
-     &                             Work(ip1+a),nVir(iSyma))
+     &                             V(ip1+a,2),nVir(iSyma))
                      End Do
                   End Do
                End Do
@@ -220,28 +218,29 @@ C
 !              X(J,K) = sum_ai L(ai,J)*L(ai,K)*exp(-(e(a)-a(i))*t(q)/2)
 !              Eq += w(q)*sum_JK [X(J,K)]**2
                Do jBlock=1,nBlock
-                  ipj=ip_SV+Nai*Laplace_BlockSize*(jBlock-1)
+                  ipj=1+Nai*Laplace_BlockSize*(jBlock-1)
                   If (jBlock.eq.nBlock) Then
                      nVecj=nEnrVec(iSym)-Laplace_BlockSize*(nBlock-1)
                   Else
                      nVecj=Laplace_BlockSize
                   End If
                   Do iBlock=jBlock,nBlock
-                     ipi=ip_SV+Nai*Laplace_BlockSize*(iBlock-1)
+                     ipi=1+Nai*Laplace_BlockSize*(iBlock-1)
                      If (iBlock.eq.nBlock) Then
                         nVeci=nEnrVec(iSym)-Laplace_BlockSize*(nBlock-1)
                      Else
                         nVeci=Laplace_BlockSize
                      End If
                      Call dGEMM_('T','N',nVeci,nVecj,Nai,
-     &                           1.0d0,Work(ipi),Nai,Work(ipj),Nai,
-     &                           0.0d0,Work(ip_X),nVeci)
+     &                           1.0d0,V(ipi,2),Nai,
+     &                                 V(ipj,2),Nai,
+     &                           0.0d0,X,nVeci)
                      If (iBlock.eq.jBlock) Then
                         Eq=Eq
-     &               +0.5d0*dDot_(nVeci*nVecj,Work(ip_X),1,Work(ip_X),1)
+     &               +0.5d0*dDot_(nVeci*nVecj,X,1,X,1)
                      Else
                         Eq=Eq
-     &                     +dDot_(nVeci*nVecj,Work(ip_X),1,Work(ip_X),1)
+     &                     +dDot_(nVeci*nVecj,X,1,X,1)
                      End If
                   End Do
                End Do
@@ -249,8 +248,8 @@ C
                EMP2=EMP2-w(q)*Eq
             End Do
             ! deallocate memory
-            Call GetMem('LSMV','Free','Real',ip_V,l_V)
-            Call GetMem('LSMX','Free','Real',ip_X,l_X)
+            Call mma_deallocate(V)
+            call mma_deallocate(X)
             ! close (and possibly delete) vector file
             Call ChoMP2_OpenF(iClos,iTyp,iSym)
          End If
@@ -281,19 +280,19 @@ C
       Logical Delete
       Real*8  EMP2
       Integer irc
-#include "WrkSpc.fh"
+
+#include "real.fh"
+#include "cholesky.fh"
 #include "chomp2_cfg.fh"
 #include "chomp2.fh"
-#include "cholesky.fh"
+#include "stdalloc.fh"
 
-      Character*22 SecNam
-      Parameter (SecNam='ChoLSOSMP2_Energy_Fll2')
+      Character(LEN=22), Parameter:: SecNam='ChoLSOSMP2_Energy_Fll2'
 
-      Real*8   dDot_
-      external ddot_
+      Real*8, External:: dDot_
 
 #if !defined (_I8_) || defined (_DEBUGPRINT_)
-      Character*2 Unt
+      Character(LEN=2) Unt
       Real*8  Byte
 #endif
 
@@ -301,8 +300,7 @@ C
 
       Integer iTyp
       Integer iSym
-      Integer ip_X, l_X
-      Integer ip_V, l_V
+      Integer l_X
       Integer Nai
       Integer nBlock
       Integer iOpt, iAddr, l_Tot
@@ -321,9 +319,12 @@ C
       Real*8  lX, xM, xn, xb, xbp
       Real*8  tq, Eq, wq
 
+      Real*8, Allocatable:: X(:), V(:)
+
       Integer j, k
       Real*8  epsi, epsa
       Integer MulD2h
+
       epsi(j,k)=EOcc(iOcc(k)+j)
       epsa(j,k)=EVir(iVir(k)+j)
       MulD2h(j,k)=iEOr(j-1,k-1)+1
@@ -332,7 +333,7 @@ C
       irc=0
 
       ! init energy
-      EMP2=0.0d0
+      EMP2=Zero
 
       ! check input (incl. common block variables)
       If (N.ne.Laplace_nGridPoints) Then
@@ -354,7 +355,7 @@ C
       End If
 
       ! allocate X
-      lX=0.0d0
+      lX=Zero
       Do iSym=1,nSym
          If (nT1am(iSym).gt.0 .and. nEnrVec(iSym).gt.0) Then
             bsize=min(Laplace_BlockSize,nEnrVec(iSym))
@@ -386,15 +387,14 @@ C
          Return
       End If
 #endif
-      Call GetMem('LSMX','Allo','Real',ip_X,l_X)
+      Call mma_allocate(X,l_X,Label='X')
 
       ! allocate vector array
       Nai=nT1am(1)*nEnrVec(1)
       Do iSym=2,nSym
          Nai=max(Nai,nT1am(iSym)*nEnrVec(iSym))
       End Do
-      l_V=Nai
-      Call GetMem('LSMV','Allo','Real',ip_V,l_V)
+      Call mma_allocate(V,Nai,Label='V')
 
       ! compute energy correction
       Do q=1,N
@@ -414,7 +414,7 @@ C
                lenX=nEnrVec(iSym)*(nEnrVec(iSym)+1)/2
      &             +(nBlock-1)*(bsize*(bsize-1)/2)
      &             +blast*(blast-1)/2
-               Call fZero(Work(ip_X),lenX)
+               X(1:lenX)=Zero
                ! open file, read vectors, close file
                ! do not delete file here - it may be needed later
                ! (because of the loop over q)
@@ -422,12 +422,12 @@ C
                iOpt=2
                l_Tot=Nai*nEnrVec(iSym)
                iAddr=1
-               Call dDAFile(lUnit_F(iSym,iTyp),iOpt,Work(ip_V),
+               Call dDAFile(lUnit_F(iSym,iTyp),iOpt,V,
      &                      l_Tot,iAddr)
                Call ChoMP2_OpenF(2,iTyp,iSym)
                ! scale vectors
                Do iVec=1,nEnrVec(iSym)
-                  ip0=ip_V-1+Nai*(iVec-1)
+                  ip0=Nai*(iVec-1)
                   Do iSymi=1,nSym
                      If (nOcc(iSymi).gt.0) Then
                         iSyma=MulD2h(iSym,iSymi)
@@ -435,12 +435,12 @@ C
                         Do i=1,nOcc(iSymi)
                            Call dScal_(nVir(iSyma),
      &                                exp(epsi(i,iSymi)*tq),
-     &                                Work(ip1+nVir(iSyma)*(i-1)+1),1)
+     &                                V(ip1+nVir(iSyma)*(i-1)+1),1)
                         End Do
                         Do a=1,nVir(iSyma)
                            Call dScal_(nOcc(iSymi),
      &                                exp(-epsa(a,iSyma)*tq),
-     &                                Work(ip1+a),nVir(iSyma))
+     &                                V(ip1+a),nVir(iSyma))
                         End Do
                      End If
                   End Do
@@ -448,9 +448,9 @@ C
                ! loop over vector blocks to compute
                ! X(J,K) +=
                ! sum_ai L(ai,J)*L(ai,K)*exp(-(e(a)-e(i))*t(q)/2)
-               ipX=ip_X
+               ipX=1
                Do jBlock=1,nBlock
-                  ipj=ip_V+Nai*Laplace_BlockSize*(jBlock-1)
+                  ipj=1+Nai*Laplace_BlockSize*(jBlock-1)
                   If (jBlock.eq.nBlock) Then
                      nVecj=nEnrVec(iSym)
      &                    -Laplace_BlockSize*(nBlock-1)
@@ -458,7 +458,7 @@ C
                      nVecj=Laplace_BlockSize
                   End If
                   Do iBlock=jBlock,nBlock
-                     ipi=ip_V+Nai*Laplace_BlockSize*(iBlock-1)
+                     ipi=1+Nai*Laplace_BlockSize*(iBlock-1)
                      If (iBlock.eq.nBlock) Then
                         nVeci=nEnrVec(iSym)
      &                       -Laplace_BlockSize*(nBlock-1)
@@ -466,23 +466,24 @@ C
                         nVeci=Laplace_BlockSize
                      End If
                      Call dGEMM_('T','N',nVeci,nVecj,Nai,
-     &                          1.0d0,Work(ipi),Nai,Work(ipj),Nai,
-     &                          1.0d0,Work(ipX),nVeci)
+     &                          1.0d0,V(ipi),Nai,
+     &                                V(ipj),Nai,
+     &                          1.0d0,X(ipX),nVeci)
                      ipX=ipX+nVeci*nVecj
                   End Do
                End Do
 #if defined (_DEBUGPRINT_)
-               If (lenX.ne.(ipX-ip_X)) Then
+               If (lenX.ne.(ipX-1)) Then
                   Call WarningMessage(2,
      &                          SecNam//': dimension problem [1]')
                   Write(6,'(A,I10,A,I10)')
-     &            'lenX=',lenX,' ipX-ip_X=',ipX-ip_X
+     &            'lenX=',lenX,' ipX-1=',ipX-1
                   Call Abend()
                End If
 #endif
                ! compute energy contribution
                ! Eq += sum_JK [X(J,K)]**2
-               ipX=ip_X
+               ipX=1
                Do jBlock=1,nBlock
                   If (jBlock.eq.nBlock) Then
                      nVecj=nEnrVec(iSym)
@@ -499,20 +500,20 @@ C
                      End If
                      If (iBlock.eq.jBlock) Then
                         Eq=Eq+0.5d0*dDot_(nVeci*nVecj,
-     &                                   Work(ipX),1,Work(ipX),1)
+     &                                   X(ipX),1,X(ipX),1)
                      Else
                         Eq=Eq+dDot_(nVeci*nVecj,
-     &                             Work(ipX),1,Work(ipX),1)
+     &                             X(ipX),1,X(ipX),1)
                      End If
                      ipX=ipX+nVeci*nVecj
                   End Do
                End Do
 #if defined (_DEBUGPRINT_)
-               If (lenX.ne.(ipX-ip_X)) Then
+               If (lenX.ne.(ipX-1)) Then
                   Call WarningMessage(2,
      &                             SecNam//': dimension problem [2]')
                   Write(6,'(A,I10,A,I10)')
-     &            'lenX=',lenX,' ipX-ip_X=',ipX-ip_X
+     &            'lenX=',lenX,' ipX-1=',ipX-1
                   Call Abend()
                End If
 #endif
@@ -525,8 +526,8 @@ C
       End Do
 
       ! deallocations
-      Call GetMem('LSMV','Free','Real',ip_V,l_V)
-      Call GetMem('LSMX','Free','Real',ip_X,l_X)
+      Call mma_deallocate(V)
+      Call mma_deallocate(X)
 
       ! delete files if requested
       If (Delete) Then
