@@ -75,7 +75,7 @@ C        --------------------------------------------------
             If (ChoAlg.eq.2) Then
 
                kMabij = kXaibj  ! rename pointer
-               Call Cho_dZero(Wrk(kMabij),LnT2am) ! initialize
+               Call FZero(Wrk(kMabij),LnT2am) ! initialize
 
 C              Loop over Cholesky vector symmetries.
 C              -------------------------------------
@@ -301,7 +301,7 @@ C     --------------------------------------------------
          If (ChoAlg.eq.2) Then
 
             kMabij = kXaibj  ! rename pointer
-            Call Cho_dZero(Wrk(kMabij),LnT2am) ! initialize
+            Call FZero(Wrk(kMabij),LnT2am) ! initialize
 
 C           Loop over Cholesky vector symmetries.
 C           -------------------------------------
