@@ -28,14 +28,12 @@
 ************************************************************************
       use Symmetry_Info, only: nIrrep
       use SOAO_Info, only: iAOtSO, iOffSO
+      use ChoArr, only: iSOShl, iShlSO, nBstSh, iShP2RS, iShP2Q
+      use sort_data, only: nSkip
       Implicit Real*8 (A-H,O-Z)
 #include "cholesky.fh"
-#include "choptr.fh"
-#include "chosew.fh"
 #include "real.fh"
 #include "print.fh"
-#include "srt0.fh"
-#include "WrkSpc.fh"
 *
       Real*8 SOint(ijkl,nSOint), TInt(lInt)
       Integer iCmp(4), iShell(4), iAO(4), iAOst(4), iSOSym(2,nSOs)
@@ -51,11 +49,6 @@
 *     statement function
 *
       iTri(i,j)=Max(i,j)*(Max(i,j)-3)/2 + i + j
-      ISOSHL(I)=IWORK(ip_iSOShl-1+I)
-      ISHLSO(I)=IWORK(ip_iShlSO-1+I)
-      NBSTSH(I)=IWORK(ip_NBSTSH-1+I)
-      iShP2RS(i,j)=iWork(ip_iShP2RS-1+2*(j-1)+i)
-      iShP2Q(i,j)=iWork(ip_iShP2Q-1+2*(j-1)+i)
 *
       irout = 39
       jprint = nprint(irout)
@@ -73,10 +66,6 @@
      &   Call RecPrt(' in indsft:SOint ',' ',SOint,ijkl,nSOint)
       memSO2 = 0
 
-      If (nSOs .gt. 0) Then ! to make some compilers happy
-         iDummy_2 = iSOSym(1,1)
-      End If
-
       NUMC = NBSTSH(SHC)
       NUMD = NBSTSH(SHD)
       NUMA = NBSTSH(SHA)
@@ -172,9 +161,6 @@ C to avoid stupid compiler warnings:
                     k12 = nIrrep*j2 + j1+1
                 End If
              End If
-*
-             iSymi=max(j1,j2)+1
-             jSymj=min(j1,j2)+1
 *
              Do 310 j3 = 0, nIrrep-1
                 If (kSym(j3).eq.0) go to 310
@@ -203,9 +189,6 @@ C to avoid stupid compiler warnings:
                 jSO = iAOtSO(iAO(2)+i2,j2)+iAOst(2)+iOffSO(j2)
                 kSO = iAOtSO(iAO(3)+i3,j3)+iAOst(3)+iOffSO(j3)
                 lSO = iAOtSO(iAO(4)+i4,j4)+iAOst(4)+iOffSO(j4)
-*
-                kSymk=max(j3,j4)+1
-                lSyml=min(j3,j4)+1
 *
                 nijkl = 0
                 Do lSOl = lSO, lSO+lBas-1
@@ -369,4 +352,6 @@ C to avoid stupid compiler warnings:
 100   Continue
 *
       Return
+* Avoid unused argument warnings
+      If (.False.) Call Unused_integer_array(iSOSym)
       End
