@@ -12,7 +12,7 @@
       use Basis_Info, only: nBas
       use Aces_Stuff
       use Index_arrays, only: iSO2Sh
-      use Real_Info, only: CutInt
+      use Gateway_Info, only: CutInt
       use Symmetry_Info, only: nIrrep
       Implicit Real*8 (a-h,o-z)
 #include "setup.fh"
