@@ -27,9 +27,6 @@
 #include "setup.fh"
 #include "mp2alaska.fh"
       Logical DoCholesky
-*
-      iRout = 249
-      iPrint = nPrint(iRout)
 *
       If(case_mp2) then
          Call DecideOnCholesky(DoCholesky)
