@@ -15,7 +15,7 @@
       use Basis_Info, only: nBas
       use PCM_arrays
       use Symmetry_Info, only: nIrrep, iChBas
-      use Temporary_Parameters, only: PrPrt
+      use Gateway_global, only: PrPrt
       use Integral_Interfaces, only: OneEl_Integrals
       Implicit Real*8 (A-H,O-Z)
       External PCMInt, NaMem
