@@ -62,17 +62,6 @@
       nElem(ixyz) = (ixyz+1)*(ixyz+2)/2
 *                                                                      *
 ************************************************************************
-*                                                                      *
-      Interface
-      Subroutine Kernel(
-#define _CALLING_
-#include "int_interface.fh"
-     &                 )
-#include "int_interface.fh"
-      End Subroutine Kernel
-      End Interface
-*                                                                      *
-************************************************************************
 *                                                                      *
       If (Label(1:3).eq.'MAG') Then
       iCmp   = iSD( 2,iS)
