@@ -38,15 +38,12 @@
       Logical Shijij
 *     Local Array
       Integer iSym(0:7), jSym(0:7), kSym(0:7), lSym(0:7)
-      Integer iTwoj(0:7)
-      Data iTwoj/1,2,4,8,16,32,64,128/
 *                                                                      *
 ************************************************************************
 *                                                                      *
+#ifdef _DEBUGPRINT_
       iRout = 39
       iPrint = nPrint(iRout)
-      iPrint=99
-#ifdef _DEBUGPRINT_
       If (iPrint.ge.99) Then
          iComp = 1
          Call PrMtrx(' In PGet2:DSO ',[iD0Lbl],iComp,1,D0)
