@@ -42,12 +42,6 @@
       Logical Shijij
 *     Local Array
       Integer iSym(0:7), jSym(0:7), kSym(0:7), lSym(0:7)
-      Integer iTwoj(0:7)
-      Data iTwoj/1,2,4,8,16,32,64,128/
-*
-      iRout = 39
-      iPrint = nPrint(iRout)
-      lOper = 1
 *
 *     Prepare some data for Pam
 *
