@@ -46,12 +46,15 @@
 ************************************************************************
       Integer nFro(0:7)
       Integer Columbus
-      Character*8 RlxLbl,Method, KSDFT*16
+      Character*8 RlxLbl,Method, KSDFT*80
       Logical lPrint
       Logical DoCholesky
       Real*8 CoefX,CoefR
       Character Fmt*60
       Real*8, Allocatable:: D1ao(:), D1AV(:), Tmp(:,:)
+*     hybrid MC-PDFT things
+      Logical Do_Hybrid
+      Real*8  WF_Ratio,PDFT_Ratio
 *
 *...  Prologue
 
@@ -91,7 +94,7 @@
      &    Method.eq. 'MSPDFT  ' .or.
      &    Method.eq. 'CASDFT  ' ) Then
          Call Get_iScalar('Multiplicity',iSpin)
-         Call Get_cArray('DFT functional',KSDFT,16)
+         Call Get_cArray('DFT functional',KSDFT,80)
          Call Get_dScalar('DFT exch coeff',CoefX)
          Call Get_dScalar('DFT corr coeff',CoefR)
          ExFac=Get_ExFac(KSDFT)
@@ -499,8 +502,14 @@
 *
            Call Get_DLAO(D0(:,4),nDens)
 
+*        Getting conditions for hybrid MC-PDFT
+         Do_Hybrid=.false.
+         CALL qpg_DScalar('R_WF_HMC',Do_Hybrid)
+         If(Do_Hybrid) Then
+          CALL Get_DScalar('R_WF_HMC',WF_Ratio)
+          PDFT_Ratio=1.0d0-WF_Ratio
+         End If
 !ANDREW - modify D2: should contain only the correction pieces
-
          If ( Method.eq.'MCPDFT  ') then
 !Get the D_theta piece
             Call mma_allocate(D1ao,nDens)
@@ -527,6 +536,15 @@
             D0(:,5)=Zero
             call daxpy_(ndens,0.5d0,D0(1,1),1,D0(1,5),1)
             call daxpy_(ndens,1.0d0,D1ao,1,D0(1,5),1)
+
+          if(do_hybrid) then
+*           add back the wave function parts that are subtracted
+*           this might be inefficient, but should have a clear logic
+            call daxpy_(ndens,Half*WF_Ratio,D0(1,1),1,D0(1,2),1)
+            call daxpy_(ndens,WF_Ratio,D1ao,1,D0(1,2),1)
+*           scale the pdft part
+            call dscal_(ndens,PDFT_Ratio,D0(1,5),1)
+          end if
             Call mma_deallocate(D1ao)
           else If (Method.eq.'MSPDFT  ') Then
             Call Get_DArray('MSPDFTD5        ',D0(1,5),nDens)
