@@ -23,11 +23,11 @@
 *             November '90                                             *
 *             Modified to multipole moments November '90               *
 *                                                                      *
-*             Roland Lindh, Dept. of Theoratical Chemistry, University *
+*             Roland Lindh, Dept. of Theoretical Chemistry, University *
 *             of Lund, SWEDEN.                                         *
 *             Modified to reaction field calculations July '92         *
 ************************************************************************
-      use Her_RW
+      use Her_RW, only: HerR, HerW, iHerR, iHerw
       Implicit Real*8 (A-H,O-Z)
 #include "real.fh"
       Real*8 Final(nZeta,(la+1)*(la+2)/2,(lb+1)*(lb+2)/2,nComp),
