@@ -8,14 +8,23 @@
 * For more details see the full text of the license in the file        *
 * LICENSE or in <http://www.gnu.org/licenses/>.                        *
 ************************************************************************
-      subroutine rlsmem_ints
+      subroutine rlsmem_ints()
+      use k2_arrays, only: Sew_Scr
       implicit real*8 (a-h,o-z)
 #include "setup.fh"
+#include "stdalloc.fh"
+#include "status.fh"
 c
-      If(MemMax_int.gt.0) then
-        Call GetMem('MaxMem','Free','Real',ipMem_int,MemMax_int)
-        MemMax_int=0
-        ipMem_int=0
-      End if
+      If (XMem_Status.eq.Active) Then
+C        Write (6,*) 'RlsMem_Ints: External scratch handling active!'
+      Else If (XMem_Status.eq.InActive) Then
+         If (Allocated(Sew_Scr)) Then
+C           Write (6,*) 'RlsMem_Ints: Memory released!'
+            Call mma_deallocate(Sew_Scr)
+C        Else
+C           Write (6,*) 'RlsMem_Ints: No memory to release!'
+         End If
+      End If
+*
       return
       end
