@@ -32,8 +32,9 @@ C
       Real*8  xInt(l_xInt_)
 #include "WrkSpc.fh"
 #include "ldf_atom_pair_info.fh"
-#include "localdf_int3.fh"
+#include "localdf_mem.fh"
 #include "localdf_bas.fh"
+#include "localdf_int3.fh"
 #include "ldf_integral_prescreening_info.fh"
 
       Character*28 SecNam
@@ -191,10 +192,11 @@ C
 
       ! Allocate memory for Seward
       Call GetMem('GetMax','Max ','Real',ip_SewWrk,l_SewWrk)
+      l_SewWrk = min(l_SewWrk,MaxLDFSew)
       Call xSetMem_Ints(l_SewWrk)
 
       ! Compute integrals
-      Call Cho_dZero(xInt,l_xInt)
+      Call FZero(xInt,l_xInt)
       kShell=nShell_Valence+nShell_Auxiliary+1
       SHC=kShell
       If (A.eq.B) Then
@@ -297,6 +299,7 @@ C
 #include "WrkSpc.fh"
 #include "ldf_atom_pair_info.fh"
 #include "localdf_int.fh"
+#include "localdf_mem.fh"
 #include "localdf_bas.fh"
 #include "ldf_integral_prescreening_info.fh"
 
@@ -419,10 +422,11 @@ C
 
       ! Allocate memory for Seward
       Call GetMem('GetMax','Max ','Real',ip_SewWrk,l_SewWrk)
+      l_SewWrk = min(l_SewWrk,MaxLDFSew)
       Call xSetMem_Ints(l_SewWrk)
 
       ! Compute integrals
-      Call Cho_dZero(xInt,l_xInt)
+      Call FZero(xInt,l_xInt)
       Do klS=1,l_2CList_2
          kShell=i2CList(1,klS)
          lShell=i2CList(2,klS)
