@@ -21,21 +21,21 @@
 *     history: none                                                    *
 *                                                                      *
 ************************************************************************
-
+      use Str_Info, only: DTOC
+      use negpre
+      use ipPage, only: W
       Implicit Real*8 (a-h,o-z)
 
 #include "Input.fh"
 #include "Files_mclr.fh"
-#include "WrkSpc.fh"
+#include "stdalloc.fh"
 #include "Pointers.fh"
 #include "sa.fh"
-#include "negpre.fh"
-
 #include "detdim.fh"
-#include "csfbas_mclr.fh"
 #include "spinfo_mclr.fh"
 #include "dmrginfo_mclr.fh"
       logical ldisk,ipopen
+      Real*8, Allocatable:: CIVec(:,:), CITmp(:)
 
 ! ==========================================================
       integer,allocatable::index_SD(:) ! not final version
@@ -45,8 +45,20 @@
 *                                                                      *
 ************************************************************************
 *                                                                      *
-      Call Rd1Int_MCLR !Read in interesting info from RUNFILE and ONEINT
-      Call RdAB   ! Read in orbitals, perturbation type, etc.
+      Interface
+        Subroutine RdJobIph_td(CIVec)
+        Real*8, Allocatable:: CIVec(:,:)
+        End Subroutine RdJobIph_td
+        Subroutine RdJobIph(CIVec)
+        Real*8, Allocatable:: CIVec(:,:)
+        End Subroutine RdJobIph
+      End Interface
+*                                                                      *
+************************************************************************
+*                                                                      *
+      !Read in interesting info from RUNFILE and ONEINT
+      Call Rd1Int_MCLR()
+      Call RdAB()   ! Read in orbitals, perturbation type, etc.
 *                                                                      *
 ************************************************************************
 *                                                                      *
@@ -59,27 +71,20 @@
 ************************************************************************
 *                                                                      *
 *     Default activate ippage utility
-
 *
-
       ldisk  =ipopen(0,.True.)
 *
-      write(6,*) "iMethod:",iMethod,iCASSCF
       If (iMethod.eq.iCASSCF) Then
          If (TimeDep) Then
-            Call RdJobIph_td
+            Call RdJobIph_td(CIVec)
          Else
-            Call RdJobIph
+            Call RdJobIph(CIVec)
          End If
 
 *        Write(6,*) 'Setup of Determinant tables'
          Call DetCtl   ! set up determinant tables
 *....... Read in tables from disk
          Call InCsfSD(State_sym,State_sym,.true.)
-
-             !Call GetMem('CIvec','Allo','Real',ipNEW,NCONF)
-             !Call GetMem('OCIvec','Free','Real',ipCI,nConf)
-             !ipCI=ipNEW
 *                                                                      *
 ************************************************************************
 *                                                                      *
@@ -96,16 +101,16 @@
            ! yma
 !          No need to copy,since there are no CI-vectors
            if(doDMRG.and.doMCLR)then
-             Call Getmem('CIROOT','ALLO','REAL',ipT,ndets_RGLR)
+             Call mma_allocate(CITmp,ndets_RGLR,Label='CITmp')
            else
-             Call Getmem('CIROOT','ALLO','REAL',ipT,nconf)
-             call dcopy_(nconf,Work(ipCI+(i-1)*nconf),1,Work(ipT),1)
+             Call mma_allocate(CITmp,nconf,Label='CITmp')
+             call dcopy_(nconf,CIVec(:,i),1,CITmp,1)
            end if
 
            !> If doDMRG
            if(doDMRG.and.doMCLR)then ! yma
            else
-             Call GugaCtl_MCLR(ipT,1)   ! transform to sym. group
+             Call GugaCtl_MCLR(CITmp,1)   ! transform to sym. group
            end if
 
 ! Here should be the position for introducing the CI(SR) coefficients
@@ -116,33 +121,26 @@
              ! mma_allocate and mma_deallocate
              allocate(index_SD(ndets_RGLR))
              allocate(vector_cidmrg(ndets_RGLR))
-             call ci_reconstruct(i,ndets_RGLR,vector_cidmrg,
-     &                           index_SD)
+             call ci_reconstruct(i,ndets_RGLR,vector_cidmrg,index_SD)
              do ii=1,ndets_RGLR
                if(abs(vector_cidmrg(ii)).lt.0.0d0)then
                  vector_cidmrg(ii)=0.0d0
                end if
              end do
-             call CSDTVC_dmrg(work(ipT),vector_cidmrg,2,WORK(KDTOC),
+             call CSDTVC_dmrg(CITmp,vector_cidmrg,2,DTOC,
      &                     index_SD,ISSM,1,IPRDIA)
              ! mma_allocate and mma_deallocate
              deallocate(index_SD)
              deallocate(vector_cidmrg)
            end if
 
-           call dcopy_(nconf,Work(ipT),1,Work(ipCI+(i-1)*nconf),1)
-
-          if(doDMRG.and.doMCLR)then !yma
-            Call Getmem('CIROOT','FREE','REAL',ipT,ndets_RGLR)
-          else
-            Call Getmem('CIROOT','FREE','REAL',ipT,nconf)
-          end if
+           call dcopy_(nconf,CITmp,1,CIVec(:,i),1)
+           Call mma_deallocate(CITmp)
         End Do
-
 *                                                                      *
 ************************************************************************
 *                                                                      *
-        ldisk  =ipopen(nconf,page)
+         ldisk  =ipopen(nconf,page)
 *
 *        If we are computing Lagrangian multipliers we pick up all CI
 *        vectors. For Hessian calculations we pick up just one vector.
@@ -150,34 +148,46 @@
 C        Write (*,*) 'iState,SA,nroots=',iState,SA,nroots
          If (SA.or.iMCPD) Then
             ipcii=ipget(nconf*nroots)
-            call dcopy_(nconf*nroots,Work(ipCI),1,Work(ipin(ipcii)),1)
+            irc=ipin(ipcii)
+            call dcopy_(nconf*nroots,CIVec,1,W(ipcii)%Vec,1)
             nDisp=1
          Else
             ipcii=ipget(nconf)
-            ipCI_ = ipCI + (iState-1)*nConf
-            call dcopy_(nConf,Work(ipCI_),1,Work(ipin(ipcii)),1)
+            irc=ipin(ipcii)
+            call dcopy_(nConf,CIVec(:,iState),1,W(ipcii)%Vec,1)
             If (iRoot(iState).ne.1) Then
                Write (6,*) 'McKinley does not support computation of'
      &                   //' harmonic frequencies of excited states'
                Call Abend()
             End If
          End If
-C        Call RecPrt('CI vector',' ',Work(ipin(ipcii)),1,nConf)
-         Call Getmem('CIVEC','FREE','REAL',ipci,idum)
+C        irc=ipin(ipcii)
+C        Call RecPrt('CI vector',' ',W(ipcii)%Vec,1,nConf)
+         Call mma_deallocate(CIVec)
+*
+*        At this point we change to ipci being the index of the CI
+*        vector in the ipage utility.
+*
          ipci=ipcii
          irc=ipout(ipci)
 *                                                                      *
 ************************************************************************
 *                                                                      *
-         If (ngp) Call rdciv
+         If (ngp) Call rdciv()
       End If
 *                                                                      *
 ************************************************************************
 *                                                                      *
-      Call InpOne           ! read in oneham
+      Call InpOne()         ! read in oneham
       Call PrInp_MCLR(iPL)  ! Print all info
 *                                                                      *
 ************************************************************************
 *                                                                      *
       Return
+#ifdef _WARNING_WORKAROUND_
+      If (.False.) Then
+         Call Unused_integer(irc)
+         Call Unused_logical(ldisk)
+      End If
+#endif
       End
