@@ -26,6 +26,7 @@
 #include "sa.fh"
 #include "dmrginfo_mclr.fh"
 #include "SysDef.fh"
+      Character*8 Method
       Logical CI, Is_Roots_Set
       Character(LEN=80) Note
 ! Added for DMRG calculation
@@ -361,6 +362,10 @@ c
 c
 c Read active one el dens for state j from JOBIPH and store in G1q
 c
+         Call Get_cArray('Relax Method',Method,8)
+         if(Method.eq.'MSPDFT  ') then
+          Call Get_DArray('D1MOt           ',G1q,ng1)
+         else
          Do i=1,iR-1  ! Dummy read until state j
            Call dDaFile(LUJOB ,0,rdum,ng1,jDisk)
            Call dDaFile(LUJOB ,0,rdum,ng1,jDisk)
@@ -368,6 +373,7 @@ c
            Call dDaFile(LUJOB ,0,rdum,ng2,jDisk)
          End Do
          Call dDaFile(LUJOB ,2,G1q,ng1,jDisk)
+         end if
        EndIf
 *
 *    Construct a variationally stable density matrix. In MO
