@@ -21,11 +21,12 @@ C
       IMPLICIT REAL*8 (A-H,O-Z)
 C
 #include "rasdim.fh"
-#include "warnings.fh"
+#include "warnings.h"
 #include "rasscf.fh"
 #include "general.fh"
 #include "gas.fh"
 #include "output_ras.fh"
+      Character*16 ROUTINE
       Parameter (ROUTINE='GUGACTL ')
 #include "gugx.fh"
 #include "WrkSpc.fh"
@@ -105,7 +106,7 @@ C
 C     INITIALIZE GUGA TABLES:
 C
       CALL MKGUGA_m(NSM,IPRLEV)
-      NCONF=NCSF(LSYM)
+      NCONF=NCSF(STSYM)
       If ( NAC.eq.0 ) NCONF=1
 
 100   Continue
