@@ -45,11 +45,10 @@
       Implicit Real*8 (A-H,O-Z)
 
 #include "rasdim.fh"
-#include "warnings.fh"
+#include "warnings.h"
 #include "rasscf.fh"
 #include "general.fh"
 #include "output_ras.fh"
-      Parameter (ROUTINE='OVLP    ')
 #include "WrkSpc.fh"
 
       Dimension C1(*),C2(*),Smat(*)
