@@ -39,15 +39,12 @@
 #include "rasdim.fh"
 #include "general.fh"
 
-      Integer case, state_symmetry
+      Integer case
       Integer   off_PUVX, off_Dmat, off_Fmat
       Dimension off_PUVX(mxSym), off_Dmat(mxSym), off_Fmat(mxSym)
 
       iTri(i)=(i*i-i)/2
 
-*     nasty, but necessary
-      state_symmetry=lSym
-
 *     generate offsets
 
       iStack = 0
@@ -346,9 +343,6 @@
         End Do
       End Do
 
-*     nasty, but necessary
-      lSym=state_symmetry
-
       Return
       End
 
@@ -384,20 +378,16 @@
 #include "general.fh"
 #include "WrkSpc.fh"
 
-      Integer  state_symmetry
       Integer   off_Fmat
       Dimension  off_Fmat(mxSym)
       Integer off_Bas(mxSym),off_ish(mxSym)
-      Integer off_BasAsh(mxSym),off_BasIsh(mxSym)
+      Integer off_BasAsh(mxSym)
       Integer p,q,ipq
       Integer iStack1,iStack2,iStack
       Integer count_tmp
 
       iTri(i)=(i*i-i)/2
 
-*     nasty, but necessary
-      state_symmetry=lSym
-
 *     generate offsets
 
 ************************************************************************
@@ -412,7 +402,6 @@
         off_Bas(iSym)    = iStack1
         off_ish(isym)    = iStack2
         off_BasAsh(isym) = iStack1 + nIsh(iSym) + nFro(iSym)
-        off_BasIsh(isym) = iStack1 + nFro(iSym)
         off_Fmat(iSym) = iStack
         iOrb = nOrb(iSym)
         iStack = iStack+ (iOrb*iOrb+iOrb)/2
@@ -506,9 +495,6 @@
 
 ************************************************************************
 
-*     nasty, but necessary
-      lSym=state_symmetry
-
       Return
       End
 
@@ -542,21 +528,18 @@
 #include "rasdim.fh"
 #include "general.fh"
 
-      Integer case, state_symmetry
-      Integer   off_PUVX, off_Dmat, off_Fmat
-      Dimension off_PUVX(mxSym), off_Dmat(mxSym), off_Fmat(mxSym)
+      Integer case
+      Integer   off_PUVX, off_Fmat
+      Dimension off_PUVX(mxSym), off_Fmat(mxSym)
 
       iTri(i)=(i*i-i)/2
 
       Call unused_real(ExFac)
-*     nasty, but necessary
-      state_symmetry=lSym
 
 *     generate offsets
 
       iStack = 0
       Do iSym = 1,nSym
-         off_Dmat(iSym) = iStack
          iAsh = nAsh(iSym)
          iStack = iStack+ (iAsh*iAsh+iAsh)/2
       End Do
@@ -642,15 +625,9 @@
 *               symmetry case (II!II)
 100             Continue
                 iFoff = off_Fmat(iSym)
-                iDoff = off_Dmat(iSym)
                 Do iV = 1,kAsh
                   Do iX = 1,iV
-                    iVX = iTri(iV) + iX
                     Do iU = 1,jAsh
-                      iUV = iTri(iU) + iV
-                      If ( iV.gt.iU ) iUV  = iTri(iV) + iU
-                      iUX = iTri(iU) + iX
-                      If ( iX.gt.iU ) iUX  = iTri(iX) + iU
                       If ( iX.eq.iV ) then
                       End If
                       iPUVX = off_PUVX(iSym)
@@ -722,10 +699,8 @@
 *               symmetry case (II!KK)
 200             Continue
                 iFoff = off_Fmat(iSym)
-                kDoff = off_Dmat(kSym)
                 Do iV = 1,kAsh
                   Do iX = 1,iV
-                    iVX = iTri(iV) + iX
                     Do iU = 1,jAsh
                       iPUVX = off_PUVX(iSym)
 *                     inactive/active block
@@ -760,13 +735,9 @@
 300             Continue
                 iFoff = off_Fmat(iSym)
                 jFoff = off_Fmat(jSym)
-                iDoff = off_Dmat(iSym)
-                jDoff = off_Dmat(jSym)
                 Do iV = 1,kAsh
                   Do iX = 1,lAsh
                     Do iU= 1,jAsh
-                      iUX = iTri(iU) + iX
-                      If ( iX.gt.iU ) iUX  = iTri(iX) + iU
                       iPUVX = off_PUVX(iSym)
 *                     inactive/active block
                       Do iP = 1,iIsh
@@ -793,8 +764,6 @@
                       off_PUVX(iSym) = off_PUVX(iSym) + iOrb
                     End Do
                     Do iU= 1,iAsh
-                      iUV = iTri(iU) + iV
-                      If ( iV.gt.iU ) iUV  = iTri(iV) + iU
                       iPUVX = off_PUVX(jSym)
 *                     inactive/active block
                       Do iP = 1,jIsh
@@ -841,9 +810,6 @@
         End Do
       End Do
 
-*     nasty, but necessary
-      lSym=state_symmetry
-
       Return
       End
 
