@@ -46,8 +46,6 @@
 *
 
 #include "FileIDs.fh"
-#include "TwoRc.fh"
-#include "TwoFlags.fh"
 #include "Molcas.fh"
 #include "TwoDat.fh"
 *
@@ -129,7 +127,6 @@
 *---- Call to GetOrd to fill nBatch etc.
 *
       If (Option.eq.0) Then
-         rc_Dummy=-1
          Call GetOrd(rd_Dummy,lDummy,iDummy,nDummy1,nDummy2)
       End If
 *
