@@ -8,7 +8,7 @@
 * For more details see the full text of the license in the file        *
 * LICENSE or in <http://www.gnu.org/licenses/>.                        *
 ************************************************************************
-      Subroutine PrCoor
+      Subroutine PrCoor()
 ************************************************************************
 *                                                                      *
 *     purpose: Write coordinates.                                      *
