@@ -26,15 +26,12 @@
 #include "WrkSpc.fh"
 *
       Interface
-        Function allocmem(ref,cref,intof,dblof,sglof,chrof,size_)
+        Function allocmem(ref,intof,dblof,chrof,size_)
      &           bind(C,name='allocmem_')
-          Use, Intrinsic :: iso_c_binding, only: c_char
           Use Definitions, only: MOLCAS_C_INT, MOLCAS_C_REAL
           Integer(kind=MOLCAS_C_INT) :: allocmem
           Real(kind=MOLCAS_C_REAL) :: ref(*)
-          Character(kind=c_char) :: cref(*)
-          Integer(kind=MOLCAS_C_INT) :: intof, dblof, sglof, chrof,
-     &                                  size_
+          Integer(kind=MOLCAS_C_INT) :: intof, dblof, chrof, size_
         End Function allocmem
       End Interface
 *----------------------------------------------------------------------*
@@ -59,7 +56,7 @@
 *----------------------------------------------------------------------*
 *     Grab from the system a pointer to the dynamic work area          *
 *----------------------------------------------------------------------*
-      iRc=allocmem(Work,cWork,iofint,iofdbl,iofsgl,iofchr,MxMem)
+      iRc=allocmem(Work,iofint,iofdbl,iofchr,MxMem)
       If ( iRc.ne.0 ) Then
          Write (6,'(A,I3,A)') 'The initialization of the memory '//
      &                        'manager failed ( iRc=',iRc,' ).'
