@@ -35,6 +35,7 @@
 *> @param[out]    P      Average symm. 2-dens matrix
 *> @param[out]    PA     Average antisymm. 2-dens matrix
 *> @param[out]    FI     Fock matrix from inactive density
+*> @param         FA
 *> @param[in,out] D1I    Inactive 1-dens matrix
 *> @param[in,out] D1A    Active 1-dens matrix
 *> @param[in]     TUVX   Active 2-el integrals
@@ -61,6 +62,8 @@
 #ifdef _HDF5_
       use mh5, only: mh5_put_dset
 #endif
+      use csfbas, only: CONF, KCFTP
+      use CMS, only: iCMSOpt,CMSGiveOpt
       Implicit Real* 8 (A-H,O-Z)
 
       Dimension CMO(*),D(*),DS(*),P(*),PA(*),FI(*),FA(*),D1I(*),D1A(*),
@@ -81,7 +84,6 @@
 #include "output_ras.fh"
       Character*16 ROUTINE
       Parameter (ROUTINE='CICTL   ')
-#include "csfbas.fh"
 #include "gugx.fh"
 #include "WrkSpc.fh"
 #include "SysDef.fh"
@@ -550,8 +552,18 @@ C     kh0_pointer is used in Lucia to retrieve H0 from Molcas.
          CALL XMSRot(CMO,FI,FA)
         End If
         IF(ICMSP.eq.1) THEN
-         CALL XMSRot(CMO,FI,FA)
-         CALL CMSRot(TUVX)
+         If(trim(CMSStartMat).eq.'XMS') Then
+          CALL XMSRot(CMO,FI,FA)
+         End If
+         If(.not.CMSGiveOpt) Then
+          if(lRoots.eq.2) iCMSOpt=2
+          if(lRoots.ge.3) iCMSOpt=1
+         End If
+         If(iCMSOpt.eq.1) Then
+          CALL CMSOpt(TUVX)
+         Else If (iCMSOpt.eq.2) Then
+          CALL CMSRot(TUVX)
+         End If
         END IF
         If(IRotPsi==1) Then
          CALL f_inquire('ROT_VEC',Do_Rotate)
@@ -781,7 +793,7 @@ c
           call getmem('kcnf','allo','inte',ivkcnf,nactel)
          if(.not.iDoGas)then
           Call Reord2(NAC,NACTEL,STSYM,0,
-     &                iWork(KICONF(1)),iWork(KCFTP),
+     &                CONF,iWork(KCFTP),
      &                Work(LW4),Work(LW11),iWork(ivkcnf))
 c        end if
 c         call getmem('kcnf','free','inte',ivkcnf,nactel)
@@ -825,7 +837,7 @@ C.. printout of the wave function
      c                 prwthr,' for root', i
             Write(LF,'(6X,A,F15.6)')
      c                'energy=',ener(i,iter)
-          call gasprwf(iwork(lw12),nac,nactel,stsym,iwork(kiconf(1)),
+          call gasprwf(iwork(lw12),nac,nactel,stsym,conf,
      c                 iwork(kcftp),work(lw4),iwork(ivkcnf))
           End If
          end if
@@ -849,7 +861,7 @@ C.. printout of the wave function
 * reorder it according to the split graph GUGA conventions
           call getmem('kcnf','allo','inte',ivkcnf,nactel)
           Call Reord2(NAC,NACTEL,STSYM,0,
-     &                iWork(KICONF(1)),iWork(KCFTP),
+     &                CONF,iWork(KCFTP),
      &                Work(LW4),Work(LW11),iWork(ivkcnf))
           call getmem('kcnf','free','inte',ivkcnf,nactel)
 * save reorder CI vector on disk
