@@ -35,7 +35,7 @@
 *> @param[in]     IFINAL Calculation status switch
 *> @param[in]     IRst   DMRG restart status switch
 ************************************************************************
-#if defined _ENABLE_BLOCK_DMRG_ || defined _ENABLE_CHEMPS2_DMRG_
+#if defined _ENABLE_BLOCK_DMRG_ || defined _ENABLE_CHEMPS2_DMRG_ || defined _ENABLE_DICE_SHCI_
       Subroutine DMRGCtl(CMO,D,DS,P,PA,FI,D1I,D1A,TUVX,IFINAL,IRst)
 
       Implicit Real* 8 (A-H,O-Z)
@@ -179,6 +179,9 @@ C Local print level (if any)
 #elif _ENABLE_CHEMPS2_DMRG_
                  CALL chemps2_densi_rasscf(IPCMRoot,Work(LW6),Work(LW7),
      &                                 Work(LW8),Work(LW9),Work(LW10))
+#elif _ENABLE_DICE_SHCI_
+                 CALL dice_densi_rasscf(IPCMRoot,Work(LW6),Work(LW7),
+     &                                  Work(LW8),Work(LW9),Work(LW10))
 #endif
 
 * NN.14 NOTE: IFCAS must be 0 for DMRG-CASSCF
@@ -267,6 +270,8 @@ C     kh0_pointer is used in Lucia to retrieve H0 from Molcas.
           Call BlockCtl(Work(LW1),Work(ipTmpTUVX),IFINAL,IRst)
 #elif _ENABLE_CHEMPS2_DMRG_
           Call Chemps2Ctl(Work(LW1),Work(ipTmpTUVX),IFINAL,IRst)
+#elif _ENABLE_DICE_SHCI_
+          Call DiceCtl(Work(LW1),Work(ipTmpTUVX),IFINAL,IRst)
 #endif
 
           Call GetMem('TmpTUVX','Free','Real',ipTmpTUVX,NACPR2)
@@ -276,6 +281,8 @@ C     kh0_pointer is used in Lucia to retrieve H0 from Molcas.
           Call BlockCtl(Work(LW1),TUVX,IFINAL,IRst)
 #elif _ENABLE_CHEMPS2_DMRG_
           Call Chemps2Ctl(Work(LW1),TUVX,IFINAL,IRst)
+#elif _ENABLE_DICE_SHCI_
+          Call DiceCtl(Work(LW1),TUVX,IFINAL,IRst)
 #endif
         End If
       endif
@@ -319,6 +326,9 @@ C     kh0_pointer is used in Lucia to retrieve H0 from Molcas.
 #elif _ENABLE_CHEMPS2_DMRG_
           CALL chemps2_densi_rasscf(jRoot,Work(LW6),Work(LW7),
      &                              Work(LW8),Work(LW9),Work(LW10))
+#elif _ENABLE_DICE_SHCI_
+          CALL dice_densi_rasscf(jRoot,Work(LW6),Work(LW7),
+     &                           Work(LW8),Work(LW9),Work(LW10))
 #endif
           CALL GETMEM('PTscr','FREE','REAL',LW10,NACT4)
         EndIf
