@@ -56,9 +56,6 @@
       Integer nTemp(8)
       Character(Len=16) mstate
 *
-#ifndef _DMRG_
-      logical :: doDMRG = .false.
-#endif
 *----------------------------------------------------------------------*
 *     Prologue                                                         *
 *----------------------------------------------------------------------*
