@@ -173,9 +173,36 @@ C Local print level (if any)
       Call CollapseOutput(0,'Orbital specifications:')
       Write(LF,*)
 
-#if defined _ENABLE_BLOCK_DMRG_ || defined _ENABLE_CHEMPS2_DMRG_
+#if defined _ENABLE_BLOCK_DMRG_ || defined _ENABLE_CHEMPS2_DMRG_ || defined _ENABLE_DICE_SHCI_
       If(.Not.DoBlockDMRG) GoTo 113
 
+#ifdef _ENABLE_DICE_SHCI_
+      Line=' '
+      Write(Line(left-2:),'(A)') 'DICE specifications:'
+      Call CollapseOutput(1,Line)
+      Write(LF,Fmt2//'A)')'--------------------------'
+      Write(LF,*)
+      Write(LF,Fmt2//'A,T70,L6)')'Heat-bath configuration interaction
+     &(JCTC, 2017, 13, 1595)', DoBlockDMRG
+      Write(LF,Fmt2//'A,T45,L6)')'Semistochastic algorithm',Dice_stoc
+      Write(LF,Fmt2//'A,T45,L6)')'Full restart',dice_restart
+      Write(LF,Fmt2//'A,T45,I6)')'Max iterations',dice_iter
+      Write(LF,Fmt2//'A,T45,E10.3)')'Epsilon1',
+     &                           dice_eps1
+      Write(LF,Fmt2//'A,T45,E10.3)')'Epsilon2',
+     &                           dice_eps2
+      Write(LF,Fmt2//'A,T45,I6)')'SampleN',
+     &                           dice_sampleN
+      Write(LF,Fmt2//'A,T45)')'Occupation guess'
+      do iref_dice=1,nref_dice
+         write(LF,Fmt2//'A)') trim(diceocc(iref_dice))
+      enddo
+      Call CollapseOutput(0,'DICE specifications:')
+
+*     Skip printing CI specifications in DICE
+      GoTo 114
+#endif
+
       Line=''
       Write(Line(left-2:),'(A)') 'DMRG sweep specifications:'
       Call CollapseOutput(1,Line)
@@ -330,10 +357,10 @@ C Local print level (if any)
      &                    'in a previous calculation'
          Write(LF,*)
       End If
-      If (KSDFT.ne.'SCF'.and.KSDFT.ne.'PAM') Call Print_NQ_Info(iSpin)
+      If (KSDFT.ne.'SCF'.and.KSDFT.ne.'PAM') Call Print_NQ_Info()
       Call CollapseOutput(0,'CI expansion specifications:')
 
-#if defined _ENABLE_BLOCK_DMRG_ || defined _ENABLE_CHEMPS2_DMRG_
+#if defined _ENABLE_BLOCK_DMRG_ || defined _ENABLE_CHEMPS2_DMRG_ || defined _ENABLE_DICE_SHCI_
  114  Continue
 #endif
 
