@@ -25,6 +25,7 @@
       Use Fock_util_global, only: ALGO, Deco, DensityCheck, dmpk,
      &                            DoCholesky, DoLocK, Estimate, Nscreen,
      &                            Update
+      use CMS, only: iCMSOpt,CMSGiveOpt
       Implicit Real*8 (A-H,O-Z)
       External Get_SuperName
       Character*100 ProgName, Get_SuperName
@@ -32,13 +33,12 @@
 #include "output_ras.fh"
 #include "rasscf.fh"
 #include "casvb.fh"
-#include "general.fh"
+#include "general_mul.fh"
 #include "gas.fh"
 #include "timers.fh"
 #include "lucia_ini.fh"
 #include "orthonormalize.fh"
 #include "WrkSpc.fh"
-#include "ksdft.fh"
       Integer IPRGLB_IN, IPRLOC_IN(7)
 * What to do with Cholesky stuff?
       Logical, External :: Is_First_Iter
@@ -258,9 +258,6 @@ C        ICIRST=1 ! to be activated!
 *
       KSDFT='SCF'
       ExFac=1.0D0
-* Initialize KSDF coefficients (S Dong, 2018)
-      CoefR = 1.0D0
-      CoefX = 1.0D0
 ** Default orthonormalization of CMOs to be with
 ** Gram-Schmidt
 *      Lowdin_ON=.False.
@@ -371,6 +368,9 @@ C state rotation
       iCMSP=0
       ICMSIterMax=100
       ICMSIterMin=5
-      CMSThreshold=1.0d-6
+      CMSThreshold=1.0d-8
+      CMSStartMat='XMS'
+      iCMSOpt=1
+      CMSGiveOpt=.false.
       RETURN
       END
