@@ -15,6 +15,7 @@
       use rasscf_data, only: doDMRG
       use qcmaquis_interface_cfg
 #endif
+      use Fock_util_global, only: Deco, Estimate, PseudoChoMOs, Update
 
       IMPLICIT NONE
 #include "prgm.fh"
@@ -34,7 +35,6 @@
       Logical lExists
 #include "chorassi.fh"
 #include "chotime.fh"
-#include "lkscreen.fh"
       Integer I, J, ISTATE, JSTATE, IJOB, ILINE, LINENR
       Integer LuIn
       Integer NFLS
@@ -519,6 +519,23 @@ c BP Natural orbitals options
         GoTo 100
       Endif
 c END BP OPTIONS
+c RF SO-NTO
+      If(line(1:4).eq.'SONT') then
+        read(LuIn,*,ERR=997) SONTOSTATES
+        CALL GETMEM('SONTO','ALLO','INTE',LSONTO,2*SONTOSTATES)
+        linenr=linenr+1
+        do ILINE=1,SONTOSTATES
+          read(LuIn,*,ERR=997) (iwork(LSONTO+J-1),J=ILINE*2-1,ILINE*2)
+          linenr=linenr+1
+        enddo
+        goto 100
+      Endif
+      If(line(1:4).eq.'ARGU') then
+        IFARGU=.TRUE.
+        Linenr=Linenr+1
+        goto 100
+      Endif
+c END RF
 C-SVC 2007 2008------------------------------
       If(Line(1:4).eq.'MAGN') then
         IFXCAL=.TRUE.
@@ -764,8 +781,15 @@ C--------------------------------------------
         Read(LuIn,*,ERR=997) (e_Vector(i),i=1,3)
         GoTo 100
       Endif
-#ifdef _DMRG_
 C--------------------------------------------
+C VKochetov 2021 enable saving more data to hdf5
+      if (Line(1:4).eq.'RHOD') then
+        rhodyn=.true.
+        Linenr=Linenr+1
+        GoTo 100
+      endif
+C--------------------------------------------
+#ifdef _DMRG_
       if (Line(1:4).eq.'QDSC') then
         QDPT2SC = .true.
         goto 100
