@@ -109,7 +109,7 @@ C
       IF (fexist) THEN
          CALL DANAME(file,filnam)
          IF (IPGLOB.GE.VERBOSE)
-     &      WRITE(6,*) filnam(:mylen(filnam))//' file exists.'
+     &      WRITE(6,*) trim(filnam)//' file exists.'
       ELSE
 C If the file does not exist, create a new one with the
 C current vectors
@@ -130,7 +130,7 @@ C Write the real table of contents
          IAD3=0
          CALL IDAFILE(file,1,IADR3,3,IAD3)
          IF (IPGLOB.GE.VERBOSE)
-     &      WRITE(6,*) filnam(:mylen(filnam))//' file created.'
+     &      WRITE(6,*) trim(filnam)//' file created.'
       ENDIF
 C
 C Check for surface hop if the energy difference is smaller than
