@@ -12,7 +12,7 @@
       Implicit Real*8 (A-H,O-Z)
 #include "WrkSpc.fh"
 
-      Character*24 Label
+      Character(LEN=24) Label
       Logical      Found
 
       Label='dExcdRa'
@@ -25,3 +25,25 @@
 
       Return
       End
+      Subroutine Get_dExcdRa_X(dExcdRa,ndExcdRa)
+      Implicit None
+      Character(LEN=24) Label
+      Logical      Found
+      Integer :: mdExcdRa=-1
+      Integer, Intent(In) :: ndExcdRa
+      Real*8,  Intent(Out) :: dExcdRa(ndExcdRa)
+
+      Label='dExcdRa'
+      Call qpg_dArray(Label,Found,mdExcdRa)
+      If(.not.Found .or. mdExcdRa.eq.0) Then
+         Call SysAbendmsg('Get_dExcdRa','Did not find:',Label)
+      End If
+      If (mdExcdRa/=ndExcdRa) Then
+         Write (6,*) 'mdExcdRa/=ndExcdRa'
+         Write (6,*)  mdExcdRa,'/=',ndExcdRa
+         Call AbEnd()
+      End If
+      Call Get_dArray(Label,dExcdRa,ndExcdRa)
+
+      Return
+      End
