@@ -149,10 +149,10 @@
 *----------------------------------------------------------------------*
       i_run_DS_used(item)=i_run_DS_used(item)+1
       If(item.eq.-1) Then
-         Call SysAbendMsg('get_dScalar','Could not locate',Label)
+         Call SysAbendMsg('get_dScalar','Could not locate: ',Label)
       End If
       If(RecIdx(item).eq.0) Then
-         Call SysAbendMsg('get_dScalar','Data not defined',Label)
+         Call SysAbendMsg('get_dScalar','Data not defined: ',Label)
       End If
       Data=RecVal(item)
 *----------------------------------------------------------------------*
