@@ -15,8 +15,7 @@
       Character*8 Label
       Integer nSym, nBas(8)
 *
-      Logical DoEMPC
-      Common /EmbPCharg/ DoEMPC
+#include "embpcharg.fh"
 *
       Call Get_iScalar('nSym',nSym)
       Call Get_iArray('nBas',nBas,nSym)
