@@ -44,12 +44,12 @@
 *     history: none                                                    *
 *                                                                      *
 ************************************************************************
+      use InfSO
       Implicit Real*8 (a-h,o-z)
 *
 #include "real.fh"
 #include "mxdm.fh"
 #include "infscf.fh"
-#include "infso.fh"
 #include "stdalloc.fh"
 #include "file.fh"
 #include "llists.fh"
