@@ -34,15 +34,9 @@
 *----------------------------------------------------------------------*
 * Local variables                                                      *
 *----------------------------------------------------------------------*
-      Logical Debug
 *----------------------------------------------------------------------*
 * Perform setup                                                        *
 *----------------------------------------------------------------------*
-#ifdef _DEBUGPRINT_
-      Debug=.true.
-#else
-      Debug=.false.
-#endif
       Write(6,'(a)') '+++ Entering Fao2Fmo'
 *----------------------------------------------------------------------*
 *                                                                      *
