@@ -10,27 +10,26 @@
 ************************************************************************
       Subroutine Get_DEcorr(nh1,Grad,nGrad,DFTFOCK)
       use SCF_Arrays, only: CMO
+      use SpinAV
       Implicit Real*8 (a-h,o-z)
 #include "real.fh"
 #include "mxdm.fh"
-#include "WrkSpc.fh"
+#include "stdalloc.fh"
 #include "infscf.fh"
       Real*8  Grad(nGrad), Ec_AB(2)
       Character*4 DFTFOCK
 #include "addcorr.fh"
-#include "spave.fh"
+      Real*8, Allocatable :: F_DFT(:,:), D_DS(:,:)
+      nD=2
 *
-      Call GetMem('F-DS','Allo','Real',ipF_DFT,2*nBT)
-      Call GetMem('D-DS','Allo','Real',ip_D_DS,2*nBT)
-      ip_Da=ip_D_DS
-      ip_Db=ip_D_DS+nBT
+      Call mma_allocate(F_DFT,nBT,nD,Label='F_DFT')
+      Call mma_allocate(D_DS ,nBT,nD,Label='D_DS')
 *
       Do iAB=1,2
        iOff=1
-       jOff=0
+       jOff=1
        lOff=0
        Do iSym=1,nSym
-          ipDaa=ip_Da+jOff
           If (iAB.eq.1) Then
              nXoX=nOcc(iSym,1)
              iXoX=0
@@ -42,8 +41,7 @@
           Call DGEMM_tri('N','T',nBas(iSym),nBas(iSym),nXoX,
      &                     1.0d0,CMO(mAdCMOO,1),nBas(iSym),
      &                           CMO(mAdCMOO,1),nBas(iSym),
-     &                     0.0d0,Work(ipDaa),nBas(iSym))
-          ipDbb=ip_Db+jOff
+     &                     0.0d0,D_DS(jOff,1),nBas(iSym))
           If (iAB.eq.1) Then
              nXoX=nOcc(iSym,2)
              iXoX=0
@@ -55,17 +53,16 @@
           Call DGEMM_tri('N','T',nBas(iSym),nBas(iSym),nXoX,
      &                     1.0d0,CMO(mAdCMOO,2),nBas(iSym),
      &                           CMO(mAdCMOO,2),nBas(iSym),
-     &                     0.0d0,Work(ipDbb),nBas(iSym))
+     &                     0.0d0,D_DS(jOff,2),nBas(iSym))
 *
           If (Do_SpinAV) Then
              Do j=1,nBas(iSym)
                 Do i=1,j
-                   iDSc=ip_DSc-1+nBas(iSym)*(j-1)+i
+                   iDSc=nBas(iSym)*(j-1)+i
                    ji=j*(j-1)/2+i
-                   iDaa=ipDaa-1+ji
-                   Work(iDaa)=Work(iDaa)-Work(iDSc)
-                   iDbb=ipDbb-1+ji
-                   Work(iDbb)=Work(iDbb)+Work(iDSc)
+                   iDij=jOff-1+ji
+                   D_DS(iDij,1)=D_DS(iDij,1)-DSc(iDSc)
+                   D_DS(iDij,2)=D_DS(iDij,2)+DSc(iDSc)
                 End Do
              End Do
              lOff=lOff+nBas(iSym)**2
@@ -74,43 +71,42 @@
           Do j=1,nBas(iSym)
              Do i=1,j-1
                 ji=j*(j-1)/2+i
-                iDaa=ipDaa-1+ji
-                Work(iDaa)=2.0d0*Work(iDaa)
-                iDbb=ipDbb-1+ji
-                Work(iDbb)=2.0d0*Work(iDbb)
+                iDij=jOff-1+ji
+                D_DS(iDij,1)=2.0d0*D_DS(iDij,1)
+                D_DS(iDij,2)=2.0d0*D_DS(iDij,2)
              End Do
           End Do
           iOff=iOff+nBas(iSym)*nOrb(iSym)
           jOff=jOff+nBas(iSym)*(nBas(iSym)+1)/2
        End Do
 *
-       Call Get_Ecorr_dft(nh1,Grad,nGrad,DFTFOCK,ipF_DFT,ip_D_DS,
+       Call Get_Ecorr_dft(nh1,Grad,nGrad,DFTFOCK,F_DFT,D_DS,nBT,nD,
      &                        ADDC_KSDFT,Ec_AB(iAB))
       End Do
 *----------------------------------------------------------------------*
       DE_KSDFT_c=Ec_AB(1)-Ec_AB(2)
 *----------------------------------------------------------------------*
 *
-      Call GetMem('D-DS','Free','Real',ip_D_DS,2*nBT)
-      Call GetMem('F-DS','Free','Real',ipF_DFT,2*nBT)
+      Call mma_deallocate(D_DS)
+      Call mma_deallocate(F_DFT)
       Return
       End
 *                                                                      *
 ************************************************************************
 *                                                                      *
-      Subroutine Get_Ecorr_dft(nh1,Grad,nGrad,DFTFOCK,ipF_DFT,ip_D_DS,
-     &                             KSDFT,Ec_AB)
+      Subroutine Get_Ecorr_dft(nh1,Grad,nGrad,DFTFOCK,F_DFT,D_DS,
+     &                         nBT,nD,KSDFT,Ec_AB)
       use OFembed, only: dFMD, Do_Core
-      use nq_Info
+      use nq_Info, only: Dens_I, Grad_I, Tau_I
       Implicit Real*8 (a-h,o-z)
 
 #include "real.fh"
-#include "WrkSpc.fh"
 #include "debug.fh"
       Real*8  Grad(nGrad)
       Logical Do_MO,Do_TwoEl,Do_Grad
-      Character*4 DFTFOCK
-      Character*16  KSDFT
+      Character(LEN=4) DFTFOCK
+      Character(LEN=80)  KSDFT
+      Real*8 :: F_DFT(nBT,nD), D_DS(nBT,nD)
 
       Debug=.False.
 *                                                                      *
@@ -134,8 +130,7 @@
 *                                                                      *
       Do_Core=.True.
       Call Driver(KSDFT,Do_Grad,Func,Grad,nGrad,
-     &            Do_MO,Do_TwoEl,Work(ip_D_DS),
-     &                          Work(ipF_DFT),nh1,nFckDim,DFTFOCK)
+     &            Do_MO,Do_TwoEl,D_DS,F_DFT,nh1,nFckDim,DFTFOCK)
       Do_Core=.False.
 *                                                                      *
 ************************************************************************
@@ -148,8 +143,7 @@
       write(6,*) ' Correlation potentials: (itri,F_alpha,F_beta)'
       write(6,*)
       Do i=1,nh1
-        Write(6,'(i4,3f22.16)') i,Work(ipF_DFT+i-1),
-     &                            Work(ipF_DFT+i-1+nh1)
+        Write(6,'(i4,3f22.16)') i,F_DFT(i,1),F_DFT(i,2)
       End Do
 #endif
 *
