@@ -13,38 +13,34 @@
       Implicit Real*8 (a-h,o-z)
 #include "real.fh"
 #include "mxdm.fh"
-#include "WrkSpc.fh"
+#include "stdalloc.fh"
 #include "infscf.fh"
       Real*8  Grad(nGrad)
       Character*4 DFTFOCK
 #include "dcscf.fh"
+      Real*8, Allocatable :: F_DFT(:,:), D_DS(:,:)
 *
       Erest_xc=0.0d0
-      Call GetMem('F-DS','Allo','Real',ipF_DFT,2*nBT)
-      Call GetMem('D-DS','Allo','Real',ip_D_DS,2*nBT)
-      ip_Da=ip_D_DS
-      ip_Db=ip_D_DS+nBT
+      Call mma_allocate(D_DS ,nBT,2,Label='D_DS ')
+      D_DS(:,:)=Zero
 *
       iOff=1
-      jOff=0
+      jOff=1
       Do iSym=1,nSym
-         ipDaa=ip_Da+jOff
          Call DGEMM_tri('N','T',nBas(iSym),nBas(iSym),nOcc(iSym,1),
      &                    1.0d0,CMO(iOff,1),nBas(iSym),
      &                          CMO(iOff,1),nBas(iSym),
-     &                    0.0d0,Work(ipDaa),nBas(iSym))
-         ipDbb=ip_Db+jOff
+     &                    0.0d0,D_DS(jOff:,1),nBas(iSym))
          Call DGEMM_tri('N','T',nBas(iSym),nBas(iSym),nOcc(iSym,2),
      &                    1.0d0,CMO(iOff,2),nBas(iSym),
      &                          CMO(iOff,2),nBas(iSym),
-     &                    0.0d0,Work(ipDbb),nBas(iSym))
+     &                    0.0d0,D_DS(jOff:,2),nBas(iSym))
          Do j=1,nBas(iSym)
             Do i=1,j-1
                ji=j*(j-1)/2+i
-               iDaa=ipDaa-1+ji
-               Work(iDaa)=2.0d0*Work(iDaa)
-               iDbb=ipDbb-1+ji
-               Work(iDbb)=2.0d0*Work(iDbb)
+               iDji=iOff-1+ji
+               D_DS(iDji,1)=2.0d0*D_DS(iDji,1)
+               D_DS(iDji,2)=2.0d0*D_DS(iDji,2)
             End Do
          End Do
          iOff=iOff+nBas(iSym)*nOrb(iSym)
@@ -52,34 +48,34 @@
       End Do
 *
 *----------------------------------------------------------------------*
-      Call Get_Fmat_nondyn(Work(ip_Da),Work(ip_Db),nBT,.true.)
+      Call Get_Fmat_nondyn(D_DS(:,1),D_DS(:,2),nBT,.true.)
 *----------------------------------------------------------------------*
 *
 *----------------------------------------------------------------------*
-      Call Get_Exc_dft(nh1,Grad,nGrad,DFTFOCK,ipF_DFT,ip_D_DS,
+      Call mma_allocate(F_DFT,nBT,2,Label='F_DFT')
+      Call Get_Exc_dft(nh1,Grad,nGrad,DFTFOCK,F_DFT,D_DS,nBT,2,
      &                     KSDFT)
 *----------------------------------------------------------------------*
 *
-      Call GetMem('D-DS','Free','Real',ip_D_DS,2*nBT)
-      Call GetMem('F-DS','Free','Real',ipF_DFT,2*nBT)
+      Call mma_deallocate(D_DS)
+      Call mma_deallocate(F_DFT)
       Return
       End
 *                                                                      *
 ************************************************************************
 *                                                                      *
-      Subroutine Get_Exc_dft(nh1,Grad,nGrad,DFTFOCK,ipF_DFT,ip_D_DS,
+      Subroutine Get_Exc_dft(nh1,Grad,nGrad,DFTFOCK,F_DFT,D_DS,nBT,nD,
      &                       KSDFT)
-      use nq_Info
+      use nq_Info, only: Dens_I, Grad_I, Tau_I
       Implicit Real*8 (a-h,o-z)
 #include "real.fh"
-#include "WrkSpc.fh"
 #include "debug.fh"
       Real*8  Grad(nGrad)
       Logical Do_MO,Do_TwoEl,Do_Grad
       Character*4 DFTFOCK
-      Character*16  KSDFT
+      Character*80  KSDFT
 #include "dcscf.fh"
-
+      Real*8 :: D_DS(nBT,nD), F_DFT(nBT,nD)
 *
       Debug=.False.
 *                                                                      *
@@ -100,8 +96,7 @@
 ************************************************************************
 *                                                                      *
       Call Driver(KSDFT,Do_Grad,Func,Grad,nGrad,
-     &            Do_MO,Do_TwoEl,Work(ip_D_DS),
-     &                          Work(ipF_DFT),nh1,nFckDim,DFTFOCK)
+     &            Do_MO,Do_TwoEl,D_DS,F_DFT,nh1,nFckDim,DFTFOCK)
 *                                                                      *
 ************************************************************************
 *                                                                      *
@@ -113,8 +108,7 @@
       write(6,*) ' XC-potentials: (itri,F_alpha,F_beta)'
       write(6,*)
       Do i=1,nh1
-        Write(6,'(i4,3f22.16)') i,Work(ipF_DFT+i-1),
-     &                            Work(ipF_DFT+i-1+nh1)
+        Write(6,'(i4,3f22.16)') i,F_DFT(i,1),F_DFT(i,2)
       End Do
 #endif
 *
