@@ -104,10 +104,10 @@
      &                  1.0d0,OvlS,nBas(iSym),
      &                        TrMat(iOld),nBas(iSym),
      &                  0.0d0,OvlH,nBas(iSym))
-            Call MxMt(TrMat(iOld),nBas(iSym),1,
-     &                OvlH,1,nBas(iSym),
-     &                OvlT,
-     &                nOF,nBas(iSym))
+            Call DGEMM_Tri('T','N',nOF,nOF,nBas(iSym),
+     &                    One,TrMat(iOld),nBas(iSym),
+     &                        OvlH,nBas(iSym),
+     &                    Zero,OvlT,nOF)
 *
 *---------- Diagonalize overlap and form eigenvalues vector
             Call mma_allocate(Scratch,nOF**2,Label='Scrtach')
