@@ -31,14 +31,15 @@
 *                                                                      *
 ************************************************************************
       use SCF_Arrays
+#ifdef _FDE_
+      use Embedding_Global, only: embInt, embPot, embPotInBasis,
+     &                            embPotPath
+#endif
       Implicit Real*8 (a-h,o-z)
 #include "mxdm.fh"
 #include "infscf.fh"
 #include "stdalloc.fh"
 #include "real.fh"
-#ifdef _FDE_
-#include "embpotdata.fh"
-#endif
 *
 *---- Define local variables
       Character*8 Label
@@ -53,9 +54,8 @@
       Call Get_iScalar('embpot', iDummyEmb)
       if (iDummyEmb.eq.1) embPot=.true.
       if (embPot) then
-         call mma_allocate(Emb,nBT,Label='Emb')
-         ipEmb=ip_of_Work(Emb(1))
-         Call EmbPotRdRun
+         call mma_allocate(embInt,nBT,Label='Emb')
+         Call EmbPotRdRun()
       end if
 #endif
 *---- Allocate memory for one-electron integrals
@@ -86,14 +86,14 @@
         iunit = isFreeUnit(1)
         call molcas_open(iunit, embPotPath)
         do iEmb=1, nBT
-         read(iunit,*) Emb(iEmb)
+         read(iunit,*) embInt(iEmb)
         end do
         close(iunit)
        else
         ! Read one-electron integrals due to embedding potential
         iRc=-1
         Label='embpot  '
-        Call RdOne(iRc,iOpt,Label,iComp,Emb,iSyLbl)
+        Call RdOne(iRc,iOpt,Label,iComp,embInt,iSyLbl)
         If (iRc.ne.0) Then
            Write (6,*) 'R1Inta: Error readin ONEINT'
            Write (6,'(A,A)') 'Label=',Label
