@@ -61,16 +61,16 @@
 #ifdef _HDF5_
       Use mh5, Only: mh5_close_file
 #endif
+      use InfSO
       Implicit Real*8 (a-h,o-z)
 *
 #include "real.fh"
 #include "mxdm.fh"
 #include "infscf.fh"
-#include "infso.fh"
 #include "file.fh"
       Real*8 CMO(mBB,nD), TrM(mBB,nD), OneHam(mBT), Fock(mBT,nD),
      &       Ovrlp(mBT), EOrb(mmB,nD), OccNo(mmB,nD)
-      Character FName*512, KSDFT_save*16
+      Character FName*512, KSDFT_save*80
       Logical FstItr
       Logical found
 *
