@@ -18,25 +18,24 @@
 *     called from: SOrb                                                *
 *                                                                      *
 ************************************************************************
+      use SpinAV
       Implicit Real*8 (a-h,o-z)
 #include "real.fh"
 #include "file.fh"
 #include "mxdm.fh"
 #include "infscf.fh"
-#include "WrkSpc.fh"
 #include "stdalloc.fh"
 *
       Character FName*(*), Line*62
       Integer nTmp(8), nIF(8), nRASO(8), nBD(8), nZero(8), nHoles(8)
       Integer nSsh(8), nSsh_ab(8)
 #include "dcscf.fh"
-#include "spave.fh"
 * Pam 2012 Changed VECSORT arg list, need dummy array:
       Integer iDummy(1)
       Real*8 CMO(mBB,nD), EOrb(mmB,nD), OccNo(mmB,nD)
       Integer, Dimension(:), Allocatable:: IndT, ID_vir
-      Real*8, Dimension(:,:), Allocatable:: Da
-      Integer, Dimension(:,:), Allocatable:: Match
+      Real*8, Allocatable:: Da(:,:)
+      Integer, Allocatable:: Match(:,:)
       Real*8, Dimension(:), Allocatable:: Corb, SAV, SLT, SQ
       Real*8 Dummy(1)
 ************************************************************************
@@ -180,7 +179,7 @@
       Call TrimEor(EOrb,EOrb,nSym,nBas,nOrb)
       Call mma_deallocate(IndT)
 *
-      Call Setup
+      Call Setup()
 *
       Call Izero(nBD,nSym)
       Do iSym=2,nSym
@@ -188,7 +187,7 @@
      &             + nBas(iSym-1)*(nBas(iSym-1)+1)/2
       End Do
       Call mma_allocate(Da,nBT,2,Label='Da')
-      Call Fzero(Da,2*nBT)
+      Da(:,:)=Zero
       Call mma_allocate(Match,2,MxConstr,Label='Match')
       Call mma_allocate(Corb,MaxBas,Label='Corb')
 *
@@ -293,7 +292,8 @@
 *
       If (Do_SpinAV) Then
          Call mma_deallocate(SAV)
-         Call GetMem('DSc','Allo','Real',ip_DSc,nBB)
+         Call mma_Allocate(DSc,nBB,Label='DSc')
+         DSC(:)=Zero
       EndIf
 *
       iOff=1
@@ -313,16 +313,16 @@
      &                    0.0d0,Da(ipDbb,2),nBas(iSym))
 *
          If (Do_SpinAV) Then
-            ipDScc=ip_DSc+lOff
+            ipDScc=lOff
             Do j=1,nBas(iSym)
                Do i=1,j
                   ji=j*(j-1)/2+i
                   iDaa=ipDaa-1+ji
                   iDbb=ipDbb-1+ji
-                  iDSc=ipDScc-1+nBas(iSym)*(j-1)+i
-                  Work(iDSc)=0.5d0*(Da(iDaa,1)-Da(iDbb,2))
-                  kDSc=ipDScc-1+nBas(iSym)*(i-1)+j
-                  Work(kDSc)=Work(iDSc)
+                  iDSc=ipDScc+nBas(iSym)*(j-1)+i
+                  DSc(iDSc)=0.5d0*(Da(iDaa,1)-Da(iDbb,2))
+                  kDSc=ipDScc+nBas(iSym)*(i-1)+j
+                  DSc(kDSc)=DSc(iDSc)
                End Do
             End Do
             lOff=lOff+nBas(iSym)**2
@@ -345,9 +345,8 @@
          Call WarningMessage(2,'Start6. Non-zero rc in Cho_X_init.')
          Call Abend
       endif
-
 *----------------------------------------------------------------------*
-      Call Get_Fmat_nondyn(Da(1,1),Da(1,2),nBT,.false.)
+      Call Get_Fmat_nondyn(Da(:,1),Da(:,2),nBT,.false.)
 *----------------------------------------------------------------------*
 
       Call Cho_X_Final(irc)
@@ -473,11 +472,11 @@ c      Call ChkOrt(CMO(1,2),nBB,SLT,nnB,Whatever) ! silent
       Subroutine Get_Fmat_nondyn(Dma,Dmb,nBDT,DFTX)
       Use Fock_util_global, only: Deco
       use Data_Structures, only: Allocate_DT, Deallocate_DT, DSBA_Type
+      use SpinAV
       Implicit Real*8 (a-h,o-z)
 #include "real.fh"
 #include "mxdm.fh"
 #include "infscf.fh"
-#include "WrkSpc.fh"
 #include "stdalloc.fh"
 *
       Integer nBDT
@@ -493,9 +492,7 @@ c      Call ChkOrt(CMO(1,2),nBB,SLT,nnB,Whatever) ! silent
       Type (DSBA_Type) FLT(2), KLT(2), POrb(2), PLT(2)
 *
 #include "dcscf.fh"
-#include "spave.fh"
 *
-
       nDMat=2
       Do i=1,nSym
          nForb(i,1)=0
@@ -519,8 +516,8 @@ c      Call ChkOrt(CMO(1,2),nBB,SLT,nnB,Whatever) ! silent
       Call Allocate_DT(POrb(2),nBas,nBas,nSym)
 
       Call mma_allocate(Dm,nBB,2,Label='Dm')
-      Call UnFold(Dma,nBDT,Dm(1,1),nBB,nSym,nBas)
-      Call UnFold(Dmb,nBDT,Dm(1,2),nBB,nSym,nBas)
+      Call UnFold(Dma,nBDT,Dm(:,1),nBB,nSym,nBas)
+      Call UnFold(Dmb,nBDT,Dm(:,2),nBB,nSym,nBas)
 *
       If (Do_SpinAV) Then
          If (.not.DECO) Then
@@ -528,8 +525,8 @@ c      Call ChkOrt(CMO(1,2),nBB,SLT,nnB,Whatever) ! silent
            write(6,*) ' NODE will be reset to default. '
            DECO=.true.
          EndIf
-         Call daxpy_(NBB,-1.0d0,Work(ip_DSc),1,Dm(1,1),1)
-         Call daxpy_(NBB, 1.0d0,Work(ip_DSc),1,Dm(1,2),1)
+         Call daxpy_(NBB,-1.0d0,DSc,1,Dm(:,1),1)
+         Call daxpy_(NBB, 1.0d0,DSc,1,Dm(:,2),1)
       EndIf
 *
       iOff=0
@@ -539,6 +536,7 @@ c      Call ChkOrt(CMO(1,2),nBB,SLT,nnB,Whatever) ! silent
      &                  nIorb(i,1),1.0d-12,irc)
          If (irc.ne.0) Then
             write(6,*) ' Alpha density. Sym= ',i,'   rc= ',irc
+            Call RecPrt('Dm',' ',Dm(ipDai,1),nBas(i),nBas(i))
             Call Abend()
          EndIf
          ipDbi=1+iOff
@@ -546,6 +544,7 @@ c      Call ChkOrt(CMO(1,2),nBB,SLT,nnB,Whatever) ! silent
      &                  nIorb(i,2),1.0d-12,irc)
          If (irc.ne.0) Then
             write(6,*) ' Beta density. Sym= ',i,'   rc= ',irc
+            Call RecPrt('Dm',' ',Dm(ipDbi,1),nBas(i),nBas(i))
             Call Abend()
          EndIf
          iOff=iOff+nBas(i)**2
@@ -572,8 +571,8 @@ c      Call ChkOrt(CMO(1,2),nBB,SLT,nnB,Whatever) ! silent
       If (Do_SpinAV) Then
          Call UnFold(Dma,nBDT,Dm(1,1),nBB,nSym,nBas)
          Call UnFold(Dmb,nBDT,Dm(1,2),nBB,nSym,nBas)
-         Call daxpy_(NBB,-1.0d0,Work(ip_DSc),1,Dm(1,1),1)
-         Call daxpy_(NBB, 1.0d0,Work(ip_DSc),1,Dm(1,2),1)
+         Call daxpy_(NBB,-1.0d0,DSc,1,Dm(1,1),1)
+         Call daxpy_(NBB, 1.0d0,DSc,1,Dm(1,2),1)
          Call Fold(nSym,nBas,Dm(1,1),Dma)
          Call Fold(nSym,nBas,Dm(1,2),Dmb)
       EndIf
