@@ -319,10 +319,10 @@
 *        Write(6,*) 'Using Guessorb orbitals'
          If(OccSet) Then
 *           Write(6,*) 'Occupation is set'
-            Continue
+            !continue
          Else If(FermSet) Then
 *           Write(6,*) 'Fermi is set'
-            Continue
+            !continue
          Else
 *           Write(6,*) 'Must decide if to use Fermi'
             If(nAufb(1).eq.-1) Then
