@@ -36,6 +36,8 @@
 ************************************************************************
 *
       Use Functionals, only: Print_Info
+      Use KSDFT_Info, only: CoefR, CoefX
+      Use InfSO
 *
       Implicit Real*8 (a-h,o-z)
 *
@@ -44,10 +46,8 @@
 
 #include "mxdm.fh"
 #include "infscf.fh"
-#include "infso.fh"
 #include "rctfld.fh"
 #include "ldfscf.fh"
-#include "ksdft.fh"
 *
 *---- Define local variables
       Character*60 Fmt, FmtR, FmtI
