@@ -13,7 +13,7 @@
 
       Implicit None
 #include "stdalloc.fh"
-      Integer, Parameter            :: wp=selected_real_kind(p=15,r=307)
+      Integer, Parameter            :: wp=kind(0.d0)
       Integer, intent(in)           :: iprint, iDIM
       Integer, intent(in)           :: nDIMcf, iopt, nlanth
       Real(kind=8), intent(in)     :: ESOJ(nDIMcf)
@@ -189,7 +189,7 @@ C================== Variable declarations =============================
 
       Implicit None
 #include "stdalloc.fh"
-      Integer, Parameter            :: wp=selected_real_kind(p=15,r=307)
+      Integer, Parameter            :: wp=kind(0.d0)
       Integer, intent(in)           :: nDIMcf, nlanth, iprint
       Logical, intent(in)           :: GRAD
       Real(kind=8), intent(in)     :: ESOJ(nDIMcf)
@@ -197,17 +197,15 @@ C================== Variable declarations =============================
       ! local variables:
       Integer                       :: info, i, j, k, q
       Integer                       :: LuCF, IsFreeUnit
-      Real(kind=8)                 :: dznrm2
       Real(kind=8), allocatable    :: Winit(:), Eloc(:), a(:)
       Real(kind=8)                 :: BNC(nDIMcf,0:nDIMcf)
       Real(kind=8)                 :: BNS(nDIMcf,0:nDIMcf)
       Real(kind=8)                 :: Bstev(nDIMcf,-nDIMcf:nDIMcf)
-      Complex(kind=8)              :: trace
       Complex(kind=8)              ::
      &                   Akq((nDIMcf-1),-(nDIMcf-1):(nDIMcf-1))
       Complex(kind=8), allocatable :: Zinit(:,:), Z(:,:),
      &                                  HCF(:,:)
-      External           :: trace, dznrm2, IsFreeUnit
+      External           :: IsFreeUnit
 
 C============== End of variable declarations ==========================
       Call mma_allocate(Winit,nDIMcf,'Winit')
@@ -344,7 +342,7 @@ c-----------------------------------------------------------------------
 
       Subroutine newCF(H,n,A, B,C,Bstev)
       Implicit none
-      Integer, Parameter          :: wp=selected_real_kind(p=15,r=307)
+      Integer, Parameter            :: wp=kind(0.d0)
 #include "stdalloc.fh"
       Integer, intent(in)           :: n
       Complex(kind=8),intent(in)   :: H(n,n)
@@ -449,7 +447,7 @@ c-----------------------------------------------------------------------
 
       Subroutine recover_CF(N,HAM,Akq,B,C,Bstev)
       Implicit none
-      Integer, Parameter           :: wp=selected_real_kind(p=15,r=307)
+      Integer, Parameter            :: wp=kind(0.d0)
       Integer, intent(in)          :: n
       Complex(kind=8), intent(in) :: HAM(n,n)
       Complex(kind=8), intent(in) :: Akq((n-1), -(n-1):(n-1))
