@@ -13,9 +13,6 @@
 *                                                                      *
       Module Chkpnt
       Implicit None
-#ifdef _HDF5_
-#  include "mh5.fh"
-#endif
       Character(Len=9) :: basename = 'SLAPAFCHK'
       Character(Len=12) :: filename
       Integer :: chkpnt_id, chkpnt_iter, chkpnt_hess
@@ -28,8 +25,11 @@
 *                                                                      *
       Subroutine Chkpnt_open()
 #ifdef _HDF5_
-      use Symmetry_Info, only: nIrrep
-#  include "info_slapaf.fh"
+      Use Symmetry_Info, Only: nIrrep
+      Use Slapaf_Info, Only: Coor
+      Use Slapaf_Parameters, Only: IRC, iter
+      Use mh5, Only: mh5_is_hdf5, mh5_open_file_rw, mh5_open_attr,
+     &               mh5_open_dset, mh5_fetch_attr
       Character(Len=3) :: level
       Logical :: create
       Integer :: tmp
@@ -52,7 +52,7 @@
         Call mh5_fetch_attr(chkpnt_id, 'NSYM', tmp)
         If (tmp.ne.nIrrep) create = .True.
         Call mh5_fetch_attr(chkpnt_id, 'NATOMS_UNIQUE', tmp)
-        If (tmp.ne.nsAtom) create = .True.
+        If (tmp.ne.SIZE(Coor,2)) create = .True.
         Call mh5_fetch_attr(chkpnt_id, 'ITERATIONS', tmp)
         If (IRC.eq.-1) Then
           If (Iter.ge.tmp) create = .True.
@@ -77,13 +77,19 @@
 *                                                                      *
       Subroutine Chkpnt_init()
 #ifdef _HDF5_
-      use Phase_Info
-      use Symmetry_Info, only: nIrrep
-#  include "info_slapaf.fh"
-#  include "WrkSpc.fh"
+      Use Phase_Info
+      Use Symmetry_Info, Only: nIrrep
+      Use Slapaf_Info, Only: dMass, nStab, iCoSet, AtomLbl, Smmtrc,
+     &                       Coor
+      Use Slapaf_Parameters, Only: nDimBC, rMEP, MEP, dMEPStep
+      Use mh5, Only: mh5_create_file, mh5_init_attr,
+     &               mh5_create_attr_int, mh5_create_dset_str,
+     &               mh5_create_dset_real, mh5_create_dset_int,
+     &               mh5_put_dset, mh5_close_dset
+#  include "Molcas.fh"
 #  include "stdalloc.fh"
       Character :: lIrrep(24)
-      Integer :: dsetid, attrid, mAtom, i, j, k
+      Integer :: dsetid, mAtom, i, j, k
       Real*8, Allocatable :: charges(:)
       Integer, Allocatable :: desym(:,:), symdof(:,:)
 
@@ -97,33 +103,33 @@
       Call mh5_init_attr(chkpnt_id, 'IRREP_LABELS',
      &                   1, [nIrrep], lIrrep, 3)
 
-      Call mh5_init_attr(chkpnt_id, 'NATOMS_UNIQUE', nsAtom)
+      Call mh5_init_attr(chkpnt_id, 'NATOMS_UNIQUE', SIZE(Coor,2))
 
       Call mh5_init_attr(chkpnt_id, 'DOF', nDimBC)
 
 *     atom labels
       dsetid = mh5_create_dset_str(chkpnt_id,
-     &         'CENTER_LABELS', 1, [nsAtom], LENIN)
-      Call mh5_init_attr(dsetid, 'description',
+     &         'CENTER_LABELS', 1, [SIZE(Coor,2)], LENIN)
+      Call mh5_init_attr(dsetid, 'DESCRIPTION',
      &     'Unique center labels arranged as one [NATOMS_UNIQUE] block')
       Call mh5_put_dset(dsetid, AtomLbl)
       Call mh5_close_dset(dsetid)
 
 *     atom masses
       dsetid = mh5_create_dset_real(chkpnt_id,
-     &         'CENTER_MASSES', 1, [nsAtom])
-      Call mh5_init_attr(dsetid, 'description',
+     &         'CENTER_MASSES', 1, [SIZE(Coor,2)])
+      Call mh5_init_attr(dsetid, 'DESCRIPTION',
      &    'Nuclear masses, stored as array of size [NATOMS_UNIQUE]')
-      Call mh5_put_dset(dsetid, Work(ipCM))
+      Call mh5_put_dset(dsetid, dMass)
       Call mh5_close_dset(dsetid)
 
 *     atom charges
       dsetid = mh5_create_dset_real(chkpnt_id,
-     &         'CENTER_CHARGES', 1, [nsAtom])
-      Call mh5_init_attr(dsetid, 'description',
+     &         'CENTER_CHARGES', 1, [SIZE(Coor,2)])
+      Call mh5_init_attr(dsetid, 'DESCRIPTION',
      &    'Nuclear charges, stored as array of size [NATOMS_UNIQUE]')
-      Call mma_allocate(charges, nsAtom)
-      Call Get_dArray('Nuclear Charge', charges, nsAtom)
+      Call mma_allocate(charges, SIZE(Coor,2))
+      Call Get_dArray('Nuclear Charge', charges, SIZE(Coor,2))
       Call mh5_put_dset(dsetid, charges)
       Call mma_deallocate(charges)
       Call mh5_close_dset(dsetid)
@@ -135,22 +141,22 @@
 *     atom coordinates (new iteration)
 *       use the same dataset name as in run2hdf5
       chkpnt_new = mh5_create_dset_real(chkpnt_id,
-     &             'CENTER_COORDINATES', 2, [3,nsAtom])
-      Call mh5_init_attr(chkpnt_new, 'description',
+     &             'CENTER_COORDINATES', 2, [3,SIZE(Coor,2)])
+      Call mh5_init_attr(chkpnt_new, 'DESCRIPTION',
      &     'Atom coordinates for new iteration, matrix of size '//
      &     '[NATOMS_UNIQUE,3], stored with atom index varying slowest')
 
       If (nIrrep.gt.1) Then
 
         mAtom = 0
-        Do i=1,nsAtom
+        Do i=1,SIZE(Coor,2)
           mAtom = mAtom+nIrrep/nStab(i)
         End Do
         Call mma_allocate(desym, 4, mAtom)
         Call mma_allocate(symdof, 2, nDimBC)
         mAtom = 0
         k = 0
-        Do i=1,nsAtom
+        Do i=1,SIZE(Coor,2)
           Do j=0,nIrrep/nStab(i)-1
             mAtom = mAtom+1
             desym(1,mAtom) = i
@@ -159,7 +165,7 @@
             desym(4,mAtom) = iPhase(3,iCoSet(j,i))
           End Do
           Do j=1,3
-            If (.Not.Smmtrc(3*(i-1)+j)) Cycle
+            If (.Not.Smmtrc(j,i)) Cycle
             k = k+1
             symdof(1,k) = i
             symdof(2,k) = j
@@ -172,23 +178,23 @@
 *     desymmetrization factors
         dsetid = mh5_create_dset_int(chkpnt_id,
      &           'DESYM_FACTORS', 2, [4,mAtom])
-        Call mh5_init_attr(dsetid, 'description',
+        Call mh5_init_attr(dsetid, 'DESCRIPTION',
      &      'Factors for obtaining all coordinates, matrix of size '//
      &      '[NATOMS_ALL,4], each row contains the unique atom index'//
      &      'and the factors with which to multiply the x,y,z '//
      &      'coordinates')
-        Call mh5_put_dset(dsetid, desym(1,1))
+        Call mh5_put_dset(dsetid, desym)
         Call mh5_close_dset(dsetid)
         Call mma_deallocate(desym)
 
 *     symmetry-unique degrees of freedom (Cartesian indices)
         dsetid = mh5_create_dset_int(chkpnt_id,
      &           'DOF_INDICES', 2, [2, nDimBC])
-        Call mh5_init_attr(dsetid, 'description',
+        Call mh5_init_attr(dsetid, 'DESCRIPTION',
      &      'Indices of the Cartesian degrees of freedom, matrix of '//
      &      'size [DOF, 2], each row contains the atom index and the '//
      &      'Cartesian index (1=x, 2=y, 3=z)')
-        Call mh5_put_dset(dsetid, symdof(1,1))
+        Call mh5_put_dset(dsetid, symdof)
         Call mh5_close_dset(dsetid)
         Call mma_deallocate(symdof)
       End If
@@ -198,22 +204,22 @@
 *     energies
       chkpnt_ener = mh5_create_dset_real(chkpnt_id,
      &              'ENERGIES', 1, [0], dyn=.True.)
-      Call mh5_init_attr(chkpnt_ener, 'description',
+      Call mh5_init_attr(chkpnt_ener, 'DESCRIPTION',
      &     'Energies for all iterations as a matrix of size '//
      &     '[ITERATIONS]')
 
 *     atom coordinates
       chkpnt_coor = mh5_create_dset_real(chkpnt_id,
-     &              'COORDINATES', 3, [3,nsAtom,0], dyn=.True.)
-      Call mh5_init_attr(chkpnt_coor, 'description',
+     &              'COORDINATES', 3, [3,SIZE(Coor,2),0], dyn=.True.)
+      Call mh5_init_attr(chkpnt_coor, 'DESCRIPTION',
      &     'Atom coordinates, matrix of size [ITERATIONS,'//
      &     'NATOMS_UNIQUE,3], stored with iteration varying slowest, '//
      &     'then atom index')
 
 *     Cartesian forces (F = -g)
       chkpnt_force = mh5_create_dset_real(chkpnt_id,
-     &               'FORCES', 3, [3,nsAtom,0], dyn=.True.)
-      Call mh5_init_attr(chkpnt_force, 'description',
+     &               'FORCES', 3, [3,SIZE(Coor,2),0], dyn=.True.)
+      Call mh5_init_attr(chkpnt_force, 'DESCRIPTION',
      &     'Cartesian forces, matrix of size [ITERATIONS,'//
      &     'NATOMS_UNIQUE,3], stored with iteration varying slowest, '//
      &     'then atom index')
@@ -221,18 +227,18 @@
 *     Cartesian Hessian
       chkpnt_hess = mh5_create_dset_real(chkpnt_id,
      &              'HESSIAN', 1, [nDimBC*(nDimBC+1)/2])
-      Call mh5_init_attr(chkpnt_hess, 'description',
+      Call mh5_init_attr(chkpnt_hess, 'DESCRIPTION',
      &     'Cartesian Hessian in triangular form, as a vector of '//
      &     'size [DOF*(DOF+1)/2]')
 
 *     MEP/IRC information
       If (MEP.or.rMEP) Then
         Call mh5_init_attr(chkpnt_id, 'MEP_STEP', dMEPStep)
-        attrid = mh5_create_attr_int(chkpnt_id, 'MEP_ITERATIONS')
+        Call mh5_init_attr(chkpnt_id, 'MEP_ITERATIONS', 0)
 
         dsetid = mh5_create_dset_int(chkpnt_id,
      &           'MEP_INDICES', 1, [0], dyn=.True.)
-        Call mh5_init_attr(dsetid, 'description',
+        Call mh5_init_attr(dsetid, 'DESCRIPTION',
      &       'Iteration number for each converged MEP step, as a '//
      &       'vector of size [MEP_ITERATIONS]')
       End If
@@ -244,10 +250,13 @@
 *                                                                      *
       Subroutine Chkpnt_update()
 #ifdef _HDF5_
-#  include "info_slapaf.fh"
+      Use Slapaf_Info, Only: Cx, Gx, Energy
+      Use Slapaf_Parameters, Only: nDimBC, iter
+      Use mh5, Only: mh5_put_attr, mh5_resize_dset,
+     &               mh5_put_dset
 #  include "WrkSpc.fh"
 #  include "stdalloc.fh"
-      Integer :: N3, i, j
+      Integer :: i, j
       Logical :: Found
       Real*8, Allocatable :: Hss_X(:)
 
@@ -266,23 +275,22 @@
         End Do
       End If
 
-      N3 = 3*nsAtom
 *     iterations
       Call mh5_put_attr(chkpnt_iter, Iter_all)
 *     energies
       Call mh5_resize_dset(chkpnt_ener, [Iter_all])
-      Call mh5_put_dset_array_real(chkpnt_ener,
-     &     Work(ipEner+(Iter-1)), [1], [Iter_all-1])
+      Call mh5_put_dset(chkpnt_ener,
+     &     Energy(Iter:Iter), [1], [Iter_all-1])
 *     coordinates
-      Call mh5_resize_dset(chkpnt_coor, [3,nsAtom,Iter_all])
-      Call mh5_put_dset_array_real(chkpnt_coor,
-     &     Work(ipCx+N3*(Iter-1)), [3,nsAtom,1], [0,0,Iter_all-1])
+      Call mh5_resize_dset(chkpnt_coor, [3,SIZE(Cx,2),Iter_all])
+      Call mh5_put_dset(chkpnt_coor,
+     &     Cx(:,:,Iter), [3,SIZE(Cx,2),1], [0,0,Iter_all-1])
 *     new coordinates
-      Call mh5_put_dset(chkpnt_new,Work(ipCx+N3*Iter))
+      Call mh5_put_dset(chkpnt_new,Cx(1,1,Iter+1))
 *     forces
-      Call mh5_resize_dset(chkpnt_force, [3,nsAtom,Iter_all])
-      Call mh5_put_dset_array_real(chkpnt_force,
-     &     Work(ipGx+N3*(Iter-1)), [3,nsAtom,1], [0,0,Iter_all-1])
+      Call mh5_resize_dset(chkpnt_force, [3,SIZE(Cx,2),Iter_all])
+      Call mh5_put_dset(chkpnt_force,
+     &     Gx(:,:,Iter), [3,SIZE(Cx,2),1], [0,0,Iter_all-1])
 *     Hessian
       If (Found) Then
         Call mh5_put_dset(chkpnt_hess,Hss_X(1))
@@ -293,28 +301,38 @@
 *                                                                      *
 ************************************************************************
 *                                                                      *
-      Subroutine Chkpnt_update_MEP(IRCRestart)
-      Logical, Intent(In) :: IRCRestart
+      Subroutine Chkpnt_update_MEP(SaveMEP,IRCRestart)
+#ifdef _HDF5_
+      Use mh5, Only: mh5_init_attr, mh5_open_attr, mh5_get_attr,
+     &               mh5_put_attr,  mh5_close_attr, mh5_open_dset,
+     &               mh5_resize_dset, mh5_put_dset, mh5_close_dset
+#endif
+      Logical, Intent(In) :: SaveMEP, IRCRestart
 #ifdef _HDF5_
-#  include "info_slapaf.fh"
       Integer :: attrid, dsetid, iMEP
 
       If (IRCRestart) Then
         Call mh5_init_attr(chkpnt_id, 'IRC_RESTART', Iter_all+1)
       End If
-      attrid = mh5_open_attr(chkpnt_id, 'MEP_ITERATIONS')
-      Call mh5_get_attr(attrid, iMEP)
-      iMEP = iMEP+1
-      Call mh5_put_attr(attrid, iMEP)
-      Call mh5_close_attr(attrid)
-      dsetid = mh5_open_dset(chkpnt_id, 'MEP_INDICES')
-      Call mh5_resize_dset(dsetid, [iMEP])
-      Call mh5_put_dset_array_int(dsetid, [Iter_all], [1], [iMEP-1])
-      Call mh5_close_dset(dsetid)
+      If (SaveMEP) Then
+        attrid = mh5_open_attr(chkpnt_id, 'MEP_ITERATIONS')
+        Call mh5_get_attr(attrid, iMEP)
+        iMEP = iMEP+1
+        Call mh5_put_attr(attrid, iMEP)
+        Call mh5_close_attr(attrid)
+        dsetid = mh5_open_dset(chkpnt_id, 'MEP_INDICES')
+        Call mh5_resize_dset(dsetid, [iMEP])
+        Call mh5_put_dset(dsetid, [Iter_all], [1], [iMEP-1])
+        Call mh5_close_dset(dsetid)
+      End If
 #else
       Return
-* Avoid unused argument warnings
-      If (.False.) Call Unused_logical(IRCRestart)
+#ifdef _WARNING_WORKAROUND_
+      If (.False.) Then
+        Call Unused_logical(SaveMEP)
+        Call Unused_logical(IRCRestart)
+      End If
+#endif
 #endif
       End Subroutine Chkpnt_update_MEP
 *                                                                      *
@@ -322,6 +340,7 @@
 *                                                                      *
       Subroutine Chkpnt_close()
 #ifdef _HDF5_
+      Use mh5, Only: mh5_close_file
       Call mh5_close_file(chkpnt_id)
 #endif
       End Subroutine Chkpnt_close
