@@ -27,22 +27,17 @@
 *> @param[in]     nAtom Number of symmetry-unique atoms
 ************************************************************************
       Subroutine Align(Coord,Ref,nAtom)
-      use Symmetry_Info, only: nIrrep, iOper
+      use Symmetry_Info, only: nIrrep, iOper, VarR, VarT
+      use Slapaf_Info, only: Weights
       Implicit Real*8 (a-h,o-z)
 #include "real.fh"
-#include "sbs.fh"
-#include "WrkSpc.fh"
 #include "stdalloc.fh"
-#include "info_slapaf.fh"
-#include "weighting.fh"
       Real*8 Coord(3*nAtom), Ref(3*nAtom)
-      Logical Invar
       Real*8, Allocatable:: Coor_All(:,:), Ref_All(:,:)
       Integer, Allocatable:: iStab(:)
 
 *---- Do nothing if the energy is not rot. and trans. invariant
-      Invar=(iAnd(iSBS,2**7).eq.0).and.(iAnd(iSBS,2**8).eq.0)
-      If (.Not.Invar) Return
+      If (VarR.or.VarT) Return
 
       Call mma_allocate(Coor_All,3,nAtom*8,Label='Coor_All')
       Call Expand_Coor(Coord,nAtom,Coor_All,mAtom)
@@ -51,8 +46,7 @@
 
 c     Call RecPrt('Coord before align',' ',Coor_All,3,mAtom)
 
-      Call Superpose_w(Coor_All,Ref_All,Work(ipWeights),mAtom,
-     &                 RMS,RMSMax)
+      Call Superpose_w(Coor_All,Ref_All,Weights,mAtom,RMS,RMSMax)
 
 *---- Get the stabilizers for each atom (to keep the symmetry)
 *     (code copied from init_slapaf)
