@@ -10,37 +10,34 @@
 ************************************************************************
       Subroutine Angle_List(
      &                 nq,
-     &                 nAtoms,iIter,nIter,Cx,jStab,
-     &                 nStab,nDim,Smmtrc,Process,Value,
-     &                 nB,iANr,qLbl,iRef,
-     &                 fconst,rMult,LuIC,Name,Indq,
+     &                 nsAtom,iIter,nIter,Cx,
+     &                 Process,Value,
+     &                 nB,qLbl,iRef,
+     &                 fconst,rMult,LuIC,Indq,
      &                 Grad_all,iGlow,iGhi,iPrv,Proc_dB,
      &                 iTabBonds,nBonds,iTabAI,mAtoms,iTabAtoms,nMax,
      &                 mB_Tot,mdB_Tot,
      &                 BM,dBM,iBM,idBM,nB_Tot,ndB_Tot,nqB,Thr_small)
       use Symmetry_Info, only: nIrrep, iOper
+      use Slapaf_Info, only: jStab, nStab, AtomLbl, ANr
       Implicit Real*8 (a-h,o-z)
 #include "real.fh"
 #include "print.fh"
 #include "Molcas.fh"
       Parameter (mB = 3*3)
-      Real*8 Cx(3,nAtoms,nIter), A(3,3), Hess(mB**2),
+      Real*8 Cx(3,nsAtom,nIter), A(3,3), Hess(mB**2),
      &       fconst(nB),Value(nB,nIter), rMult(nB),
      &       Ref(3,3), Prv(3,3),
      &       Grad_Ref(9), Axis(3), Perp_Axis(3,2), Grad(mB),
      &       Grad_all(9,iGlow:iGhi,nIter),
      &       BM(nB_Tot), dBM(ndB_Tot)
-      Integer   nStab(nAtoms), iANr(nAtoms),
-     &          iDCRR(0:7), jStab(0:7,nAtoms),
-     &          iStabM(0:7), Ind(3), iDCR(3), iDCRT(0:7),
+      Integer   iDCRR(0:7), iStabM(0:7), Ind(3), iDCR(3), iDCRT(0:7),
      &          iStabN(0:7), iChOp(0:7), Indq(3,nB), nqB(nB),
      &          iTabBonds(3,nBonds), iTabAI(2,mAtoms),
      &          iTabAtoms(2,0:nMax,mAtoms), iBM(nB_Tot),idBM(2,ndB_Tot)
-      Logical Smmtrc(3,nAtoms), Process, PSPrint,
-     &        MinBas, Help, Proc_dB, R_Stab_A
+      Logical Process, MinBas, Help, Proc_dB, R_Stab_A
       Character*14 Label, qLbl(nB)
       Character*3 ChOp(0:7)
-      Character*(LENIN) Name(nAtoms)
       Character*(LENIN4) Lbls(3)
 #include "bondtypes.fh"
 #define _FMIN_
@@ -57,23 +54,20 @@
 ************************************************************************
 *                                                                      *
       If (nBonds.lt.2) Return
+#ifdef _DEBUGPRINT_
       iRout=150
       iPrint=nPrint(iRout)
-#ifdef _DEBUGPRINT_
       iPrint=99
 #endif
 *
       nqA=0
-      PSPrint=.False.
 #ifdef _DEBUGPRINT_
-      If (iPrint.ge.99) PSPrint=.True.
-      If (PSPrint) Write (6,*) ' Enter Bends.'
+      If (iPrint.ge.99) Write (6,*) ' Enter Bends.'
 #endif
       Call FZero(Hess,81)
 *
 *---- Loop over bends
 *
-      bohr=CONST_BOHR_RADIUS_IN_SI_ * 1.0D+10
       MinBas=.False.
       If (MinBas) Then
          Fact=1.3d0
@@ -85,22 +79,21 @@
 *
       Do mAtom_ = 1, mAtoms
          mAtom = iTabAI(1,mAtom_)
-         mr = iTabRow(iANr(mAtom))
+         mr = iTabRow(ANr(mAtom))
          Ind(2) = mAtom
          iDCR(2) = iTabAI(2,mAtom_)
 
          nNeighbor_m = iTabAtoms(1,0,mAtom_)
-         nCoBond_m=nCoBond(mAtom_,mAtoms,nMax,iTabBonds,nBonds,
+         nCoBond_m=nCoBond(mAtom_,mAtoms,nMax,iTabBonds,
      &                     nBonds,iTabAtoms)
          If (nNeighbor_m.lt.2) Go To 100
 *
          Do iNeighbor = 1, nNeighbor_m
             iAtom_ = iTabAtoms(1,iNeighbor,mAtom_)
             iAtom = iTabAI(1,iAtom_)
-            nNeighbor_i = iTabAtoms(1,0,iAtom_)
-            nCoBond_i=nCoBond(iAtom_,mAtoms,nMax,iTabBonds,nBonds,
+            nCoBond_i=nCoBond(iAtom_,mAtoms,nMax,iTabBonds,
      &                        nBonds,iTabAtoms)
-            ir = iTabRow(iANr(iAtom))
+            ir = iTabRow(ANr(iAtom))
             Ind(1) = iAtom
             iDCR(1) = iTabAI(2,iAtom_)
 *
@@ -126,14 +119,13 @@
             Do jNeighbor = 1, nNeighbor_m
                jAtom_ = iTabAtoms(1,jNeighbor,mAtom_)
                jAtom = iTabAI(1,jAtom_)
-               nNeighbor_j = iTabAtoms(1,0,jAtom_)
-               nCoBond_j=nCoBond(jAtom_,mAtoms,nMax,iTabBonds,nBonds,
+               nCoBond_j=nCoBond(jAtom_,mAtoms,nMax,iTabBonds,
      &                           nBonds,iTabAtoms)
                If (nCoBond_i.ge.8 .and.
      &             nCoBond_j.ge.8 .and.
      &             nCoBond_m.ge.8       ) Go To 300
 *
-               jr = iTabRow(iANr(jAtom))
+               jr = iTabRow(ANr(jAtom))
                Ind(3) = jAtom
                iDCR(3) = iTabAI(2,jAtom_)
                If (R_Stab_A(iDCR(3),jStab(0,iAtom),nStab(iAtom)) .and.
@@ -160,7 +152,7 @@
      &                'A(',iAtom,',',mAtom,',',jAtom,')'
 *
 #ifdef _DEBUGPRINT_
-               If (PSPrint) Then
+               If (iPrint.ge.99) Then
                   Call RecPrt('A',' ',Cx(1,iAtom,iIter),1,3)
                   Call RecPrt('B',' ',Cx(1,mAtom,iIter),1,3)
                   Call RecPrt('C',' ',Cx(1,jAtom,iIter),1,3)
@@ -179,7 +171,7 @@
                kDCRT=iDCR(3)
 *
 #ifdef _DEBUGPRINT_
-               If (PSPrint) Then
+               If (iPrint.ge.99) Then
                   Write (6,'(10A)') 'U={',
      &                  (ChOp(jStab(i,iAtom)),i=0,nStab(iAtom)-1),'}  '
                   Write (6,'(10A)') 'V={',
@@ -207,7 +199,7 @@
                End If
 *
 #ifdef _DEBUGPRINT_
-               If (PSPrint) Then
+               If (iPrint.ge.99) Then
                   Write (6,'(10A)') 'N={',
      &                  (ChOp(iStabN(i)),i=0,nStabN-1),'}  '
                End If
@@ -222,7 +214,7 @@
                kDCRR = iDCR(2)
 *
 #ifdef _DEBUGPRINT_
-               If (PSPrint) Then
+               If (iPrint.ge.99) Then
                   Write (6,'(10A)') 'R={',
      &                  (ChOp(iDCRR(i)),i=0,nDCRR-1),'}  '
                   Write (6,'(2A)') 'R=',ChOp(kDCRR)
@@ -240,7 +232,7 @@
      &                    iStabM,nStabM)
 *
 #ifdef _DEBUGPRINT_
-               If (PSPrint) Then
+               If (iPrint.ge.99) Then
                   Write (6,'(10A)') 'M={',
      &                  (ChOp(iStabM(i)),i=0,nStabM-1),'}  '
                End If
@@ -251,7 +243,8 @@
                ideg=nIrrep/nStabM
                Deg=Sqrt(DBLE(iDeg))
 #ifdef _DEBUGPRINT_
-               If (PSPrint) Write (6,*)' nIrrep,nStabM=',nIrrep,nStabM
+               If (iPrint.ge.99) Write (6,*)
+     &            ' nIrrep,nStabM=',nIrrep,nStabM
 #endif
 *
 *------------- Test if coordinate should be included
@@ -262,13 +255,9 @@
                   rim2=(Ref(1,1)-Ref(1,2))**2
      &                +(Ref(2,1)-Ref(2,2))**2
      &                +(Ref(3,1)-Ref(3,2))**2
-                  Rab=Sqrt(rim2)
-                  RabCov=CovRad(iANr(iAtom))+CovRad(iANr(mAtom))
                   rmj2=(Ref(1,2)-Ref(1,3))**2
      &                +(Ref(2,2)-Ref(2,3))**2
      &                +(Ref(3,2)-Ref(3,3))**2
-                  Rbc=Sqrt(rmj2)
-                  RbcCov=CovRad(iANr(jAtom))+CovRad(iANr(mAtom))
                   If (ir.eq.1.or.jr.eq.1) Then
                      f_Const=A_Bend(1)
                   Else
@@ -365,28 +354,22 @@ C                 Do k = 1, 2
 *
                      nqA = nqA + 1
                      iF1=1
-                     Call NxtWrd(Name(iAtom),iF1,iE1)
-                     Lbls(1)=Name(iAtom)(iF1:iE1)
+                     Call NxtWrd(AtomLbl(iAtom),iF1,iE1)
+                     Lbls(1)=AtomLbl(iAtom)(iF1:iE1)
                      iF2=1
-                     Call NxtWrd(Name(mAtom),iF2,iE2)
-                     Lbls(2)=Name(mAtom)(iF2:iE2)
+                     Call NxtWrd(AtomLbl(mAtom),iF2,iE2)
+                     Lbls(2)=AtomLbl(mAtom)(iF2:iE2)
                      If (kDCRR.ne.0) Then
-                        Lbls(2)(iE2+1:iE2+1)='('
-                        Lbls(2)(iE2+2:iE2+1+iChOp(kDCRR))=
-     &                        ChOp(kDCRR)(1:iChOp(kDCRR))
-                        Lbls(2)(iE2+2+iChOp(kDCRR):
-     &                          iE2+2+iChOp(kDCRR))=')'
+                        Lbls(2)(iE2+1:iE2+2+iChOp(kDCRR))=
+     &                   '('//ChOp(kDCRR)(1:iChOp(kDCRR))//')'
                         Call NxtWrd(Lbls(2),iF2,iE2)
                      End If
                      iF3=1
-                     Call NxtWrd(Name(jAtom),iF3,iE3)
-                     Lbls(3)=Name(jAtom)(iF3:iE3)
+                     Call NxtWrd(AtomLbl(jAtom),iF3,iE3)
+                     Lbls(3)=AtomLbl(jAtom)(iF3:iE3)
                      If (kDCRT.ne.0) Then
-                        Lbls(3)(iE3+1:iE3+1)='('
-                        Lbls(3)(iE3+2:iE3+1+iChOp(kDCRT))=
-     &                        ChOp(kDCRT)(1:iChOp(kDCRT))
-                        Lbls(3)(iE3+2+iChOp(kDCRT):
-     &                          iE3+2+iChOp(kDCRT))=')'
+                        Lbls(3)(iE3+1:iE3+2+iChOp(kDCRT))=
+     &                   '('//ChOp(kDCRT)(1:iChOp(kDCRT))//')'
                         Call NxtWrd(Lbls(3),iF3,iE3)
                      End If
                      Write (LuIC,'(A,I3.3,A,I1.1,6A)')
@@ -410,7 +393,7 @@ C                 Do k = 1, 2
 *
                         Call LBend(A,nCent,Val,
      &                             Grad_all(1,nq,iIter),
-     &                             .False.,.False.,
+     &                             .False.,
      &                             '        ',Hess,Proc_dB,Axis,
      &                             Perp_Axis(1,k),(k.eq.2))
 *
@@ -427,8 +410,8 @@ C                 Do k = 1, 2
                         End If
 *
                         Indq(1,nq)=2+k
-                        mi = (iAtom-1)*nAtoms + mAtom
-                        Indq(2,nq)= (jAtom-1)*nAtoms**2 + mi
+                        mi = (iAtom-1)*nsAtom + mAtom
+                        Indq(2,nq)= (jAtom-1)*nsAtom**2 + mi
                         Indq(3,nq)= kDCRT*8 + kDCRR+1
 *
                         f_Const=Max(f_Const,f_Const_Min)
@@ -444,10 +427,9 @@ C                 Do k = 1, 2
 *
 *---------------------- Project the gradient vector
 *
-                        Call ProjSym(nAtoms,nCent,Ind,nStab,
-     &                               jStab,A,iDCR,
+                        Call ProjSym(nCent,Ind,A,iDCR,
      &                               Grad_all(1,nq,iIter),
-     &                               Smmtrc,nDim,PSPrint,Hess,
+     &                               Hess,
      &                               mB_Tot,mdB_Tot,
      &                               BM,dBM,iBM,idBM,nB_Tot,ndB_Tot,
      &                               Proc_dB,nqB,nB,nq,rMult(nq))
@@ -464,28 +446,22 @@ C                 Do k = 1, 2
 *
                   nqA = nqA + 1
                   iF1=1
-                  Call NxtWrd(Name(iAtom),iF1,iE1)
-                  Lbls(1)=Name(iAtom)(iF1:iE1)
+                  Call NxtWrd(AtomLbl(iAtom),iF1,iE1)
+                  Lbls(1)=AtomLbl(iAtom)(iF1:iE1)
                   iF2=1
-                  Call NxtWrd(Name(mAtom),iF2,iE2)
-                  Lbls(2)=Name(mAtom)(iF2:iE2)
+                  Call NxtWrd(AtomLbl(mAtom),iF2,iE2)
+                  Lbls(2)=AtomLbl(mAtom)(iF2:iE2)
                   If (kDCRR.ne.0) Then
-                     Lbls(2)(iE2+1:iE2+1)='('
-                     Lbls(2)(iE2+2:iE2+1+iChOp(kDCRR))=
-     &                     ChOp(kDCRR)(1:iChOp(kDCRR))
-                     Lbls(2)(iE2+2+iChOp(kDCRR):
-     &                       iE2+2+iChOp(kDCRR))=')'
+                     Lbls(2)(iE2+1:iE2+2+iChOp(kDCRR))=
+     &                '('//ChOp(kDCRR)(1:iChOp(kDCRR))//')'
                      Call NxtWrd(Lbls(2),iF2,iE2)
                   End If
                   iF3=1
-                  Call NxtWrd(Name(jAtom),iF3,iE3)
-                  Lbls(3)=Name(jAtom)(iF3:iE3)
+                  Call NxtWrd(AtomLbl(jAtom),iF3,iE3)
+                  Lbls(3)=AtomLbl(jAtom)(iF3:iE3)
                   If (kDCRT.ne.0) Then
-                     Lbls(3)(iE3+1:iE3+1)='('
-                     Lbls(3)(iE3+2:iE3+1+iChOp(kDCRT))=
-     &                     ChOp(kDCRT)(1:iChOp(kDCRT))
-                     Lbls(3)(iE3+2+iChOp(kDCRT):
-     &                       iE3+2+iChOp(kDCRT))=')'
+                     Lbls(3)(iE3+1:iE3+2+iChOp(kDCRT))=
+     &                '('//ChOp(kDCRT)(1:iChOp(kDCRT))//')'
                      Call NxtWrd(Lbls(3),iF3,iE3)
                   End If
                   Write (LuIC,'(A,I3.3,6A)')
@@ -523,8 +499,8 @@ C                 Do k = 1, 2
                      End If
 *
                      Indq(1,nq)=2
-                     mi = (iAtom-1)*nAtoms + mAtom
-                     Indq(2,nq)= (jAtom-1)*nAtoms**2 + mi
+                     mi = (iAtom-1)*nsAtom + mAtom
+                     Indq(2,nq)= (jAtom-1)*nsAtom**2 + mi
                      Indq(3,nq)= kDCRT*8 + kDCRR+1
 *
                      If (.Not.Help .and.
@@ -539,10 +515,9 @@ C                 Do k = 1, 2
 *
 *------------------- Project the gradient vector
 *
-                     Call ProjSym(nAtoms,nCent,Ind,nStab,
-     &                            jStab,A,iDCR,
+                     Call ProjSym(nCent,Ind,A,iDCR,
      &                            Grad_all(1,nq,iIter),
-     &                            Smmtrc,nDim,PSPrint,Hess,
+     &                            Hess,
      &                            mB_Tot,mdB_Tot,
      &                            BM,dBM,iBM,idBM,nB_Tot,ndB_Tot,
      &                            Proc_dB,nqB,nB,nq,rMult(nq))
