@@ -10,9 +10,9 @@
 *                                                                      *
 * Copyright (C) 1991,1997, Roland Lindh                                *
 ************************************************************************
-      SubRoutine Cllct2(Strng,Vector,dVector,Value,Names,nAtom,Coor,
-     &                  nCntr,mCntr,xyz,Grad,Ind,Type,rMss,qMss,Lbl,
-     &                  lWrite,jStab,nStab,mxdc,Deg,Smmtrc,Hess,lIter)
+      SubRoutine Cllct2(Strng,Vector,dVector,Value,nAtom,
+     &                  nCntr,mCntr,xyz,Grad,Ind,Type,qMss,Lbl,
+     &                  lWrite,Deg,Hess,lIter)
 ************************************************************************
 *     Author: Roland Lindh, Dep. of Theoretical Chemistry,             *
 *             University of Lund, SWEDEN                               *
@@ -22,38 +22,54 @@
 *             June '97 (R. Lindh)                                      *
 ************************************************************************
       use Symmetry_Info, only: nIrrep, iOper
+      use Slapaf_Info, only: Cx, dMass, AtomLbl
       Implicit Real*8 (A-H,O-Z)
 #include "print.fh"
 #include "real.fh"
-#include "WrkSpc.fh"
 #include "Molcas.fh"
-      Character*(*) Strng
-      Character*(LENIN) Names(nAtom)
-      Character*(LENIN5)Label
-      Character*(LENIN) Name
-      Character Oper*3, Type*6, Lbl*8
-      Real*8 Coor(3,nAtom), Vector(3,nAtom), xyz(3,nCntr+mCntr),
+      Character(LEN=*) Strng
+      Character(LEN=LENIN5)Label
+      Character(LEN=LENIN) Name
+      Character(LEN=8) Lbl
+      Character Oper*3, Type*6
+      Real*8 Vector(3,nAtom), xyz(3,nCntr+mCntr),
      &       Grad(3,nCntr+mCntr), dVector(3,nAtom,3,nAtom),
      &       Axis(3),
-     &       Perp_Axis(3,2),rMss(nAtom), qMss(nCntr+mCntr),
+     &       Perp_Axis(3,2), qMss(nCntr+mCntr),
      &       Hess(3,nCntr+mCntr,3,nCntr+mCntr)
-      Integer   Ind(nCntr+mCntr,2), nStab(mxdc),
-     &          jStab(0:7,mxdc), iDCR(MxAtom)
+      Integer   Ind(nCntr+mCntr,2), iDCR(MxAtom)
+      Logical lWrite, ldB, lWarn
+      Real*8, Allocatable:: Not_Allocated(:,:)
+*                                                                      *
+************************************************************************
+*                                                                      *
+      Interface
+      Subroutine SphInt(xyz,nCent,OfRef,RR0,Bf,l_Write,Label,dBf,ldB)
+      Integer nCent
+      Real*8  xyz(3,nCent)
+      Real*8, Allocatable, Target:: OfRef(:,:)
+      Real*8  RR0
+      Real*8  Bf(3,nCent)
+      Logical l_Write
+      Character(LEN=8) Label
+      Real*8  dBf(3,nCent,3,nCent)
+      Logical ldB
+      End Subroutine SphInt
+      End Interface
+*                                                                      *
+************************************************************************
+*                                                                      *
 
-      Logical lWrite, ldB, lWarn, PSPrint, Smmtrc(3,nAtom)
 *
       iRout = 50
       iPrint = nPrint(iRout)
       ldB=.True.
       lWarn  = lWrite
       If (iPrint.gt.20) lWrite = .True.
-      PSPrint=.False.
-      If (iPrint.gt.20) PSPrint = .True.
-      If (iPrint.ge.99) Then
-         Call RecPrt(' In Cllct2: Coor',' ',
-     &                               Coor,3,nAtom)
-         Call RecPrt('rMss',' ',rMss,1,nAtom)
-      End If
+#ifdef _DEBUGPRINT_
+      Call RecPrt(' In Cllct2: Coor',' ',Cx(:,:,lIter),3,nAtom)
+      Call RecPrt('dMass',' ',dMass,1,nAtom)
+#endif
 *
       iFrst = 1
       iEnd  = 1
@@ -119,7 +135,7 @@
      &       Type(1:6).ne.'TRANSV'        ) Then
             jsAtom = 0
             Do isAtom = 1, nAtom
-               If (Name.eq.Names(isAtom)) jsAtom = isAtom
+               If (Name.eq.AtomLbl(isAtom)) jsAtom = isAtom
             End Do
             If (jsAtom.eq.0) Then
                Call WarningMessage(2,
@@ -134,12 +150,12 @@
 *
          Ind(ixyz,1) = jsAtom
          Ind(ixyz,2) = iPhase
-         call dcopy_(3,Coor(1,jsAtom),1,xyz(1,ixyz),1)
+         call dcopy_(3,Cx(:,jsAtom,lIter),1,xyz(1,ixyz),1)
 *--------Generate actual coordinate
          If (iAnd(iPhase,1).ne.0) xyz(1,ixyz) = - xyz(1,ixyz)
          If (iAnd(iPhase,2).ne.0) xyz(2,ixyz) = - xyz(2,ixyz)
          If (iAnd(iPhase,4).ne.0) xyz(3,ixyz) = - xyz(3,ixyz)
-         If (Type.eq.'DISSOC') qMss(ixyz) = rMss(jsAtom)
+         If (Type.eq.'DISSOC') qMss(ixyz) = dMass(jsAtom)
 *
       End Do  ! Do ixyz = 1, nCntr+mCntr
 *
@@ -161,7 +177,7 @@
          Grad(1,1) = One
          If (lWrite) Write (6,'(1X,A,A,2X,F10.4,A)') Lbl,
      &          ' : x-component=',Value,'/ bohr'
-         Deg=D_Cart(Ind(1,1),nStab,jStab,mxdc,nIrrep)
+         Deg=D_Cart(Ind(1,1),nIrrep)
       Else If (Type.eq.'Y     ') Then
          Value = xyz(2,1)
          call dcopy_(3,[Zero],0,Grad,1)
@@ -169,7 +185,7 @@
          Grad(2,1) = One
          If (lWrite) Write (6,'(1X,A,A,2X,F10.4,A)') Lbl,
      &          ' : y-component=',Value,'/ bohr'
-         Deg=D_Cart(Ind(1,1),nStab,jStab,mxdc,nIrrep)
+         Deg=D_Cart(Ind(1,1),nIrrep)
       Else If (Type.eq.'Z     ') Then
          Value = xyz(3,1)
          call dcopy_(3,[Zero],0,Grad,1)
@@ -177,46 +193,44 @@
          Grad(3,1) = One
          If (lWrite) Write (6,'(1X,A,A,2X,F10.4,A)') Lbl,
      &          ' : z-component=',Value,'/ bohr'
-         Deg=D_Cart(Ind(1,1),nStab,jStab,mxdc,nIrrep)
+         Deg=D_Cart(Ind(1,1),nIrrep)
       Else If (Type.eq.'STRTCH') Then
          Call Strtch(xyz,nCntr,Value,Grad,lWrite,Lbl,Hess,ldB)
-         Deg=D_Bond(Ind,Ind(1,2),nStab,jStab,mxdc,nIrrep)
+         Deg=D_Bond(Ind,Ind(1,2),nIrrep)
       Else If (Type.eq.'LBEND1')Then
          Call CoSys(xyz,Axis,Perp_Axis)
-         Call LBend(xyz,nCntr,Value,Grad,lWrite,lWarn,Lbl,Hess,ldB,
+         Call LBend(xyz,nCntr,Value,Grad,lWrite,Lbl,Hess,ldB,
      &              Axis,Perp_Axis(1,1),.False.)
-         Deg=D_Bend(Ind,Ind(1,2),nStab,jStab,mxdc,nIrrep)
+         Deg=D_Bend(Ind,Ind(1,2),nIrrep)
       Else If (Type.eq.'LBEND2')Then
          Call CoSys(xyz,Axis,Perp_Axis)
-         Call LBend(xyz,nCntr,Value,Grad,lWrite,lWarn,Lbl,Hess,ldB,
+         Call LBend(xyz,nCntr,Value,Grad,lWrite,Lbl,Hess,ldB,
      &              Axis,Perp_Axis(1,2),.True.)
-         Deg=D_Bend(Ind,Ind(1,2),nStab,jStab,mxdc,nIrrep)
+         Deg=D_Bend(Ind,Ind(1,2),nIrrep)
       Else If (Type.eq.'BEND  ')Then
          Call Bend(xyz,nCntr,Value,Grad,lWrite,lWarn,Lbl,Hess,ldB)
-         Deg=D_Bend(Ind,Ind(1,2),nStab,jStab,mxdc,nIrrep)
+         Deg=D_Bend(Ind,Ind(1,2),nIrrep)
       Else If (Type.eq.'TRSN  ')Then
          Call Trsn(xyz,nCntr,Value,Grad,lWrite,lWarn,Lbl,Hess,ldB)
-         Deg=D_Trsn(Ind,Ind(1,2),nStab,jStab,mxdc,nIrrep)
+         Deg=D_Trsn(Ind,Ind(1,2),nIrrep)
       Else If (Type.eq.'OUTOFP')Then
          Call OutOfP(xyz,nCntr,Value,Grad,lWrite,lWarn,Lbl,Hess,ldB)
-         Deg=D_Trsn(Ind,Ind(1,2),nStab,jStab,mxdc,nIrrep)
+         Deg=D_Trsn(Ind,Ind(1,2),nIrrep)
       Else If (Type(1:3).eq.'NAC')Then
-         Call NACInt(xyz,nCntr,Value,Grad,lWrite,lWarn,Lbl,Hess,ldB,
-     &               lIter)
+         Call NACInt(xyz,nCntr,Value,Grad,lWrite,Lbl,Hess,ldB)
          Deg=One
       Else If (Type(1:5).eq.'EDIFF')Then
-         Call ConInt(xyz,nCntr,Value,Grad,lWrite,lWarn,Lbl,Hess,ldB,
-     &               lIter)
+         Call ConInt(xyz,nCntr,Value,Grad,lWrite,Lbl,Hess,ldB,lIter)
          Deg=One
       Else If (Type(1:6).eq.'SPHERE')Then
-         Call SphInt(xyz,nCntr,ip_Dummy,Value,Grad,lWrite,lWarn,Lbl,
-     &               Hess,ldB)
+         Call SphInt(xyz,nCntr,Not_Allocated,Value,Grad,lWrite,Lbl,Hess,
+     &               ldB)
          Deg=One
       Else If (Type(1:6).eq.'TRANSV')Then
-         Call Transverse(xyz,nCntr,Value,Grad,lWrite,lWarn,Lbl,Hess,ldB)
+         Call Transverse(xyz,nCntr,Value,Grad,lWrite,Lbl,Hess,ldB)
          Deg=One
       Else If (Type.eq.'DISSOC')Then
-         Call Dissoc(xyz,nCntr,mCntr,qMss,nAtom,Value,Grad,lWrite,
+         Call Dissoc(xyz,nCntr,mCntr,qMss,Value,Grad,lWrite,
      &               Lbl,Hess,ldB)
          Deg=One
       Else
@@ -229,8 +243,7 @@
 *                                                                      *
       Deg=Sqrt(Deg)
 *
-      Call ProjSym2(nAtom,nCent,Ind,nStab,jStab,xyz,
-     &             iDCR,Grad,Vector,Smmtrc,PSPrint,Hess,dVector)
+      Call ProjSym2(nAtom,nCent,Ind,xyz,iDCR,Grad,Vector,Hess,dVector)
       If (iPrint.ge.99) Then
          Call RecPrt(' symmetry adapted vector',
      &                              ' ',Vector,3,nAtom)
