@@ -12,12 +12,12 @@
      &                 Thr)
       Implicit Real*8 (a-h,o-z)
 #include "real.fh"
-#include "WrkSpc.fh"
+#include "stdalloc.fh"
       Real*8 Bmtrx(nq,nx), Gmtrx(nq,nq), EVec(nq,nq),
      &       EVal(nq*(nq+1)/2), uMtrx(nX), Scrt(nq,nX)
       Logical g12K, Diagonal
-      Real*8 Zero_Approx
-      Parameter (Zero_Approx=0.1D-9)
+      Real*8, Parameter:: Zero_Approx=0.1D-9
+      Real*8, Allocatable:: Work(:), W(:)
 *                                                                      *
 ************************************************************************
 *                                                                      *
@@ -96,12 +96,12 @@
       If (.NOT.Diagonal) Then
          N=nQ
          LDZ=Max(1,N)
-         Call Allocate_Work(ipWork,3*N)
-         Call FZero(Work(ipWork),3*N)
-         Call Allocate_Work(ipW,N)
-         Call FZero(Work(ipW),N)
+         Call mma_allocate(Work,3*N,Label='Work')
+         Work(:)=Zero
+         Call mma_allocate(W,N,Label='W')
+         W(:)=Zero
          Info=0
-        call dspev_('V','U',N,Eval,Work(ipW),EVec,LDZ,Work(ipWork),Info)
+        call dspev_('V','U',N,Eval,W,EVec,LDZ,Work,Info)
          If (Info.ne.0) Then
             Write (6,*) 'Info.ne.0'
             Write (6,*) 'Info=',Info
@@ -110,16 +110,16 @@
          Call FZero(EVal,N*(N+1)/2)
          Do i = 1, N
             ii = i*(i+1)/2
-            EVal(ii)=Work(ipW+i-1)
+            EVal(ii)=W(i)
          End Do
-         Call Free_Work(ipW)
-         Call Free_Work(ipWork)
+         Call mma_deallocate(W)
+         Call mma_deallocate(Work)
       End If
       Call DScal_(nQ*(nQ+1)/2,-1.0D0,EVal,1)
       Call JacOrd(EVal,EVec,nQ,nQ)
 *     Fix standard direction.
       Do iQ = 1, nQ
-         tmp=OrbPhase(EVec(1,iQ),nQ)
+         call VecPhase(EVec(1,iQ),nQ)
       End Do
       Call DScal_(nQ*(nQ+1)/2,-1.0D0,EVal,1)
 #ifdef _DEBUGPRINT_
@@ -131,7 +131,6 @@
 *---- Remove redundant vectors and form g     K
 *
       nK = 0
-      ThrD=1.0D-13
       Do i = 1, nQ
          ii=i*(i+1)/2
          If (EVal(ii).gt.Thr) Then
@@ -145,7 +144,7 @@ c        If (g12K .and. Abs(EVal(i)).gt.Zero)
 #ifdef _DEBUGPRINT_
       Call RecPrt('ElRed: The NonRedundant eigenvectors',
      &            '(5e21.12)',EVec,nQ,nK)
-       Call RecPrt('ElRed: eigenvalues ','(8E12.4)',
+      Call RecPrt('ElRed: eigenvalues ','(8E12.4)',
      &            EVal,1,nK)
 #endif
 *
@@ -159,13 +158,13 @@ c        If (g12K .and. Abs(EVal(i)).gt.Zero)
      &                 Thr,BM,iBM,nB_Tot,nqB)
       Implicit Real*8 (a-h,o-z)
 #include "real.fh"
-#include "WrkSpc.fh"
+#include "stdalloc.fh"
       Real*8 Gmtrx(nq,nq), EVec(nq,nq),
      &       EVal(nq*(nq+1)/2), uMtrx(nX), BM(nB_Tot)
       Integer iBM(nB_Tot), nqB(nq)
       Logical g12K, Diagonal
-      Real*8 Zero_Approx
-      Parameter (Zero_Approx=0.1D-9)
+      Real*8, Parameter:: Zero_Approx=0.1D-9
+      Real*8, Allocatable:: Work(:), W(:)
 *                                                                      *
 ************************************************************************
 *                                                                      *
@@ -252,12 +251,12 @@ c        If (g12K .and. Abs(EVal(i)).gt.Zero)
       If (.NOT.Diagonal) Then
          N=nQ
          LDZ=Max(1,N)
-         Call Allocate_Work(ipWork,3*N)
-         Call FZero(Work(ipWork),3*N)
-         Call Allocate_Work(ipW,N)
-         Call FZero(Work(ipW),N)
+         Call mma_allocate(Work,3*N,Label='Work')
+         Work(:)=Zero
+         Call mma_allocate(W,N,Label='W')
+         W(:)=Zero
          Info=0
-        call dspev_('V','U',N,Eval,Work(ipW),EVec,LDZ,Work(ipWork),Info)
+         call dspev_('V','U',N,Eval,W,EVec,LDZ,Work,Info)
          If (Info.ne.0) Then
             Write (6,*) 'Info.ne.0'
             Write (6,*) 'Info=',Info
@@ -266,16 +265,16 @@ c        If (g12K .and. Abs(EVal(i)).gt.Zero)
          Call FZero(EVal,N*(N+1)/2)
          Do i = 1, N
             ii = i*(i+1)/2
-            EVal(ii)=Work(ipW+i-1)
+            EVal(ii)=W(i)
          End Do
-         Call Free_Work(ipW)
-         Call Free_Work(ipWork)
+         Call mma_deallocate(W)
+         Call mma_deallocate(Work)
       End If
       Call DScal_(nQ*(nQ+1)/2,-1.0D0,EVal,1)
       Call JacOrd(EVal,EVec,nQ,nQ)
 *     Fix standard direction.
       Do iQ = 1, nQ
-         tmp=OrbPhase(EVec(1,iQ),nQ)
+         call VecPhase(EVec(1,iQ),nQ)
       End Do
       Call DScal_(nQ*(nQ+1)/2,-1.0D0,EVal,1)
 #ifdef _DEBUGPRINT_
@@ -287,7 +286,6 @@ c        If (g12K .and. Abs(EVal(i)).gt.Zero)
 *---- Remove redundant vectors and form g     K
 *
       nK = 0
-      ThrD=1.0D-13
       Do i = 1, nQ
          ii=i*(i+1)/2
          If (EVal(ii).gt.Thr) Then
