@@ -8,15 +8,14 @@
 * For more details see the full text of the license in the file        *
 * LICENSE or in <http://www.gnu.org/licenses/>.                        *
 ************************************************************************
-      Subroutine GenCoo(Cart,nAtom,Coor,mAtom,Vctrs,Smmtrc,
-     &                  nDim,iAnr,jAnr,iTabAI,Degen)
+      Subroutine GenCoo(Cart,nsAtom,Coor,mTtAtm,Vctrs,nDim,jAnr,iTabAI)
       use Symmetry_Info, only: nIrrep, iOper
+      use Slapaf_Info, only: Degen, Smmtrc, ANr
       Implicit Real*8 (a-h,o-z)
 #include "real.fh"
-      Real*8 Cart(3,nAtom), Coor(3,mAtom), Vctrs(3*mAtom,nDim), r(3),
-     &       Degen(3*nAtom)
-      Integer iAnr(nAtom), jAnr(mAtom), iTabAI(2,mAtom)
-      Logical New, SmmTrc(3,nAtom)
+      Real*8 Cart(3,nsAtom), Coor(3,mTtAtm), Vctrs(3*mTtAtm,nDim), r(3)
+      Integer jAnr(mTtAtm), iTabAI(2,mTtAtm)
+      Logical New
 *                                                                      *
 ************************************************************************
 *                                                                      *
@@ -25,26 +24,26 @@
 ************************************************************************
 *                                                                      *
 #ifdef _DEBUGPRINT_
-      Call RecPrt('GenCoo: Cart',' ',Cart,3,nAtom)
-      Call RecPrt('GenCoo: Degen',' ',Degen,3,nAtom)
+      Call RecPrt('GenCoo: Cart',' ',Cart,3,nsAtom)
+      Call RecPrt('GenCoo: Degen',' ',Degen,3,nsAtom)
 #endif
 *
 *-----Loop over list of symmetry unique centers
 *
       iSt=1
       iDim = 0
-      Do iAtom = 1, nAtom
-         Fact = One/Sqrt(Degen((iAtom-1)*3 + 1))
+      Do iAtom = 1, nsAtom
+         Fact = One/Sqrt(Degen(1,iAtom))
          iEnd=iSt
          jDim=iDim
          call dcopy_(3,Cart(1,iAtom),1,Coor(1,iSt),1)
          iTabAI(1,iEnd) = iAtom
          iTabAI(2,iEnd) = iOper(0)
-         jAnr(iEnd)=iAnr(iAtom)
+         jAnr(iEnd)=Anr(iAtom)
          Do ix = 1, 3
             If (Smmtrc(ix,iAtom)) Then
                jDim=jDim+1
-               call dcopy_(3*mAtom,[Zero],0,Vctrs(1,jDim),1)
+               call dcopy_(3*mTtAtm,[Zero],0,Vctrs(1,jDim),1)
                Vctrs((iEnd-1)*3+ix,jDim)=Fact
             End If
          End Do
@@ -77,7 +76,7 @@
                Coor(3,iEnd)=z
                iTabAI(1,iEnd) = iAtom
                iTabAI(2,iEnd) = iOper(ig)
-               jAnr(iEnd)=iAnr(iAtom)
+               jAnr(iEnd)=Anr(iAtom)
                jDim=iDim
                Do ix = 1, 3
                   If (Smmtrc(ix,iAtom)) Then
@@ -97,12 +96,12 @@
       End Do         ! End loop over centers
 *
 #ifdef _DEBUGPRINT_
-      Call RecPrt(' In GenCoo: Coor',' ',Coor,3,mAtom)
-      Call RecPrt(' In GenCoo: Vctrs',' ',Vctrs,3*mAtom,nDim)
+      Call RecPrt(' In GenCoo: Coor',' ',Coor,3,mTtAtm)
+      Call RecPrt(' In GenCoo: Vctrs',' ',Vctrs,3*mTtAtm,nDim)
       Write (6,*)
       Write (6,*) ' iTabAI'
       Write (6,*)
-      Do iAtom = 1, mAtom
+      Do iAtom = 1, mTtAtm
          Write (6,*) iTabAI(1,iAtom),iTabAI(2,iAtom)
       End Do
 #endif
