@@ -10,28 +10,24 @@
 ************************************************************************
       Subroutine Get_CurviL(
      &              nq,nqRF,nqB,nqA,nqT,nqO,
-     &              nAtoms,iIter,nIter,Cx,jStab,
-     &              nStab,nDim,Smmtrc,Process,Value,nB,
-     &              iANr,qLbl,iRef,
-     &              fconst,rMult,iOptC,LuIC,Name,Indq,iPrv,
-     &              dMass,iCoSet,Grad_all,iGlow,iGhi,Proc_dB,
+     &              nsAtom,iIter,nIter,Cx,
+     &              Process,Value,nB,
+     &              qLbl,iRef,
+     &              fconst,rMult,LuIC,Indq,iPrv,
+     &              Grad_all,iGlow,iGhi,Proc_dB,
      &              iTabBonds,iTabAtoms,nBonds,nMax,iTabAI,mAtoms,
      &              mB_Tot,mdB_Tot,
      &              BM,dBM,iBM,idBM,
      &              nB_Tot,ndB_Tot,mqB,Thr_small)
       Implicit Real*8 (a-h,o-z)
-      Real*8 Cx(3,nAtoms,nIter), fconst(nB),
-     &       Value(nB,nIter), rMult(nB), dMass(nAtoms),
-     &       Grad_all(9,iGlow:iGhi,nIter),
-     &       BM(nB_Tot),dBM(ndB_Tot)
-      Integer nStab(nAtoms), iANr(nAtoms),
-     &        jStab(0:7,nAtoms), Indq(3,nB), iCoSet(0:7,nAtoms),
+      Real*8 Cx(3,nsAtom,nIter), fconst(nB), Value(nB,nIter), rMult(nB),
+     &       Grad_all(9,iGlow:iGhi,nIter), BM(nB_Tot),dBM(ndB_Tot)
+      Integer Indq(3,nB),
      &        iTabBonds(3,nBonds), iTabAtoms(2,0:nMax,mAtoms),
      &        iTabAI(2,mAtoms), iBM(nB_Tot), idBM(2,ndB_Tot), mqB(nB)
-      Logical Smmtrc(3,nAtoms), Process, Proc_dB
-      Character*14 qLbl(nB)
+      Logical Process, Proc_dB
+      Character(LEN=14) qLbl(nB)
 #include "Molcas.fh"
-      Character*(LENIN) Name(nAtoms)
 *                                                                      *
 ************************************************************************
 *                                                                      *
@@ -46,21 +42,21 @@
       nq_=nq
       Call RF_Coord(
      &              nq,
-     &              nAtoms,iIter,nIter,Cx,jStab,
-     &              nStab,nDim,Smmtrc,Process,Value,nB,
-     &              iANr,qLbl,iRef,
+     &              nsAtom,iIter,nIter,Cx,
+     &              Process,Value,nB,
+     &              qLbl,iRef,
      &              fconst,rMult,LuIC,Indq,
-     &              dMass,iCoSet,Proc_dB,mB_Tot,mdB_Tot,
+     &              Proc_dB,mB_Tot,mdB_Tot,
      &              BM,dBM,iBM,idBM,nB_Tot,ndB_Tot,mqB)
       nqRF=nq-nq_
 *
       nq_=nq
       Call Bond_List(
      &              nq,
-     &              nAtoms,iIter,nIter,Cx,jStab,
-     &              nStab,nDim,Smmtrc,Process,Value,nB,
-     &              iANr,qLbl,fconst,
-     &              rMult,iOptC,LuIC,Name,Indq,
+     &              nsAtom,iIter,nIter,Cx,
+     &              Process,Value,nB,
+     &              qLbl,fconst,
+     &              rMult,LuIC,Indq,
      &              Proc_dB,iTabBonds,nBonds,iTabAI,mAtoms,
      &              mB_Tot,mdB_Tot,
      &              BM,dBM,iBM,idBM,nB_Tot,ndB_Tot,mqB)
@@ -69,10 +65,10 @@
       nq_=nq
       Call Angle_List(
      &              nq,
-     &              nAtoms,iIter,nIter,Cx,jStab,
-     &              nStab,nDim,Smmtrc,Process,Value,nB,
-     &              iANr,qLbl,iRef,
-     &              fconst,rMult,LuIC,Name,Indq,
+     &              nsAtom,iIter,nIter,Cx,
+     &              Process,Value,nB,
+     &              qLbl,iRef,
+     &              fconst,rMult,LuIC,Indq,
      &              Grad_all,iGlow,iGhi,iPrv,Proc_dB,
      &              iTabBonds,nBonds,iTabAI,mAtoms,iTabAtoms,nMax,
      &              mB_Tot,mdB_Tot,
@@ -82,10 +78,10 @@
       nq_=nq
       Call Torsion_List(
      &              nq,
-     &              nAtoms,iIter,nIter,Cx,jStab,
-     &              nStab,nDim,Smmtrc,Process,Value,nB,
-     &              iANr,qLbl,iRef,
-     &              fconst,rMult,LuIC,Name,Indq,iPrv,Proc_dB,
+     &              nsAtom,iIter,nIter,Cx,
+     &              Process,Value,nB,
+     &              qLbl,iRef,
+     &              fconst,rMult,LuIC,Indq,iPrv,Proc_dB,
      &              iTabBonds,nBonds,iTabAI,mAtoms,iTabAtoms,nMax,
      &              mB_Tot,mdB_Tot,
      &              BM,dBM,iBM,idBM,nB_Tot,ndB_Tot,mqB)
@@ -94,10 +90,10 @@
       nq_=nq
       Call OutOfPlane_List(
      &              nq,
-     &              nAtoms,iIter,nIter,Cx,jStab,
-     &              nStab,nDim,Smmtrc,Process,Value,nB,
-     &              iANr,qLbl,iRef,
-     &              fconst,rMult,LuIC,Name,Indq,iPrv,Proc_dB,
+     &              nsAtom,iIter,nIter,Cx,
+     &              Process,Value,nB,
+     &              qLbl,iRef,
+     &              fconst,rMult,LuIC,Indq,iPrv,Proc_dB,
      &              iTabBonds,nBonds,iTabAI,mAtoms,iTabAtoms,nMax,
      &              mB_Tot,mdB_Tot,
      &              BM,dBM,iBM,idBM,nB_Tot,ndB_Tot,mqB)
