@@ -8,28 +8,30 @@
 * For more details see the full text of the license in the file        *
 * LICENSE or in <http://www.gnu.org/licenses/>.                        *
 ************************************************************************
-      Subroutine GF(nX,mInter,nInter,Tmp1,Tmp2,EVec,EVal,RedM,
-     &              iNeg,iDo_dDipM,dDipM,mTR,Smmtrc,nAtom,DipM)
+      Subroutine GF(nX,nDoF,nInter,EVec,EVal,RedM,iNeg,dDipM,mTR,nAtom,
+     &              DipM)
+      use Slapaf_Info, only: Smmtrc
+      use Slapaf_parameters, only: nDimBC
       Implicit Real*8 (a-h,o-z)
 #include "real.fh"
-#include "print.fh"
-#include "WrkSpc.fh"
-      Logical Smmtrc(3,nAtom)
-      Real*8 dDipM(3,nInter+mTR), DipM(3), Tmp1(nX**2), Tmp2(nX**2),
-     &       EVec(2*mInter,mInter), EVal(2*mInter), RedM(mInter)
+#include "stdalloc.fh"
+      Real*8 dDipM(3,nInter+mTR), DipM(3),
+     &       EVec(2*nDoF,nDoF), EVal(2*nDoF), RedM(nDoF)
+      Real*8, Allocatable:: G(:), GInv(:), F(:), Tmp1(:), Tmp2(:)
 *                                                                      *
 ************************************************************************
 *                                                                      *
-      iRout=138
-*define _DEBUGPRINT_
+*#define _DEBUGPRINT_
 #ifdef _DEBUGPRINT_
       Call RecPrt('GF: dDipM',' ',dDipM,3,nInter)
       Call RecPrt('GF: DipM',' ',DipM,3,1)
 #endif
+      Call mma_allocate(Tmp1,nX**2,Label='Tmp1')
+      Call mma_allocate(Tmp2,nX**2,Label='Tmp2')
 *                                                                      *
 ************************************************************************
 *                                                                      *
-*     Note that all calculations will be done in the cartesian basis!  *
+*     Note that all calculations will be done in the Cartesian basis!  *
 *                                                                      *
 ************************************************************************
 *                                                                      *
@@ -39,42 +41,45 @@
 *                                                                      *
 *     Generate the G matrix (mass tensor in cartesians)
 *
-      Call Mk_G(ipG,ipGInv)
+      Call mma_allocate(G,nDimBC**2,Label='G')
+      Call mma_allocate(GInv,nDimBC**2,Label='GInv')
+      Call Mk_G(G,GInv,nDimBC)
 *
 *
 *     Get the force constant matrix in cartesians
 *
-      Call Get_H(ip_H)
+      Call mma_allocate(F,nX**2,Label='F')
+      Call Get_H(F,nX)
 *                                                                      *
 ************************************************************************
 *                                                                      *
 *     Form the GF-matrix (actually G^(1/2)FG^(1/2))
 *
-      Call GF_Mult(Work(ipG),Work(ip_H),Tmp2,mInter)  ! Result in Tmp2
-      Call Free_Work(ip_H)
+      Call GF_Mult(G,F,Tmp2,nDoF)  ! Result in Tmp2
+      Call mma_deallocate(F)
 *
 *     Compute the frequencies and harmonic eigenfunctions in
 *     Cartesians.
 *
-      Call GF_Harmonic_Frequencies(Work(ipG),Work(ipGInv),Tmp1,Tmp2,
-     &                             EVec,EVal,RedM,iNeg,nX,mInter)
+      Call GF_Harmonic_Frequencies(G,GInv,Tmp1,Tmp2,EVec,EVal,RedM,
+     &                             iNeg,nX,nDoF)
 *
-      Call Free_Work(ipG)
-      Call Free_Work(ipGInv)
+      Call mma_deallocate(G)
+      Call mma_deallocate(GInv)
 *                                                                      *
 ************************************************************************
 ************************************************************************
 *                                                                      *
 *     Compute the dipole moment derivative in Cartesians.
 *
-      Call Get_dDipM(dDipM,DipM,mInter,nInter)
+      Call Get_dDipM(dDipM,DipM,nDoF,nInter)
 *                                                                      *
 ************************************************************************
 *                                                                      *
 *    Transform from cartesian to normal coordinates
 *
-      Do iNC = 1, mInter
-         call dcopy_(mInter,EVec(1,iNC),2,Tmp2,1)
+      Do iNC = 1, nDoF
+         call dcopy_(nDoF,EVec(1,iNC),2,Tmp2,1)
          ix = (iNC-1)*3 + 1
          iy = (iNC-1)*3 + 2
          iz = (iNC-1)*3 + 3
@@ -93,14 +98,14 @@
             End Do
          End Do
       End Do
-      call dcopy_(3*mInter,Tmp1,1,dDipM,1)
+      call dcopy_(3*nDoF,Tmp1,1,dDipM,1)
 #ifdef _DEBUGPRINT_
-      Call RecPrt('dDipM(normal coord.)',' ',dDipM,3,mInter)
+      Call RecPrt('dDipM(normal coord.)',' ',dDipM,3,nDoF)
 #endif
+      Call mma_deallocate(Tmp2)
+      Call mma_deallocate(Tmp1)
 *                                                                      *
 ************************************************************************
 *                                                                      *
       Return
-c Avoid unused argument warnings
-      If (.False.) Call Unused_integer(iDo_dDipM)
       End
