@@ -8,60 +8,45 @@
 * For more details see the full text of the license in the file        *
 * LICENSE or in <http://www.gnu.org/licenses/>.                        *
 ************************************************************************
-      Subroutine mk_G(ipG,ipGInv)
-#include "info_slapaf.fh"
-#include "WrkSpc.fh"
-*
-      nX=3*nsAtom
-      mInter=mInt + mTROld
-*
-      Call Allocate_Work(ipG,nX**2)
-      Call Allocate_Work(ipGInv,nX**2)
-*
-      Call mk_G_(Work(ipG),Work(ipGInv),nX,mInter,nsAtom,.Not.User_Def,
-     &           CurviLinear,Smmtrc,Degen,Work(ipCM))
-*
-      Return
-      End
-      Subroutine mk_G_(G,GInv,nX,mInter,nAtom,Auto,nrc,Smmtrc,Degen,
-     &                 dMass)
+      Subroutine mk_G(G,GInv,nDimBC)
+      use Slapaf_Info, only: dMass, Degen, Smmtrc
+      use Slapaf_Parameters, only: Curvilinear, User_Def
       Implicit Real*8 (a-h,o-z)
 #include "real.fh"
 #include "constants2.fh"
 *
-      Real*8 G(mInter,mInter), GInv(mInter**2), dMass(nAtom),
-     &       Degen(3,nAtom)
-      Logical Auto, nrc, Smmtrc(3,nAtom)
+      Real*8 G(nDimBC,nDimBC), GInv(nDimBC,nDimBC)
+      Logical Auto
+
+      Auto=.Not.User_Def
+      nsAtom=SIZE(Smmtrc,2)
 *                                                                      *
 ************************************************************************
 *                                                                      *
 *     Generate the mass tensor
 *
-      Call FZero(G,mInter**2)
-      Call FZero(GInv,mInter**2)
+      G(:,:)=Zero
+      GInv(:,:)=Zero
       ii = 0
-      Do i = 1, nAtom
+      Do i = 1, nsAtom
          Do ix = 1, 3
             If (Smmtrc(ix,i)) Then
                ii = ii + 1
-               If (Auto.and..Not.nrc) Then
+               If (Auto.and..Not.Curvilinear) Then
                   G(ii,ii) = Degen(ix,i)/dMass(i)
                Else
                   G(ii,ii) = One/(Degen(ix,i)*dMass(i))
                End If
-               jj = (ii-1)*mInter + ii
-               GInv(jj) = One/(G(ii,ii)*UTOAU)
+               GInv(ii,ii) = One/(G(ii,ii)*UTOAU)
             End If
          End Do
       End Do
 #ifdef _DEBUGPRINT_
-      Call RecPrt('G (cartesian)',' ',G,mInter,mInter)
-      Call RecPrt('G-1 (cartesian)',' ',GInv,mInter,mInter)
+      Call RecPrt('G (cartesian)',' ',G,nDimBC,nDimBC)
+      Call RecPrt('G-1 (cartesian)',' ',GInv,nDimBC,nDimBC)
 #endif
 *                                                                      *
 ************************************************************************
 *                                                                      *
       Return
-c Avoid unused argument warnings
-      If (.False.) Call Unused_integer(nX)
       End
